@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -11,17 +11,15 @@ constants published by the :mod:`beartype.meta` submodule. These metadata
 constants are commonly inspected (and thus expected) by external automation.
 '''
 
-# ....................{ TODO                              }....................
-#FIXME: *DROP PYTHON 3.6 SUPPORT.* Seriously. It's dead, people. Code goes on.
-
+# ....................{ TODO                               }....................
 #FIXME: Consider significantly expanding the above module docstring, assuming
 #Sphinx presents this module in its generated frontmatter.
 
-# ....................{ IMPORTS                           }....................
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+# ....................{ IMPORTS                            }....................
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 # CAUTION: Explicitly list *ALL* public attributes imported below in the
 # "__all__" list global declared below to avoid linter complaints.
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 # CAUTION: To avoid race conditions during setuptools-based installation, this
 # module may import *ONLY* from modules guaranteed to exist at the start of
 # installation. This includes all standard Python and package submodules but
@@ -29,20 +27,20 @@ constants are commonly inspected (and thus expected) by external automation.
 # installed at some later time in the installation. Likewise, to avoid circular
 # import dependencies, the top-level of this module should avoid importing
 # package submodules where feasible.
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 # CAUTION: To avoid polluting the public module namespace, external attributes
 # should be locally imported at module scope *ONLY* under alternate private
 # names (e.g., "from argparse import ArgumentParser as _ArgumentParser" rather
 # than merely "from argparse import ArgumentParser").
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-# ....................{ IMPORTS ~ meta                    }....................
+# ....................{ IMPORTS ~ meta                     }....................
 # For PEP 8 compliance, versions constants expected by external automation are
 # imported under their PEP 8-mandated names.
 from beartype.meta import VERSION as __version__
 from beartype.meta import VERSION_PARTS as __version_info__
 
-# ....................{ IMPORTS ~ non-meta                }....................
+# ....................{ IMPORTS ~ non-meta                 }....................
 from sys import modules as _modules
 
 # If this submodule is being imported at install time from our top-level
@@ -56,17 +54,15 @@ from sys import modules as _modules
 if 'beartype.__is_installing__' not in _modules:
     # Publicize the private @beartype._decor.beartype decorator as
     # @beartype.beartype, preserving all implementation details as private.
-    from beartype._decor.main import beartype
+    from beartype._decor.decormain import beartype
 
-    #FIXME: Unit test the existence of:
-    #* "beartype.BeartypeStrategy".
-    #* "beartype.BeartypeConfiguration".
     # Publicize all top-level configuration attributes required to configure the
     # @beartype.beartype decorator.
-    from beartype._decor.conf import (
+    from beartype._conf import (
         BeartypeConf,
         BeartypeStrategy,
     )
+# Else, this submodule is *NOT* being imported at install time.
 
 # Delete the temporarily imported "sys.modules" global for ultimate safety.
 del _modules
@@ -93,13 +89,13 @@ For PEP 8 compliance, this specifier has the canonical name
 '''
 
 
-__all__ = [
-    'BeartypeConf',
-    'BeartypeStrategy',
-    'beartype',
-    '__version__',
-    '__version_info__',
-]
+# __all__ = [
+#     'BeartypeConf',
+#     'BeartypeStrategy',
+#     'beartype',
+#     '__version__',
+#     '__version_info__',
+# ]
 '''
 Special list global of the unqualified names of all public package attributes
 explicitly exported by and thus safely importable from this package.
@@ -121,3 +117,66 @@ example, :mod:`mypy` emits an error resembling:
     error: Module 'beartype' does not explicitly export attribute 'beartype';
     implicit reexport disabled.
 '''
+
+# ....................{ DEPRECATIONS                       }....................
+def __getattr__(attr_deprecated_name: str) -> object:
+    '''
+    Dynamically retrieve a deprecated attribute with the passed unqualified
+    name from this submodule and emit a non-fatal deprecation warning on each
+    such retrieval if this submodule defines this attribute *or* raise an
+    exception otherwise.
+
+    The Python interpreter implicitly calls this :pep:`562`-compliant module
+    dunder function under Python >= 3.7 *after* failing to directly retrieve an
+    explicit attribute with this name from this submodule. Since this dunder
+    function is only called in the event of an error, neither space nor time
+    efficiency are a concern here.
+
+    Parameters
+    ----------
+    attr_deprecated_name : str
+        Unqualified name of the deprecated attribute to be retrieved.
+
+    Returns
+    ----------
+    object
+        Value of this deprecated attribute.
+
+    Warns
+    ----------
+    :class:`DeprecationWarning`
+        If this attribute is deprecated.
+
+    Raises
+    ----------
+    :exc:`AttributeError`
+        If this attribute is unrecognized and thus erroneous.
+    '''
+
+    # Isolate imports to avoid polluting the module namespace.
+    from beartype._util.mod.utilmoddeprecate import deprecate_module_attr
+
+    # Package scope (i.e., dictionary mapping from the names to values of all
+    # non-deprecated attributes defined by this package).
+    attr_nondeprecated_name_to_value = globals()
+
+    # If this deprecated attribute is the deprecated "beartype.abby" submodule,
+    # forcibly import the non-deprecated "beartype.door" submodule aliased to
+    # "beartype.abby" into this package scope. For efficiency, this package does
+    # *NOT* unconditionally import and expose the "beartype.door" submodule
+    # above. That submodule does *NOT* exist in the globals() dictionary
+    # defaulted to above and *MUST* now be forcibly injected there.
+    if attr_deprecated_name == 'abby':
+        from beartype import door
+        attr_nondeprecated_name_to_value = {'door': door}
+        attr_nondeprecated_name_to_value.update(globals())
+    # Else, this deprecated attribute is any other attribute.
+
+    # Return the value of this deprecated attribute and emit a warning.
+    return deprecate_module_attr(
+        attr_deprecated_name=attr_deprecated_name,
+        attr_deprecated_name_to_nondeprecated_name={
+            'abby': 'door',
+        },
+        attr_nondeprecated_name_to_value=attr_nondeprecated_name_to_value,
+    )
