@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -16,10 +16,7 @@ importation (e.g., :mod:`numpy`) despite :mod:`beartype` itself *never*
 requiring those imports. Until resolved, that subpackage is considered tainted.
 '''
 
-# ....................{ TODO                              }....................
-#FIXME: Revise all "README.rst" examples in accordance with recent changes to
-#this submodule. Let's preserve worky, please.
-
+# ....................{ TODO                               }....................
 #FIXME: Add types for all remaining useful "collections.abc" interfaces,
 #including:
 #* "Reversible".
@@ -33,13 +30,13 @@ requiring those imports. Until resolved, that subpackage is considered tainted.
 #* "ByteString". (wut)
 #* Dictionary-specific views (e.g., "MappingView", "ItemsView").
 
-# ....................{ IMPORTS                           }....................
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+# ....................{ IMPORTS                            }....................
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 # WARNING: To avoid polluting the public module namespace, external attributes
 # should be locally imported at module scope *ONLY* under alternate private
 # names (e.g., "from argparse import ArgumentParser as _ArgumentParser" rather
 # than merely "from argparse import ArgumentParser").
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
 import functools as _functools
 import numbers as _numbers
@@ -67,6 +64,7 @@ from enum import (
     EnumMeta as _EnumMeta,
 )
 from io import IOBase as _IOBase
+from sys import exc_info as _exc_info
 from typing import Any
 
 # Note that:
@@ -87,13 +85,17 @@ from types import (
     AsyncGeneratorType as _AsyncGeneratorType,
     BuiltinFunctionType as _BuiltinFunctionType,
     CoroutineType as _CoroutineType,
+    FrameType as _FrameType,
     FunctionType as _FunctionType,
     GeneratorType as _GeneratorType,
+    GetSetDescriptorType as _GetSetDescriptorType,
+    MemberDescriptorType as _MemberDescriptorType,
     MethodType as _MethodType,
     ModuleType as _ModuleType,
+    TracebackType as _TracebackType,
 )
 
-# ....................{ IMPORTS ~ conditional             }....................
+# ....................{ IMPORTS ~ conditional              }....................
 #FIXME: Preserve for when we inevitably require similar logic in the future.
 
 # # Attempt to import types unavailable under Python 3.5, all of which should
@@ -108,7 +110,7 @@ from types import (
 # except ImportError:
 #     _Collection = None
 
-# ....................{ CLASSES                           }....................
+# ....................{ CLASSES                            }....................
 class UnavailableType(object):
     '''
     **Unavailable type** (i.e., type *not* available under the active Python
@@ -135,7 +137,7 @@ class _UnavailableTypesTuple(tuple):
 
     pass
 
-# ....................{ TYPES ~ core                      }....................
+# ....................{ TYPES ~ core                       }....................
 AnyType = object
 '''
 Type of all objects regardless of type.
@@ -161,14 +163,14 @@ Type of all **C- and Python-based modules** (i.e., importable files implemented
 either as C extensions or in pure Python).
 '''
 
-# ....................{ TYPES ~ core : singleton          }....................
-EllipsisType: Any = type(Ellipsis)
+# ....................{ TYPES ~ core : singleton           }....................
+EllipsisType: type = type(Ellipsis)
 '''
 Type of the ``Ellipsis`` singleton.
 '''
 
 
-NoneType: Any = type(None)
+NoneType: type = type(None)
 '''
 Type of the ``None`` singleton.
 
@@ -188,12 +190,12 @@ Depressingly, this type must now be manually redefined everywhere.
 '''
 
 
-NotImplementedType: Any = type(NotImplemented)
+NotImplementedType: type = type(NotImplemented)
 '''
 Type of the ``NotImplemented`` singleton.
 '''
 
-# ....................{ TYPES ~ call                      }....................
+# ....................{ TYPES ~ call                       }....................
 CallablePartialType = _functools.partial
 '''
 Type of all **pure-Python partial callables** (i.e., callables dynamically
@@ -214,7 +216,54 @@ Type of all **code objects** (i.e., C-based objects underlying all pure-Python
 callables to which those callables are compiled for efficiency).
 '''
 
-# ....................{ TYPES ~ call : function           }....................
+# ....................{ TYPES ~ call : exception           }....................
+ExceptionTracebackType = _TracebackType
+'''
+Type of all **traceback objects** (i.e., C-based objects comprising the full
+stack traces associated with raised exceptions).
+'''
+
+
+CallableFrameType = _FrameType
+'''
+Type of all **call stack frame objects** (i.e., C-based objects
+encapsulating each call to each callable on the current call stack).
+'''
+
+# ....................{ TYPES ~ call : closure             }....................
+def _closure_varcell_factory():
+    '''
+    Arbitrary function returning a closure-specific cell variable exposed by an
+    arbitrary closure isolated to this function.
+    '''
+
+    # Arbitrary outer local variable.
+    cell_variable = 42
+
+    def closure():
+        '''
+        Arbitrary closure exposing a closure-specific cell variable.
+        '''
+
+        nonlocal cell_variable
+
+    return closure.__closure__[0]  # pyright: ignore[reportOptionalSubscript]
+
+
+# Although Python >= 3.7 now exposes an explicit closure cell variable type via
+# the standard "types.CellType" object, this is of no benefit to older versions
+# of Python. Ergo, the type of an arbitrary method wrapper guaranteed to
+# *ALWAYS* exist is obtained instead.
+ClosureVarCellType = type(_closure_varcell_factory())
+'''
+Type of all **pure-Python closure cell variables.**
+'''
+
+
+# Delete this factory function for safety.
+del _closure_varcell_factory
+
+# ....................{ TYPES ~ call : function            }....................
 FunctionType = _FunctionType
 '''
 Type of all **pure-Python functions** (i.e., functions implemented in Python
@@ -257,7 +306,7 @@ extensions, official stdlib C extensions, or the active Python interpreter
 itself).
 '''
 
-# ....................{ TYPES ~ call : method : bound     }....................
+# ....................{ TYPES ~ call : method : bound      }....................
 MethodBoundInstanceOrClassType = _MethodType
 '''
 Type of all **pure-Python bound instance and class methods** (i.e., methods
@@ -296,17 +345,17 @@ See Also
     Type of all C-based unbound dunder method wrapper descriptors.
 '''
 
-# ....................{ TYPES ~ call : method : unbound   }....................
+# ....................{ TYPES ~ call : method : unbound    }....................
 # Although Python >= 3.7 now exposes an explicit method wrapper type via the
 # standard "types.ClassMethodDescriptorType" object, this is of no benefit to
 # older versions of Python. Ergo, the type of an arbitrary method descriptor
 # guaranteed to *ALWAYS* exist is obtained instead.
 MethodUnboundClassCType: Any = type(dict.__dict__['fromkeys'])
 '''
-Type of all **C-based unbound class method descriptors** (i.e., callable
-objects implemented in low-level C, associated with class methods of
-builtin types when accessed with the low-level :attr:`object.__dict__`
-dictionary rather than as class or instance attributes).
+Type of all **C-based unbound class method descriptors** (i.e., callable objects
+implemented in low-level C, associated with class methods of builtin types when
+accessed with the low-level :attr:`object.__dict__` dictionary rather than as
+class or instance attributes).
 
 Despite being unbound, class method descriptors remain callable (e.g., by
 explicitly passing the intended ``cls`` objects as their first parameters).
@@ -354,7 +403,29 @@ See Also
     Type of all C-based unbound dunder method wrapper descriptors.
 '''
 
-# ....................{ TYPES ~ call : method : decorator }....................
+
+MethodUnboundPropertyNontrivialCExtensionType = _GetSetDescriptorType
+'''
+Type of all **C extension-specific unbound non-trivial property method
+descriptors** (i.e., uncallable objects implemented in low-level C extensions,
+associated with **non-trivial property methods** (i.e., wrapping underlying
+attributes that are *not* trivially convertible to C types) of C extensions when
+accessed with the low-level :attr:`object.__dict__` dictionary rather than as
+class or instance attributes).
+'''
+
+
+MethodUnboundPropertyTrivialCExtensionType = _MemberDescriptorType
+'''
+Type of all **C extension-specific unbound trivial property method descriptors**
+(i.e., uncallable objects implemented in low-level C extensions, associated with
+**trivial property methods** (i.e., wrapping underlying attributes that are
+trivially convertible to C types) of C extensions when accessed with the
+low-level :attr:`object.__dict__` dictionary rather than as class or instance
+attributes).
+'''
+
+# ....................{ TYPES ~ call : method : decorator  }....................
 MethodDecoratorClassType = classmethod
 '''
 Type of all **C-based unbound class method descriptors** (i.e., non-callable
@@ -365,9 +436,9 @@ class or instance attributes).
 
 Caveats
 ----------
-Class method objects are *only* accessible with the low-level
+Class method objects are *only* directly accessible via the low-level
 :attr:`object.__dict__` dictionary. When accessed as class or instance
-attributes, class methods are instances of the standard
+attributes, class methods reduce to instances of the standard
 :class:`MethodBoundInstanceOrClassType` type.
 
 Class method objects are *not* callable, as their implementations fail to
@@ -384,7 +455,7 @@ pure Python, and accessed as class rather than instance attributes).
 
 Caveats
 ----------
-Property objects are accessible both as class attributes *and* with the
+Property objects are directly accessible both as class attributes *and* via the
 low-level :attr:`object.__dict__` dictionary. Property objects are *not*
 accessible as instance attributes, for hopefully obvious reasons.
 
@@ -403,16 +474,16 @@ class or instance attributes).
 
 Caveats
 ----------
-Static method objects are *only* accessible with the low-level
+Static method objects are *only* directly accessible via the low-level
 :attr:`object.__dict__` dictionary. When accessed as class or instance
-attributes, static methods are instances of the standard :class:`FunctionType`
-type.
+attributes, static methods reduce to instances of the standard
+:class:`FunctionType` type.
 
 Static method objects are *not* callable, as their implementations fail to
 define the ``__call__`` dunder method.
 '''
 
-# ....................{ TYPES ~ call : return : async     }....................
+# ....................{ TYPES ~ call : return : async      }....................
 AsyncGeneratorCType = _AsyncGeneratorType
 '''
 C-based type returned by all **asynchronous pure-Python generators** (i.e.,
@@ -442,7 +513,7 @@ callables are simply callables subject to syntactic sugar, the type of these
 callables is simply :data:`CallableTypes`.
 '''
 
-# ....................{ TYPES ~ call : return : generator }....................
+# ....................{ TYPES ~ call : return : generator  }....................
 GeneratorType = _Generator
 '''
 Type of all **C- and Python-based generator objects** (i.e., iterators
@@ -490,7 +561,15 @@ implementing the :class:`collections.abc.Iterator` protocol, the former only
 applies to generators implicitly created by Python itself.
 '''
 
-# ....................{ TYPES ~ data                      }....................
+# ....................{ TYPES ~ class                      }....................
+ClassDictType = type(type.__dict__)
+'''
+Type of all **pure-Python class dictionaries** (i.e., immutable mappings
+officially referred to as "mapping proxies," whose keys are strictly constrained
+for both efficiency and correctness to be Python identifier strings).
+'''
+
+# ....................{ TYPES ~ data                       }....................
 ContainerType = _Container
 '''
 Type of all **containers** (i.e., concrete instances of the abstract
@@ -506,9 +585,8 @@ This type ambiguously matches both:
   :class:`collections.abc.Container` abstract base class (ABC)).
 * **Structural container subtypes** (i.e., arbitrary classes implementing the
   abstract ``__contains__`` method declared by that ABC *without* subclassing
-  that ABC), as formalized by `PEP 544 -- Protocols: Structural subtyping
-  (static duck typing) <PEP 544_>`_. Notably, since the **NumPy array type**
-  (i.e., :class:`numpy.ndarray`) defines that method, this type magically
+  that ABC), as formalized by :pep:`544`. Notably, since the **NumPy array
+  type** (i.e., :class:`numpy.ndarray`) defines that method, this type magically
   matches the NumPy array type as well.
 
 Of course, distinguishing between explicit and structural subtypes would
@@ -537,8 +615,6 @@ structural container subtypes as explicit container subtypes:
 
 .. _PEP 20:
    https://www.python.org/dev/peps/pep-0020
-.. _PEP 544:
-   https://www.python.org/dev/peps/pep-0544
 '''
 
 
@@ -652,7 +728,7 @@ See Also
     Further details on structural subtyping.
 '''
 
-# ....................{ TYPES ~ data : mapping            }....................
+# ....................{ TYPES ~ data : mapping             }....................
 HashableType = _Hashable
 '''
 Type of all **hashable objects** (i.e., both concrete and structural instances
@@ -679,7 +755,7 @@ Caveats
 **This type does not guarantee mutability** (i.e., the capacity to modify
 instances of this type after instantiation). This type ambiguously matches both
 mutable mapping types (e.g., :class:`dict`) and immutable mapping types (e.g.,
-:class:`mappingproxy`). Where mutability is required, prefer the non-ambiguous
+:class:`ClassDictType`). Where mutability is required, prefer the non-ambiguous
 :class:`MappingMutableType` type instead.
 
 See Also
@@ -704,7 +780,7 @@ See Also
     Type of all mutable and immutable mappings.
 '''
 
-# ....................{ TYPES ~ data : sequence           }....................
+# ....................{ TYPES ~ data : sequence            }....................
 SequenceType = _Sequence
 '''
 Type of all **mutable** and **immutable sequences** (i.e., both concrete and
@@ -787,7 +863,7 @@ See Also
     Further details on sequences.
 '''
 
-# ....................{ TYPES ~ enum                      }....................
+# ....................{ TYPES ~ enum                       }....................
 # Enumeration types are sufficiently obscure to warrant formalization here.
 
 EnumType = _EnumMeta
@@ -852,7 +928,7 @@ that enumeration's type and should be directly referenced as such: e.g.,
     ...     return str(superlative).lower()
 '''
 
-# ....................{ TYPES ~ hint                      }....................
+# ....................{ TYPES ~ hint                       }....................
 # Define this type as either...
 HintGenericSubscriptedType: Any = (
     # If the active Python interpreter targets at least Python >= 3.9 and thus
@@ -899,7 +975,7 @@ These include:
   detecting :pep:`585`-compliant generic type hints.
 '''
 
-# ....................{ TYPES ~ scalar                    }....................
+# ....................{ TYPES ~ scalar                     }....................
 StrType = str    # Well, isn't that special.
 '''
 Type of all **unencoded Unicode strings** (i.e., instances of the builtin
@@ -932,7 +1008,7 @@ objects satisfying the string protocol via structural subtyping -- because
 there is no string protocol. While Python's data model does define a
 ``__str__()`` dunder method called to implicitly convert arbitrary objects into
 strings, that method is called infrequently. As exhibited by the infamously
-rejected `PEP 3140`_ proposal, the :meth:`list.__str__` implementation
+rejected :pep:`3140` proposal, the :meth:`list.__str__` implementation
 stringifies list items by erroneously calling the unrelated ``__repr__()``
 method rather than the expected ``__str__()`` method on those items. Moreover,
 ``__str__()`` fails to cover common string operations such as string
@@ -943,12 +1019,9 @@ while trivial, that ABC would then ambiguously match all builtin sequence types
 (e.g., :class:`list`, :class:`tuple`) as string types, which they clearly are
 not. In short, matching only :class:`str` is the *only* unambiguous means of
 matching Unicode string types.
-
-.. _PEP 3140:
-   https://www.python.org/dev/peps/pep-3140
 '''
 
-# ....................{ TYPES ~ scalar : number           }....................
+# ....................{ TYPES ~ scalar : number            }....................
 NumberType = _numbers.Number
 '''
 Type of all **numbers** (i.e., concrete instances of the abstract
@@ -1047,40 +1120,34 @@ See Also
     Further details.
 '''
 
-# ....................{ TYPES ~ stdlib : re               }....................
+# ....................{ TYPES ~ stdlib : re                }....................
 # Regular expression types are also sufficiently obscure to warrant
 # formalization here.
 
-#FIXME: Once Python 3.6 support is dropped, this can be safely reduced to:
-#     RegexCompiledType = re.Pattern
-
 # Yes, this is the only reliable means of obtaining the type of compiled
 # regular expressions. For unknown reasons presumably concerning the archaic
 # nature of Python's regular expression support, this type is *NOT* publicly
 # exposed. While the private "re._pattern_type" attribute does technically
 # provide this type, it does so in a private and hence non-portable manner.
-RegexCompiledType: type = type(_re.compile(r''))
+RegexCompiledType: type = _re.Pattern
 '''
 Type of all **compiled regular expressions** (i.e., objects created and
 returned by the stdlib :func:`re.compile` function).
 '''
 
 
-#FIXME: Once Python 3.6 support is dropped, this can be safely reduced to:
-#     RegexMatchType = re.Match
-
 # Yes, this type is required for type validation at module scope elsewhere.
 # Yes, this is the most time-efficient means of obtaining this type. No, this
 # type is *NOT* directly importable. Although this type's classname is
 # published to be "_sre.SRE_Match", the "_sre" C extension provides no such
 # type for pure-Python importation. So it goes.
-RegexMatchType: type = type(_re.match(r'', ''))
+RegexMatchType: type = _re.Match
 '''
 Type of all **regular expression match objects** (i.e., objects returned by the
 :func:`re.match` function).
 '''
 
-# ....................{ TUPLES ~ unavailable              }....................
+# ....................{ TUPLES ~ unavailable               }....................
 # Unavailable types are defined *BEFORE* any subsequent types, as the latter
 # commonly leverage the former.
 
@@ -1102,7 +1169,7 @@ Specifically, for any callable parameter or return type annotated with:
 * The empty tuple, :func:`beartype.beartype` raises a fatal exception.
 '''
 
-# ....................{ TUPLES ~ py                       }....................
+# ....................{ TUPLES ~ py                        }....................
 ModuleOrStrTypes = (ModuleType, StrType)
 '''
 Tuple of both the module *and* string type.
@@ -1118,7 +1185,7 @@ Tuple of all **testable types** (i.e., types suitable for use as the second
 parameter passed to the :func:`isinstance` and :func:`issubclass` builtins).
 '''
 
-# ....................{ TUPLES ~ call                     }....................
+# ....................{ TUPLES ~ call                      }....................
 FunctionTypes = (FunctionType, FunctionOrMethodCType,)
 '''
 Tuple of all **function types** (i.e., types whose instances are either
@@ -1132,7 +1199,7 @@ is the set of all function types as well as the ambiguous type of all C-based
 functions and methods.
 '''
 
-# ....................{ TUPLES ~ call : method            }....................
+# ....................{ TUPLES ~ call : method             }....................
 MethodBoundTypes = (
     MethodBoundInstanceOrClassType, MethodBoundInstanceDunderCType)
 '''
@@ -1162,9 +1229,34 @@ MethodDecoratorBuiltinTypes = (
     MethodDecoratorStaticType,
 )
 '''
-Tuple of all **C-based unbound method decorator objects** (i.e., non-callable
-instances of a builtin decorator class implemented in low-level C, associated
-with methods implemented in pure Python)
+Tuple of all **C-based unbound method decorator types** (i.e., builtin decorator
+types implemented in low-level C whose instances are typically uncallable,
+associated with callable methods implemented in pure Python).
+'''
+
+
+MethodDescriptorTypes = (
+    # @classmethod, @staticmethod, and @property descriptor types.
+    MethodDecoratorBuiltinTypes + (
+        # Method descriptor type.
+        MethodBoundInstanceOrClassType,
+    )
+)
+'''
+Tuple of all **C-based unbound method descriptor types** (i.e., builtin types
+implemented in low-level C whose instances are typically uncallable, associated
+with callable methods implemented in pure Python).
+
+This tuple matches the types of all:
+
+* **Class method descriptors** (i.e., methods decorated by the builtin
+  :class:`classmethod` decorator).
+* Instance method descriptors (i.e., methods *not* decorated by a builtin method
+  decorator).
+* **Property method descriptors** (i.e., methods decorated by the builtin
+  :class:`property` decorator).
+* **Static method descriptors** (i.e., methods decorated by the builtin
+  :class:`staticmethod` decorator).
 '''
 
 
@@ -1185,7 +1277,7 @@ is the set of all pure-Python bound and unbound method types as well as the
 ambiguous type of all C-based bound methods and non-method functions.
 '''
 
-# ....................{ TUPLES ~ call : callable          }....................
+# ....................{ TUPLES ~ call : callable           }....................
 # For DRY, this tuple is defined as the set union of all function and method
 # types defined above converted back to a tuple.
 #
@@ -1245,7 +1337,7 @@ as decorators. Since most classes are *not* callable, however, this tuple may
 yield false positives when passed classes.
 '''
 
-# ....................{ TUPLES ~ call : return            }....................
+# ....................{ TUPLES ~ call : return             }....................
 AsyncCTypes = (AsyncGeneratorCType, AsyncCoroutineCType)
 '''
 Tuple of all C-based types returned by all **asynchronous callables** (i.e.,
@@ -1253,7 +1345,7 @@ callables implemented in pure Python whose declaration is preceded by the
 ``async`` keyword).
 '''
 
-# ....................{ TUPLES ~ scalar                   }....................
+# ....................{ TUPLES ~ scalar                    }....................
 BoolOrNumberTypes = (BoolType, NumberType,)
 '''
 Tuple of all **boolean** and **number types** (i.e., classes whose instances
@@ -1270,7 +1362,7 @@ Perl) typically implicitly convert:
 * ``True`` to ``1`` and vice versa.
 '''
 
-# ....................{ TUPLES ~ post-init : container    }....................
+# ....................{ TUPLES ~ post-init : container     }....................
 # Tuples of types assuming the above initialization to have been performed.
 
 MappingOrSequenceTypes = (MappingType, SequenceType)
@@ -1304,7 +1396,7 @@ Tuple of all numeric types *and* all container base classes conforming to (but
 API.
 '''
 
-# ....................{ TUPLES ~ post-init : scalar       }....................
+# ....................{ TUPLES ~ post-init : scalar        }....................
 ScalarTypes = BoolOrNumberTypes + (StrType,)
 '''
 Tuple of all **scalar types** (i.e., classes whose instances are atomic scalar
@@ -1317,7 +1409,7 @@ This tuple matches all:
 * **Textual types** (i.e., types contained in the :class:`StrTypes` tuple).
 '''
 
-# ....................{ TUPLES ~ stdlib                   }....................
+# ....................{ TUPLES ~ stdlib                    }....................
 RegexTypes = (RegexCompiledType, StrType)
 '''
 Tuple of all **regular expression-like types** (i.e., types either defining
