@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -10,26 +10,54 @@ well-known types).
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
+#FIXME: Export these types from "beartype.cave", please.
 from beartype._cave._cavefast import (
+    AsyncCoroutineCType,
+    AsyncGeneratorCType,
+    CallableCodeObjectType,
+    CallableFrameType,
+    ClassDictType,
+    ClassType,
+    ClosureVarCellType,
     EllipsisType,
+    ExceptionTracebackType,
     FunctionType,
     FunctionOrMethodCType,
+    GeneratorCType,
+    MethodBoundInstanceDunderCType,
     MethodBoundInstanceOrClassType,
+    MethodDecoratorBuiltinTypes,
+    MethodUnboundClassCType,
+    MethodUnboundInstanceDunderCType,
+    MethodUnboundInstanceNondunderCType,
+    MethodUnboundPropertyNontrivialCExtensionType,
+    MethodUnboundPropertyTrivialCExtensionType,
     ModuleType,
     NoneType,
     NotImplementedType,
 )
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ SETS                              }....................
+# ....................{ SETS                               }....................
 TYPES_BUILTIN_FAKE = frozenset((
+    AsyncCoroutineCType,
+    AsyncGeneratorCType,
+    CallableCodeObjectType,
+    CallableFrameType,
+    ClassDictType,
+    ClosureVarCellType,
     EllipsisType,
+    ExceptionTracebackType,
     FunctionType,
     FunctionOrMethodCType,
+    GeneratorCType,
+    MethodBoundInstanceDunderCType,
     MethodBoundInstanceOrClassType,
+    MethodUnboundClassCType,
+    MethodUnboundInstanceDunderCType,
+    MethodUnboundInstanceNondunderCType,
+    MethodUnboundPropertyNontrivialCExtensionType,
+    MethodUnboundPropertyTrivialCExtensionType,
     ModuleType,
     NoneType,
     NotImplementedType,
@@ -66,18 +94,21 @@ See Also
     as an essential sanity check on that runtime-specific set.
 '''
 
-# ....................{ TUPLES                            }....................
-TYPES_BUILTIN_DECORATOR_DESCRIPTOR_FACTORY = (
-    property,
-    classmethod,
-    staticmethod,
+# ....................{ TUPLES                             }....................
+# Types of *ALL* objects that may be decorated by @beartype, intentionally
+# listed in descending order of real-world prevalence for negligible efficiency
+# gains when performing isinstance()-based tests against this tuple. These
+# include the types of *ALL*...
+TYPES_BEARTYPEABLE = (
+    # Pure-Python unbound functions and methods.
+    FunctionType,
+    # Pure-Python classes.
+    ClassType,
+    # C-based builtin method descriptors wrapping pure-Python unbound methods,
+    # including class methods, static methods, and property methods.
+    MethodDecoratorBuiltinTypes,
 )
 '''
-Tuple of all **builtin descriptor factory decorators** (i.e., builtin types
-which, when invoked as decorators on callables, wrap those callables in
-uncallable descriptors).
-
-These decorators are intentionally contained in a tuple rather than frozen set,
-enabling descriptors created by these decorators to be efficiently detected via
-the :func:`isinstance` builtin.
+Tuple set of all **beartypeable types** (i.e., types of all objects that may be
+decorated by the :func:`beartype.beartype` decorator).
 '''
