@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -11,7 +11,12 @@ builtin suffixed by *no* "["- and "]"-delimited subscription representations).
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
+from beartype.typing import (
+    Dict,
+    FrozenSet,
+    Set,
+)
 from beartype._data.hint.pep.sign import datapepsigns
 from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._data.hint.pep.sign.datapepsigns import (
@@ -61,7 +66,7 @@ from beartype._data.hint.pep.sign.datapepsigns import (
     HintSignNumpyArray,
     # HintSignOptional,
     HintSignOrderedDict,
-    # HintSignParamSpec,
+    HintSignParamSpec,
     # HintSignParamSpecArgs,
     # HintSignProtocol,
     HintSignReversible,
@@ -79,22 +84,34 @@ from beartype._data.hint.pep.sign.datapepsigns import (
 from beartype._util.py.utilpyversion import (
     IS_PYTHON_AT_LEAST_3_9,
     IS_PYTHON_AT_MOST_3_8,
-    IS_PYTHON_AT_LEAST_3_7,
-    IS_PYTHON_3_6,
 )
-from typing import Dict, FrozenSet, Set
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ MAPPINGS ~ repr                   }....................
-# The majority of this dictionary is initialized with automated inspection
-# below in the _init() function. The *ONLY* key-value pairs explicitly defined
-# here are those *NOT* amenable to such inspection.
+# ....................{ MAPPINGS ~ repr                    }....................
+# The majority of this dictionary is initialized with automated inspection below
+# in the _init() function. The *ONLY* key-value pairs explicitly defined here
+# are those *NOT* amenable to such inspection.
 HINT_REPR_PREFIX_ARGS_0_OR_MORE_TO_SIGN: Dict[str, HintSign] = {
-    # ..................{ PEP 484                           }..................
+    # ..................{ PEP 484                            }..................
     # All other PEP 484-compliant representation prefixes are defined by
     # automated inspection below.
+
+    # PEP 484-compliant "None" singleton, which transparently reduces to
+    # "types.NoneType". While not explicitly defined by the "typing" module,
+    # PEP 484 explicitly supports this singleton:
+    #     When used in a type hint, the expression None is considered equivalent
+    #     to type(None).
+    #
+    # Note that the representation of the type of the "None" singleton (i.e.,
+    # "<class 'NoneType'>") is intentionally omitted here despite the "None"
+    # singleton reducing to that type. Indeed, the *ONLY* reason we detect this
+    # singleton at all is to enable that reduction. Although this singleton
+    # conveys a PEP-compliant semantic, the type of this singleton explicitly
+    # conveys *NO* PEP-compliant semantics. That type is simply a standard
+    # isinstanceable type (like any other). Indeed, attempting to erroneously
+    # associate the type of the "None" singleton with the same sign here would
+    # cause that type to be detected as conveying sign-specific PEP-compliant
+    # semantics rather than *NO* such semantics, which would then substantially
+    # break and complicate dynamic code generation for no benefit whatsoever.
     'None': HintSignNone,
 }
 '''
@@ -119,15 +136,15 @@ Notably, this dictionary maps from the representation prefixes of:
 
 # The majority of this dictionary is defined by explicit key-value pairs here.
 HINT_REPR_PREFIX_ARGS_1_OR_MORE_TO_SIGN: Dict[str, HintSign] = {
-    # ..................{ PEP 585                           }..................
+    # ..................{ PEP 585                            }..................
     # PEP 585-compliant type hints *MUST* by definition be subscripted (e.g.,
     # "list[str]" rather than "list"). While the stdlib types underlying those
     # hints are isinstanceable classes and thus also permissible as type hints
     # when unsubscripted (e.g., simply "list"), unsubscripted classes convey no
     # deep semantics and thus need *NOT* be detected as PEP-compliant.
     #
-    # For maintainability, these key-value pairs are intentionally listed in
-    # the same order as the official list in PEP 585 itself.
+    # For maintainability, these key-value pairs are intentionally listed in the
+    # same order as the official list in PEP 585 itself.
     'tuple': HintSignTuple,
     'list': HintSignList,
     'dict': HintSignDict,
@@ -167,7 +184,7 @@ HINT_REPR_PREFIX_ARGS_1_OR_MORE_TO_SIGN: Dict[str, HintSign] = {
     're.Pattern': HintSignPattern,
     're.Match': HintSignMatch,
 
-    # ..................{ NON-PEP ~ lib : numpy             }..................
+    # ..................{ NON-PEP ~ lib : numpy              }..................
     # The PEP-noncompliant "numpy.typing.NDArray" type hint is permissible in
     # both subscripted and unsubscripted forms. In the latter case, this hint
     # is implicitly subscripted by generic type variables. In both cases, this
@@ -202,12 +219,12 @@ Notably, this dictionary maps from the representation prefixes of:
   detected as PEP-compliant.
 '''
 
-# ....................{ MAPPINGS ~ type                   }....................
+# ....................{ MAPPINGS ~ type                    }....................
 # The majority of this dictionary is initialized with automated inspection
 # below in the _init() function. The *ONLY* key-value pairs explicitly defined
 # here are those *NOT* amenable to such inspection.
 HINT_TYPE_NAME_TO_SIGN: Dict[str, HintSign] = {
-    # ..................{ PEP 484                           }..................
+    # ..................{ PEP 484                            }..................
     # PEP 484-compliant forward reference type hints may be annotated either:
     # * Explicitly as "typing.ForwardRef" instances, which automated inspection
     #   performed by the _init() function below already handles.
@@ -223,19 +240,20 @@ HINT_TYPE_NAME_TO_SIGN: Dict[str, HintSign] = {
     #   codebase, we (currently) opt to do so.
     'builtins.str': HintSignForwardRef,
 
-    # Python >= 3.10 implements PEP 484-compliant "typing.NewType" type hints
-    # as instances of that class. Regardless of the current Python version,
+    # Python >= 3.10 implements PEP 484-compliant "typing.NewType" type hints as
+    # instances of that class. Regardless of the current Python version,
     # "typing_extensions.NewType" type hints remain implemented in manner of
     # Python < 3.10 -- which is to say, as closures of that function. Ergo, we
     # intentionally omit "typing_extensions.NewType" here. See also:
     #     https://github.com/python/typing/blob/master/typing_extensions/src_py3/typing_extensions.py
     'typing.NewType': HintSignNewType,
 
+    # ..................{ PEP 557                            }..................
     # Python >= 3.8 implements PEP 557-compliant "dataclasses.InitVar" type
     # hints as instances of that class.
     'dataclasses.InitVar': HintSignDataclassInitVar,
 
-    # ..................{ PEP 604                           }..................
+    # ..................{ PEP 604                            }..................
     # PEP 604-compliant |-style unions (e.g., "int | float") are internally
     # implemented as instances of the low-level C-based "types.UnionType" type.
     # Thankfully, these unions are semantically interchangeable with comparable
@@ -243,6 +261,11 @@ HINT_TYPE_NAME_TO_SIGN: Dict[str, HintSign] = {
     # expose equivalent dunder attributes (e.g., "__args__", "__parameters__"),
     # enabling subsequent code generation to conflate the two without issue.
     'types.UnionType': HintSignUnion,
+
+    # ..................{ PEP 612                            }..................
+    # Python >= 3.10 implements PEP 612-compliant "typing.ParamSpec" type hints
+    # as instances of that class.
+    'typing.ParamSpec': HintSignParamSpec,
 }
 '''
 Dictionary mapping from the fully-qualified classnames of all PEP-compliant
@@ -250,7 +273,7 @@ type hints uniquely identifiable by those classnames to their identifying
 signs.
 '''
 
-# ....................{ SETS ~ deprecated                 }....................
+# ....................{ SETS ~ deprecated                  }....................
 # Initialized with automated inspection below in the _init() function.
 HINTS_PEP484_REPR_PREFIX_DEPRECATED: FrozenSet[str] = set()  # type: ignore[assignment]
 '''
@@ -261,67 +284,40 @@ for all :pep:`484`-compliant type hints obsoleted by :pep:`585`-compliant
 subscriptable classes).
 '''
 
-# ....................{ SETS ~ ignorable                  }....................
+# ....................{ SETS ~ ignorable                   }....................
 # The majority of this dictionary is initialized with automated inspection
 # below in the _init() function. The *ONLY* key-value pairs explicitly defined
 # here are those *NOT* amenable to such inspection.
 HINTS_REPR_IGNORABLE_SHALLOW: FrozenSet[str] = {  # type: ignore[assignment]
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # CAUTION: Synchronize changes to this set with the corresponding
     # testing-specific set
     # "beartype_test.a00_unit.data.hint.pep.data_pep.HINTS_PEP_IGNORABLE_SHALLOW".
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-    # ..................{ NON-PEP                           }..................
+    # ..................{ NON-PEP                            }..................
     # The PEP-noncompliant builtin "object" type is the transitive superclass
-    # of all classes, parameters and return values annotated as "object"
+    # of all classes. Ergo, parameters and return values annotated as "object"
     # unconditionally match *ALL* objects under isinstance()-based type
     # covariance and thus semantically reduce to unannotated parameters and
     # return values. This is literally the "beartype.cave.AnyType" type.
     "<class 'object'>",
 
-    # ..................{ PEP 484                           }..................
-    # The "Generic" superclass imposes no constraints and is thus also
-    # semantically synonymous with the ignorable PEP-noncompliant
-    # "beartype.cave.AnyType" and hence "object" types. Since PEP
-    # 484 stipulates that *ANY* unsubscripted subscriptable PEP-compliant
-    #     singleton including "typing.Generic" semantically expands to that
-    #     singelton subscripted by an implicit "Any" argument, "Generic"
-    #     semantically expands to the implicit "Generic[Any]" singleton.
-    "<class 'typing.Generic'>",
-    "<class 'typing_extensions.Generic'>",
-
-    # ..................{ PEP 544                           }..................
-    # Note that ignoring the "typing.Protocol" superclass is vital here. For
-    # unknown and presumably uninteresting reasons, *ALL* possible objects
-    # satisfy this superclass. Ergo, this superclass is synonymous with the
-    # "object" root superclass: e.g.,
-    #     >>> import typing as t
-    #     >>> isinstance(object(), t.Protocol)
-    #     True
-    #     >>> isinstance('wtfbro', t.Protocol)
-    #     True
-    #     >>> isinstance(0x696969, t.Protocol)
-    #     True
-    "<class 'beartype.typing.Protocol'>",
-    "<class 'typing.Protocol'>",
-    "<class 'typing_extensions.Protocol'>",
-
-    # ..................{ PEP 604                           }..................
-    # The low-level C-based "types.UnionType" class underlying PEP
-    # 604-compliant |-style unions (e.g., "int | float") imposes no constraints
-    # and is thus also semantically synonymous with the ignorable
-    # PEP-noncompliant "beartype.cave.AnyType" and hence "object" types.
-    # Nonetheless, this class *CANNOT* be instantiated from Python code:
+    # ..................{ PEP 604                            }..................
+    # The low-level C-based "types.UnionType" class underlying PEP 604-compliant
+    # |-style unions (e.g., "int | float") imposes no constraints and is thus
+    # also semantically synonymous with the ignorable PEP-noncompliant
+    # "beartype.cave.AnyType" and hence "object" types. Nonetheless, this class
+    # *CANNOT* be instantiated from Python code:
     #     >>> import types
     #     >>> types.UnionType(int, bool)
     #     TypeError: cannot create 'types.UnionType' instances
     #
-    # Likewise, this class *CANNOT* be subscripted. It follows that there
-    # exists no meaningful equivalent of shallow type-checking for these
-    # unions. While trivially feasible, listing "<class 'types.UnionType'>"
-    # here would only prevent callers from meaningfully type-checking these
-    # unions passed as valid parameters or returned as valid returns: e.g.,
+    # Likewise, this class *CANNOT* be subscripted. It follows that there exists
+    # no meaningful equivalent of shallow type-checking for these unions. While
+    # trivially feasible, listing "<class 'types.UnionType'>" here would only
+    # prevent callers from meaningfully type-checking these unions passed as
+    # valid parameters or returned as valid returns: e.g.,
     #     @beartype
     #     def muh_union_printer(muh_union: UnionType) -> None: print(muh_union)
     #
@@ -345,26 +341,26 @@ necessarily constrained to the substantially smaller finite subset of only
 shallowly ignorable type hints.
 '''
 
-# ....................{ INITIALIZERS                      }....................
+# ....................{ INITIALIZERS                       }....................
 def _init() -> None:
     '''
     Initialize this submodule.
     '''
 
-    # ..................{ EXTERNALS                         }..................
+    # ..................{ EXTERNALS                          }..................
     # Defer initialization-specific imports.
-    from beartype._data.mod.datamod import TYPING_MODULE_NAMES
+    from beartype._data.mod.datamodtyping import TYPING_MODULE_NAMES
 
     # Permit redefinition of these globals below.
     global \
         HINTS_PEP484_REPR_PREFIX_DEPRECATED, \
         HINTS_REPR_IGNORABLE_SHALLOW
 
-    # ..................{ HINTS                             }..................
+    # ..................{ HINTS                              }..................
     # Length of the ignorable substring prefixing the name of each sign.
     _HINT_SIGN_PREFIX_LEN = len('HintSign')
 
-    # ..................{ HINTS ~ repr                      }..................
+    # ..................{ HINTS ~ repr                       }..................
     # Dictionary mapping from the unqualified names of typing attributes whose
     # names are erroneously desynchronized from their bare machine-readable
     # representations to the actual representations of those attributes.
@@ -390,23 +386,21 @@ def _init() -> None:
     #   otherwise insane Python 3.6.x series having actually gotten this right.
     # * Python 3.8.x preserved this bad behaviour.
     # * Python 3.9.0 rectified this issue finally. *sigh*
-    if IS_PYTHON_AT_LEAST_3_7 and IS_PYTHON_AT_MOST_3_8:
+    if IS_PYTHON_AT_MOST_3_8:
         _HINT_TYPING_ATTR_NAME_TO_REPR_PREFIX.update({
             'AsyncContextManager': 'AbstractAsyncContextManager',
             'ContextManager': 'AbstractContextManager',
         })
 
-    # ..................{ HINTS ~ types                     }..................
+    # ..................{ HINTS ~ types                      }..................
     # Dictionary mapping from the unqualified names of all classes defined by
     # typing modules used to instantiate PEP-compliant type hints to their
     # corresponding signs.
     _HINT_TYPE_BASENAMES_TO_SIGN = {
-        # ................{ PEP 484                           }................
+        # ................{ PEP 484                            }................
         # All PEP 484-compliant forward references are necessarily instances of
-        # the same class. Unfortunately, this class was only publicized under
-        # Python >= 3.7 after its initial privatization under Python <= 3.6.
-        ('ForwardRef' if IS_PYTHON_AT_LEAST_3_7 else '_ForwardRef'): (
-            HintSignForwardRef),
+        # the same class.
+        'ForwardRef' : HintSignForwardRef,
 
         # All PEP 484-compliant type variables are necessarily instances of the
         # same class.
@@ -419,7 +413,7 @@ def _init() -> None:
         # 'Generic': HintSignGeneric,
     }
 
-    # ..................{ HINTS ~ deprecated                }..................
+    # ..................{ HINTS ~ deprecated                 }..................
     # Set of the unqualified names of all deprecated PEP 484-compliant typing
     # attributes.
     _HINT_PEP484_TYPING_ATTR_NAMES_DEPRECATED: Set[str] = set()
@@ -430,7 +424,7 @@ def _init() -> None:
     # equivalent bare PEP 585-compliant builtin classes (e.g., "list").
     if IS_PYTHON_AT_LEAST_3_9:
         _HINT_PEP484_TYPING_ATTR_NAMES_DEPRECATED.update((
-            # ..............{ PEP 484                           }..............
+            # ..............{ PEP 484                            }..............
             'AbstractSet',
             'AsyncContextManager',
             'AsyncGenerator',
@@ -473,11 +467,13 @@ def _init() -> None:
             'ValuesView',
         ))
 
-    # ..................{ HINTS ~ ignorable                 }..................
-    # Set of the unqualified names of all shallowly ignorable typing
-    # attributes.
+    # ..................{ HINTS ~ ignorable                  }..................
+    # Set of the unqualified names of all shallowly ignorable typing non-class
+    # attributes. Since classes and non-class attributes have incommensurate
+    # machine-readable representations, these two types of attributes *MUST* be
+    # isolated to distinct sets. See "_HINT_TYPING_CLASSNAMES_IGNORABLE" below.
     _HINT_TYPING_ATTR_NAMES_IGNORABLE = {
-        # ................{ PEP 484                           }................
+        # ................{ PEP 484                            }................
         # The "Any" singleton is semantically synonymous with the ignorable
         # PEP-noncompliant "beartype.cave.AnyType" and hence "object" types.
         'Any',
@@ -524,27 +520,34 @@ def _init() -> None:
         'Union',
     }
 
-    # If the active Python interpreter targets Python 3.6...
-    #
-    # Gods... these are horrible. Thanks for nuthin', Python 3.6.
-    if IS_PYTHON_3_6:
-        # Map from the idiosyncratic machine-readable bare representations of
-        # the "typing.Match" and "typing.Pattern" objects, which unlike all
-        # other "typing"-based type hints are *NOT* prefixed by "typing"
-        # (e.g., "Pattern[~AnyStr]" rather than "typing.Pattern").
-        HINT_REPR_PREFIX_ARGS_0_OR_MORE_TO_SIGN.update({
-            'Match': HintSignMatch,
-            'Pattern': HintSignPattern,
-        })
+    # Set of the unqualified names of all shallowly ignorable typing classes.
+    _HINT_TYPING_CLASSNAMES_IGNORABLE = {
+        # The "Generic" superclass imposes no constraints and is thus also
+        # semantically synonymous with the ignorable PEP-noncompliant
+        # "beartype.cave.AnyType" and hence "object" types. Since PEP
+        # 484 stipulates that *ANY* unsubscripted subscriptable PEP-compliant
+        # singleton including "typing.Generic" semantically expands to that
+        # singleton subscripted by an implicit "Any" argument, "Generic"
+        # semantically expands to the implicit "Generic[Any]" singleton.
+        'Generic',
 
-        # Shallowly ignore the unsubscripted "Generic" superclass whose
-        # idiosyncratic representation under Python 3.6 is "typing.Generic"
-        # rather than "<class 'Generic'>"". Note that logic above already
-        # handles the latter case.
-        _HINT_TYPING_ATTR_NAMES_IGNORABLE.add('Generic')
+        # ................{ PEP 544                            }................
+        # Note that ignoring the "typing.Protocol" superclass is vital here. For
+        # unknown and presumably uninteresting reasons, *ALL* possible objects
+        # satisfy this superclass. Ergo, this superclass is synonymous with the
+        # "object" root superclass: e.g.,
+        #     >>> import typing as t
+        #     >>> isinstance(object(), t.Protocol)
+        #     True
+        #     >>> isinstance('wtfbro', t.Protocol)
+        #     True
+        #     >>> isinstance(0x696969, t.Protocol)
+        #     True
+        'Protocol',
+    }
 
-    # ..................{ CONSTRUCTION                      }..................
-    # For the name of each top-level type hinting module...
+    # ..................{ CONSTRUCTION                       }..................
+    # For the fully-qualified name of each quasi-standard typing module...
     for typing_module_name in TYPING_MODULE_NAMES:
         # For the name of each sign...
         #
@@ -596,13 +599,20 @@ def _init() -> None:
             HINT_TYPE_NAME_TO_SIGN[
                 f'{typing_module_name}.{typing_attr_name}'] = hint_sign
 
-        # For each shallowly ignorable typing attribute name...
+        # For each shallowly ignorable typing non-class attribute name...
         for typing_attr_name in _HINT_TYPING_ATTR_NAMES_IGNORABLE:
             # Add that attribute relative to this module to this set.
-            # print(f'[datapeprepr] Registering ignorable "{typing_module_name}.{typing_attr_name}"...')
+            # print(f'[datapeprepr] Registering ignorable non-class "{typing_module_name}.{typing_attr_name}"...')
             HINTS_REPR_IGNORABLE_SHALLOW.add(  # type: ignore[attr-defined]
                 f'{typing_module_name}.{typing_attr_name}')
 
+        # For each shallowly ignorable typing classname...
+        for typing_classname in _HINT_TYPING_CLASSNAMES_IGNORABLE:
+            # Add that classname relative to this module to this set.
+            # print(f'[datapeprepr] Registering ignorable class "{typing_module_name}.{typing_attr_name}"...')
+            HINTS_REPR_IGNORABLE_SHALLOW.add(  # type: ignore[attr-defined]
+                f"<class '{typing_module_name}.{typing_classname}'>")
+
         # For each deprecated PEP 484-compliant typing attribute name...
         for typing_attr_name in _HINT_PEP484_TYPING_ATTR_NAMES_DEPRECATED:
             # Add that attribute relative to this module to this set.
@@ -610,13 +620,13 @@ def _init() -> None:
             HINTS_PEP484_REPR_PREFIX_DEPRECATED.add(  # type: ignore[attr-defined]
                 f'{typing_module_name}.{typing_attr_name}')
 
-    # ..................{ SYNTHESIS                         }..................
+    # ..................{ SYNTHESIS                          }..................
     # Freeze all relevant global sets for safety.
     HINTS_PEP484_REPR_PREFIX_DEPRECATED = frozenset(
         HINTS_PEP484_REPR_PREFIX_DEPRECATED)
     HINTS_REPR_IGNORABLE_SHALLOW = frozenset(HINTS_REPR_IGNORABLE_SHALLOW)
 
-    # ..................{ DEBUGGING                         }..................
+    # ..................{ DEBUGGING                          }..................
     # Uncomment as needed to display the contents of these objects.
 
     # from pprint import pformat
