@@ -1,19 +1,20 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
-**Beartype PEP-compliant type hint call-time utilities** (i.e., callables
-operating on PEP-compliant type hints intended to be called by dynamically
-generated wrapper functions wrapping decorated callables).
+**Beartype class type hint violation describers** (i.e., functions returning
+human-readable strings explaining violations of type hints that are standard
+isinstanceable classes rather than PEP-specific objects).
 
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from beartype.roar import BeartypeCallHintForwardRefException
 from beartype.roar._roarexc import _BeartypeCallHintPepRaiseException
+from beartype.typing import Optional
 from beartype._cave._cavefast import TestableTypes
 from beartype._data.hint.pep.sign.datapepsigns import (
     HintSignForwardRef,
@@ -32,16 +33,13 @@ from beartype._util.hint.pep.proposal.pep484585.utilpep484585ref import (
 from beartype._util.hint.pep.proposal.pep484585.utilpep484585type import (
     get_hint_pep484585_subclass_superclass)
 from beartype._util.hint.pep.utilpepget import (
-    get_hint_pep_type_isinstanceable_or_none)
+    get_hint_pep_origin_type_isinstanceable_or_none)
+from beartype._util.text.utiltextcolour import truth_colour
 from beartype._util.text.utiltextjoin import join_delimited_disjunction_types
 from beartype._util.text.utiltextlabel import label_type
-from beartype._util.text.utiltextrepr import represent_object
-from typing import Optional
+from beartype._decor._error._errortext import represent_pith
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ GETTERS ~ instance : type         }....................
+# ....................{ GETTERS ~ instance : type          }....................
 def get_cause_or_none_instance_type(sleuth: CauseSleuth) -> Optional[str]:
     '''
     Human-readable string describing the failure of the passed arbitrary object
@@ -72,8 +70,8 @@ def get_cause_or_none_instance_type(sleuth: CauseSleuth) -> Optional[str]:
     # Return a substring describing this failure intended to be embedded in a
     # longer string.
     return (
-        f'{represent_object(sleuth.pith)} not instance of '
-        f'{label_type(sleuth.hint)}'
+        f'{represent_pith(sleuth.pith)} not instance of '
+        f'{truth_colour(label_type(sleuth.hint))}'
     )
 
 
@@ -126,11 +124,11 @@ def get_cause_or_none_type_instance_origin(
 
     # Isinstanceable origin type originating this hint if any *OR* "None"
     # otherwise.
-    hint_type_origin_isinstanceable = (
-        get_hint_pep_type_isinstanceable_or_none(sleuth.hint))
+    hint_origin_type_isinstanceable = (
+        get_hint_pep_origin_type_isinstanceable_or_none(sleuth.hint))
 
     # If this hint does *NOT* originate from such a type, raise an exception.
-    if hint_type_origin_isinstanceable is None:
+    if hint_origin_type_isinstanceable is None:
         raise _BeartypeCallHintPepRaiseException(
             f'{sleuth.exception_prefix}type hint '
             f'{repr(sleuth.hint)} not originated from '
@@ -140,9 +138,9 @@ def get_cause_or_none_type_instance_origin(
 
     # Defer to the getter function handling non-"typing" classes. Presto!
     return get_cause_or_none_instance_type(
-        sleuth.permute(hint=hint_type_origin_isinstanceable))
+        sleuth.permute(hint=hint_origin_type_isinstanceable))
 
-# ....................{ GETTERS ~ instance : types        }....................
+# ....................{ GETTERS ~ instance : types         }....................
 def get_cause_or_none_instance_types_tuple(
     sleuth: CauseSleuth) -> Optional[str]:
     '''
@@ -175,11 +173,11 @@ def get_cause_or_none_instance_types_tuple(
     # Return a substring describing this failure intended to be embedded in a
     # longer string.
     return (
-        f'{represent_object(sleuth.pith)} not instance of '
-        f'{join_delimited_disjunction_types(sleuth.hint)}'
+        f'{represent_pith(sleuth.pith)} not instance of '
+        f'{truth_colour(join_delimited_disjunction_types(sleuth.hint))}'
     )
 
-# ....................{ GETTERS ~ subclass : type         }....................
+# ....................{ GETTERS ~ subclass : type          }....................
 def get_cause_or_none_subclass_type(sleuth: CauseSleuth) -> Optional[str]:
     '''
     Human-readable string describing the failure of the passed arbitrary object
@@ -208,7 +206,7 @@ def get_cause_or_none_subclass_type(sleuth: CauseSleuth) -> Optional[str]:
         # Reduce this superclass to the class referred to by this forward
         # reference.
         hint_superclass = import_pep484585_forwardref_type_relative_to_object(
-            hint=hint_superclass,
+            hint=hint_superclass,  # type: ignore[arg-type]
             obj=sleuth.func,
             exception_cls=BeartypeCallHintForwardRefException,
             exception_prefix=sleuth.exception_prefix,
@@ -240,6 +238,6 @@ def get_cause_or_none_subclass_type(sleuth: CauseSleuth) -> Optional[str]:
 
     # Return a substring describing this failure.
     return (
-        f'{represent_object(sleuth.pith)} not subclass of '
+        f'{represent_pith(sleuth.pith)} not subclass of '
         f'{hint_superclass_label}'
     )
