@@ -1,43 +1,38 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
-Project-wide :pep:`593`-compliant :class:`typing.Annotated` **type hint
-exception raisers** (i.e., functions raising human-readable exceptions called
-by :mod:`beartype`-decorated callables on the first invalid parameter or return
-value failing a type-check against the :pep:`593`-compliant
-:class:`typing.Annotated` type hint annotating that parameter or return).
+**Beartype** :pep:`593`-compliant **type hint violation describers** (i.e.,
+functions returning human-readable strings explaining violations of
+:pep:`593`-compliant :attr:`typing.Annotated` type hints).
 
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from beartype.roar._roarexc import _BeartypeCallHintPepRaiseException
+from beartype.typing import Optional
 from beartype._data.hint.pep.sign.datapepsigns import HintSignAnnotated
 from beartype._decor._error._errorsleuth import CauseSleuth
+from beartype._decor._error._errortext import represent_pith
 from beartype._util.hint.pep.proposal.utilpep593 import (
     get_hint_pep593_metadata,
     get_hint_pep593_metahint,
 )
 from beartype._util.text.utiltextmagic import CODE_INDENT_1
-from beartype._util.text.utiltextrepr import represent_object
-from typing import Optional
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ GETTERS                           }....................
+# ....................{ GETTERS                            }....................
 def get_cause_or_none_annotated(sleuth: CauseSleuth) -> Optional[str]:
     '''
     Human-readable string describing the failure of the passed arbitrary object
     to satisfy the passed :pep:`593`-compliant :mod:`beartype`-specific
     **metahint** (i.e., type hint annotating a standard class with one or more
-    :class:`beartype.vale._core._valecore.BeartypeValidator` objects, each produced
-    by subscripting the :class:`beartype.vale.Is` class or a subclass of that
-    class) if this object actually fails to satisfy this hint *or* ``None``
-    otherwise (i.e., if this object satisfies this hint).
+    :class:`beartype.vale._core._valecore.BeartypeValidator` objects, each
+    produced by subscripting the :class:`beartype.vale.Is` class or a subclass
+    of that class) if this object actually fails to satisfy this hint *or*
+    ``None`` otherwise (i.e., if this object satisfies this hint).
 
     Parameters
     ----------
@@ -92,8 +87,8 @@ def get_cause_or_none_annotated(sleuth: CauseSleuth) -> Optional[str]:
 
             # Return a human-readable string describing this failure.
             return (
-                f'{represent_object(sleuth.pith)} violates '
-                f'validator {repr(hint_validator)}:\n'
+                f'{represent_pith(sleuth.pith)} violates validator '
+                f'{repr(hint_validator)}:\n'
                 f'{hint_diagnosis}'
             )
         # Else, this pith satisfies this validator. Ergo, this validator is
