@@ -1,36 +1,34 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
-Project-wide :pep:`484`-compliant **union type hint exception raisers** (i.e.,
-functions raising human-readable exceptions called by :mod:`beartype`-decorated
-callables on the first invalid parameter or return value failing a type-check
-against the :pep:`484`-compliant union type hint annotating that parameter or
-return).
+**Beartype** :pep:`484`-compliant **union type hint violation describers**
+(i.e., functions returning human-readable strings explaining violations of
+:pep:`484`-compliant union type hints).
 
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from beartype.roar._roarexc import _BeartypeCallHintPepRaiseException
-from beartype._decor._error._errorsleuth import CauseSleuth
+from beartype.typing import Optional
 from beartype._data.hint.pep.sign.datapepsignset import HINT_SIGNS_UNION
+from beartype._decor._error._errorsleuth import CauseSleuth
+from beartype._decor._error._errortext import represent_pith
 from beartype._util.hint.pep.utilpepget import (
-    get_hint_pep_type_isinstanceable_or_none)
+    get_hint_pep_origin_type_isinstanceable_or_none)
 from beartype._util.hint.pep.utilpeptest import is_hint_pep
 from beartype._util.hint.utilhinttest import is_hint_ignorable
+from beartype._util.text.utiltextcolour import truth_colour
 from beartype._util.text.utiltextjoin import join_delimited_disjunction_types
 from beartype._util.text.utiltextmunge import (
-    suffix_unless_suffixed, uppercase_char_first)
-from beartype._util.text.utiltextrepr import represent_object
-from typing import Optional
+    suffix_unless_suffixed,
+    uppercase_char_first,
+)
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ GETTERS                           }....................
+# ....................{ GETTERS                            }....................
 def get_cause_or_none_union(sleuth: CauseSleuth) -> Optional[str]:
     '''
     Human-readable string describing the failure of the passed arbitrary object
@@ -73,20 +71,20 @@ def get_cause_or_none_union(sleuth: CauseSleuth) -> Optional[str]:
         if is_hint_pep(hint_child):
             # Non-"typing" class originating this child hint if any *OR* "None"
             # otherwise.
-            hint_child_type_origin = get_hint_pep_type_isinstanceable_or_none(
+            hint_child_origin_type = get_hint_pep_origin_type_isinstanceable_or_none(
                 hint_child)
 
             # If...
             if (
                 # This child hint originates from a non-"typing" class *AND*...
-                hint_child_type_origin is not None and
+                hint_child_origin_type is not None and
                 # This pith is *NOT* an instance of this class...
-                not isinstance(sleuth.pith, hint_child_type_origin)
+                not isinstance(sleuth.pith, hint_child_origin_type)
             # Then this pith fails to satisfy this child hint. In this case...
             ):
                 # Add this class to the subset of all classes this pith does
                 # *NOT* satisfy.
-                hint_classes_unsatisfied.add(hint_child_type_origin)
+                hint_classes_unsatisfied.add(hint_child_origin_type)
 
                 # Continue to the next child hint.
                 continue
@@ -164,7 +162,7 @@ def get_cause_or_none_union(sleuth: CauseSleuth) -> Optional[str]:
         # child hints of the average "typing.Union" in general *AND* due to the
         # fact that this function is only called when a catastrophic type-check
         # failure has already occurred.
-        causes_union.insert(0, f'not {cause_types_unsatisfied}')
+        causes_union.insert(0, f'not {truth_colour(cause_types_unsatisfied)}')
 
     # If prior logic appended *NO* causes, raise an exception.
     if not causes_union:
@@ -175,7 +173,7 @@ def get_cause_or_none_union(sleuth: CauseSleuth) -> Optional[str]:
     # Else, prior logic appended one or more strings describing these failures.
 
     # Truncated object representation of this pith.
-    pith_repr = represent_object(sleuth.pith)
+    pith_repr = represent_pith(sleuth.pith)
 
     # If prior logic appended one cause, return this cause as a single-line
     # substring intended to be embedded in a longer string.
