@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -12,16 +12,16 @@ PEP-compliant type hint annotating that parameter or return).
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ TODO                              }....................
+# ....................{ TODO                               }....................
 #FIXME: Generalizing the "random_int" concept (i.e., the optional "random_int"
-#parameter accepted by the raise_pep_call_exception() function) that enables
+#parameter accepted by the get_beartype_violation() function) that enables
 #O(1) rather than O(n) exception handling to containers that do *NOT* provide
 #efficient random access like mappings and sets will be highly non-trivial.
 #While there exist a number of alternative means of implementing that
 #generalization, the most reasonable *BY FAR* is probably to:
 #
 #* Embed additional assignment expressions in the type-checking tests generated
-#  by the pep_code_check_hint() function that uniquely store the value of each
+#  by the make_func_wrapper_code() function that uniquely store the value of each
 #  item, key, or value returned by each access of a non-indexable container
 #  iterator into a new unique local variable. Note this unavoidably requires:
 #  * Adding a new index to the "hint_curr_meta" tuples internally created by
@@ -34,7 +34,7 @@ This private submodule is *not* intended for importation by downstream callers.
 #    * Else, "None".
 #    Actually... hmm. Perhaps we only need a new local variable
 #    "iterator_nonsequence_names" whose value is a cached "FixedList" of
-#    sufficiently large size (so, "SIZE_BIG"?). We could then simply
+#    sufficiently large size (so, "FIXED_LIST_SIZE_MEDIUM"?). We could then simply
 #    iteratively insert the names of the wrapper-specific new unique local
 #    variables into this list.
 #    Actually... *WAIT.* Is all we need a single counter initialized to, say:
@@ -43,14 +43,14 @@ This private submodule is *not* intended for importation by downstream callers.
 #    * Uniquify the names of these wrapper-specific new unique local variables
 #      during iteration over type hints.
 #    * Trivially generate a code snippet passing a list of these names to the
-#      "iterators_nonsequence" parameter of raise_pep_call_exception() function
+#      "iterators_nonsequence" parameter of get_beartype_violation() function
 #      after iteration over type hints.
 #    Right. That looks like The Way, doesn't it? This would seem to be quite a
 #    bit easier than we'd initially thought, which is always nice. Oi!
 #  * Python >= 3.8, but that's largely fine. Python 3.6 and 3.7 are
 #    increasingly obsolete in 2021.
 #* Add a new optional "iterators_nonsequence" parameter to the
-#  raise_pep_call_exception() function, accepting either:
+#  get_beartype_violation() function, accepting either:
 #  * If the current parameter or return of the parent wrapper function was
 #    annotated with one or more non-indexable container type hints, a *LIST* of
 #    the *VALUES* of all unique local variables assigned to by assignment
@@ -65,14 +65,21 @@ This private submodule is *not* intended for importation by downstream callers.
 #  must be taken here to ensure that this exception handling algorithm visits
 #  containers in the exact same order as visited by our testing algorithm.
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from beartype.meta import URL_ISSUES
 from beartype.roar._roarexc import (
+    BeartypeCallHintViolation,
     BeartypeCallHintParamViolation,
     BeartypeCallHintReturnViolation,
     _BeartypeCallHintPepRaiseException,
     _BeartypeCallHintPepRaiseDesynchronizationException,
 )
+from beartype.typing import (
+    Callable,
+    Dict,
+    NoReturn,
+    Optional,
+)
 from beartype._cave._cavemap import NoneTypeOr
 from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._data.hint.pep.sign.datapepsigns import (
@@ -95,15 +102,12 @@ from beartype._util.text.utiltextlabel import (
     prefix_callable_decorated_arg_value,
     prefix_callable_decorated_return_value,
 )
+from beartype._util.text.utiltextcolour import truth_colour, user_value_colour
 from beartype._util.text.utiltextmunge import suffix_unless_suffixed
 from beartype._util.text.utiltextrepr import represent_object
 from beartype._data.datatyping import TypeException
-from typing import Callable, Dict, NoReturn, Optional
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ MAPPINGS                          }....................
+# ....................{ MAPPINGS                           }....................
 # Initialized with automated inspection below in the _init() function.
 PEP_HINT_SIGN_TO_GET_CAUSE_FUNC: Dict[
     HintSign, Callable[[CauseSleuth], Optional[str]]] = {}
@@ -115,7 +119,7 @@ which is dynamically dispatched by that function to describe type-checking
 failures specific to that unsubscripted :mod:`typing` attribute.,
 '''
 
-# ....................{ CONSTANTS                         }....................
+# ....................{ CONSTANTS                          }....................
 # Assuming a line length of 80 characters, this magic number truncates
 # arbitrary object representations to 100 lines (i.e., 8000/80), which seems
 # more than reasonable and (possibly) not overly excessive.
@@ -127,8 +131,8 @@ be sufficiently long to assist in identifying type-check failures but not so
 excessively long as to prevent human-readability.
 '''
 
-# ....................{ RAISERS                           }....................
-def raise_pep_call_exception(
+# ....................{ GETTERS                            }....................
+def get_beartype_violation(
     # Mandatory parameters.
     func: Callable,
     pith_name: str,
@@ -136,12 +140,20 @@ def raise_pep_call_exception(
 
     # Optional parameters.
     random_int: Optional[int] = None,
-) -> None:
+) -> BeartypeCallHintViolation:
     '''
-    Raise a human-readable exception detailing the failure of the parameter
-    with the passed name *or* return value if this name is the magic string
-    ``return`` of the passed decorated function fails to satisfy the
-    PEP-compliant type hint annotated on this parameter or return value.
+    Human-readable exception detailing the failure of the parameter with the
+    passed name *or* return if this name is the magic string ``return`` of the
+    passed decorated function fails to satisfy the PEP-compliant type hint
+    annotating this parameter or return.
+
+    This function intentionally returns rather than raises this exception. Why?
+    Because the ignorable stack frame encapsulating the call of the parent
+    type-checking wrapper function generated by the :mod:`beartype.beartype`
+    decorator complicates inspection of type-checking violations in tracebacks
+    (especially from :mod:`pytest`, which unhelpfully recapitulates the full
+    definition of this function including this docstring in those tracebacks).
+    Instead, that wrapper function raises this exception directly from itself.
 
     Design
     ----------
@@ -149,7 +161,7 @@ def raise_pep_call_exception(
     runtime type-checkers, each complementing the other by providing
     functionality unsuited for the other. These are:
 
-    * The :mod:`beartype._decor._code._pep` submodule, dynamically generating
+    * The :mod:`beartype._check.expr` submodule, dynamically generating
       optimized PEP-compliant runtime type-checking code embedded in the body
       of the wrapper function wrapping the decorated callable. For both
       efficiency and maintainability, that code only tests whether or not a
@@ -160,7 +172,7 @@ def raise_pep_call_exception(
     * This function, performing unoptimized PEP-compliant runtime type-checking
       generically applicable to all wrapper functions. The aforementioned
       code calls this function only in the event that value fails to satisfy
-      that annotation, in which case this function then raises a human-readable
+      that annotation, in which case this function then returns a human-readable
       exception after discovering the underlying cause of this type failure by
       recursively traversing that value and annotation. While efficiency is the
       foremost focus of this package, efficiency is irrelevant during exception
@@ -205,12 +217,20 @@ def raise_pep_call_exception(
         Defaults to ``None``, implying this exception handler runs in linear
         time by default.
 
+    Returns
+    ----------
+    BeartypeCallHintViolation
+        Human-readable exception detailing the failure of this parameter or
+        return to satisfy the PEP-compliant type hint annotating this parameter
+        or return value, guaranteed to be an instance of either:
+
+        * :class:`BeartypeCallHintParamViolation`, if the object failing to
+          satisfy this hint is a parameter.
+        * :class:`BeartypeCallHintReturnViolation`, if the object failing to
+          satisfy this hint is a return.
+
     Raises
     ----------
-    BeartypeCallHintParamViolation
-        If the object failing to satisfy this hint is a parameter.
-    BeartypeCallHintReturnViolation
-        If the object failing to satisfy this hint is a return value.
     BeartypeDecorHintPepException
         If the type hint annotating this object is *not* PEP-compliant.
     _BeartypeCallHintPepRaiseException
@@ -229,7 +249,7 @@ def raise_pep_call_exception(
     assert isinstance(pith_name, str), f'{repr(pith_name)} not string.'
     assert isinstance(random_int, NoneTypeOr[int]), (
         f'{repr(random_int)} neither integer nor "None".')
-    # print('''raise_pep_call_exception(
+    # print('''get_beartype_violation(
     #     func={!r},
     #     pith_name={!r},
     #     pith_value={!r}',
@@ -252,10 +272,7 @@ def raise_pep_call_exception(
     else:
         exception_cls = BeartypeCallHintParamViolation
         exception_prefix = prefix_callable_decorated_arg_value(
-            func=func,
-            arg_name=pith_name,
-            arg_value=pith_value,
-        )
+            func=func, arg_name=pith_name, arg_value=pith_value)
 
     # If this parameter or return value is unannotated, raise an exception.
     #
@@ -291,37 +308,43 @@ def raise_pep_call_exception(
         random_int=random_int,
     ).get_cause_or_none()
 
-    # If this pith does *NOT* satisfy this hint...
-    if exception_cause:
-        # This failure suffixed by a period if *NOT* yet suffixed by a period.
-        exception_cause_suffixed = suffix_unless_suffixed(
-            text=exception_cause, suffix='.')
-
-        # Raise an exception of the desired class embedding this cause.
-        raise exception_cls(  # type: ignore[misc]
-            f'{exception_prefix}violates type hint {repr(hint)}, as '
-            f'{exception_cause_suffixed}'
+    # If this pith satisfies this hint, *SOMETHING HAS GONE TERRIBLY AWRY.* In
+    # theory, this should never happen, as the parent wrapper function
+    # performing type checking should *ONLY* call this child helper function
+    # when this pith does *NOT* satisfy this hint. In this case, raise an
+    # exception encouraging the end user to submit an upstream issue with us.
+    if not exception_cause:
+        pith_value_repr = represent_object(
+            obj=pith_value, max_len=_CAUSE_TRIM_OBJECT_REPR_MAX_LEN)
+        raise _BeartypeCallHintPepRaiseDesynchronizationException(
+            f'{exception_prefix}violates type hint {truth_colour(repr(hint))}, '
+            f'but utility function get_beartype_violation() '
+            f'erroneously suggests this object satisfies this hint. '
+            f'Please report this desynchronization failure to '
+            f'the beartype issue tracker ({URL_ISSUES}) with '
+            f'the accompanying exception traceback and '
+            f'the representation of this object:\n'
+            f'{user_value_colour(pith_value_repr)}'
         )
+    # Else, this pith violates this hint as expected and as required for sanity.
 
-    # Else, this pith satisfies this hint. In this (hopefully uncommon) edge
-    # case, *SOMETHING HAS GONE TERRIBLY AWRY.* In theory, this should never
-    # happen, as the parent wrapper function performing type checking should
-    # *ONLY* call this child helper function when this pith does *NOT* satisfy
-    # this hint. In this case, raise an exception encouraging the end user to
-    # submit an upstream issue with us.
-    pith_value_repr = represent_object(
-        obj=pith_value, max_len=_CAUSE_TRIM_OBJECT_REPR_MAX_LEN)
-    raise _BeartypeCallHintPepRaiseDesynchronizationException(
-        f'{exception_prefix}violates type hint {repr(hint)}, '
-        f'but utility function raise_pep_call_exception() '
-        f'suggests this object satisfies this hint. '
-        f'Please report this desynchronization failure to '
-        f'the beartype issue tracker ({URL_ISSUES}) with '
-        f"this object's representation and "
-        f'accompanying exception traceback:\n{pith_value_repr}'
+    # This failure suffixed by a period if *NOT* yet suffixed by a period.
+    exception_cause_suffixed = suffix_unless_suffixed(
+        text=exception_cause, suffix='.')
+
+    # Exception of the desired class embedding this cause.
+    exception = exception_cls(  # type: ignore[misc]
+        f'{exception_prefix}violates type hint {truth_colour(repr(hint))}, as '
+        f'{exception_cause_suffixed}'
     )
 
-# ....................{ INITIALIZERS                      }....................
+    # Return this exception to the @beartype-generated type-checking wrapper
+    # (which directly calls this function), which will then squelch the
+    # ignorable stack frame encapsulating that call to this function by raising
+    # this exception directly from that wrapper.
+    return exception
+
+# ....................{ INITIALIZERS                       }....................
 def _init() -> None:
     '''
     Initialize this submodule.
