@@ -1,11 +1,11 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
-Project-wide **unmemoized class tester** (i.e., unmemoized and thus efficient
-callable testing various properties of arbitrary classes) utilities.
+Project-wide **class testers** (i.e., low-level callables testing and validating
+various properties of arbitrary classes).
 
 This private submodule is *not* intended for importation by downstream callers.
 '''
@@ -14,13 +14,13 @@ This private submodule is *not* intended for importation by downstream callers.
 from beartype.roar._roarexc import _BeartypeUtilTypeException
 from beartype._cave._cavefast import TestableTypes as TestableTypesTuple
 from beartype._data.cls.datacls import TYPES_BUILTIN_FAKE
-from beartype._data.mod.datamod import BUILTINS_MODULE_NAME
+from beartype._data.mod.datamodpy import BUILTINS_MODULE_NAME
 from beartype._data.datatyping import (
     TypeException,
     TypeOrTupleTypes,
 )
 
-# ....................{ VALIDATORS                        }....................
+# ....................{ VALIDATORS                         }....................
 def die_unless_type(
     # Mandatory parameters.
     cls: object,
@@ -94,8 +94,10 @@ def die_unless_type_or_types(
     if not is_type_or_types(type_or_types):
         assert isinstance(exception_cls, type), (
             'f{repr(exception_cls)} not exception class.')
+        assert issubclass(exception_cls, Exception), (
+            f'{repr(exception_cls)} not exception subclass.')
         assert isinstance(exception_prefix, str), (
-            'f{repr(exception_prefix)} not string.')
+            f'{repr(exception_prefix)} not string.')
 
         # Exception message to be raised below.
         exception_message = (
@@ -129,7 +131,7 @@ def die_unless_type_or_types(
         # Raise this exception.
         raise exception_cls(f'{exception_message}.')
 
-# ....................{ TESTERS                           }....................
+# ....................{ TESTERS                            }....................
 def is_type_or_types(type_or_types: object) -> bool:
     '''
     ``True`` only if the passed object is either a class *or* tuple of one or
@@ -162,7 +164,13 @@ def is_type_or_types(type_or_types: object) -> bool:
     )
 
 
-def is_type_builtin(cls: type) -> bool:
+def is_type_builtin(
+    # Mandatory parameters.
+    cls: type,
+
+    # Optional parameters.
+    is_ignore_fake: bool = True,
+) -> bool:
     '''
     ``True`` only if the passed class is **builtin** (i.e., globally accessible
     C-based type requiring *no* explicit importation).
@@ -175,6 +183,11 @@ def is_type_builtin(cls: type) -> bool:
     ----------
     cls : type
         Class to be inspected.
+    is_ignore_fake : bool
+        ``True`` only if this tester intentionally ignores **fake builtin
+        types** (i.e., types that are *not* builtin but nonetheless erroneously
+        masquerade as being builtin, which includes the type of the :data:`None`
+        singleton). Defaults to ``True``.
 
     Returns
     ----------
@@ -186,19 +199,20 @@ def is_type_builtin(cls: type) -> bool:
     _BeartypeUtilTypeException
         If this object is *not* a class.
     '''
+    assert isinstance(is_ignore_fake, bool), (
+        f'{repr(is_ignore_fake)} not boolean.')
 
     # Avoid circular import dependencies.
-    from beartype._util.mod.utilmodule import (
+    from beartype._util.mod.utilmodget import (
         get_object_type_module_name_or_none)
 
     # If this object is *NOT* a type, raise an exception.
     die_unless_type(cls)
     # Else, this object is a type.
 
-    # If this type is a fake builtin (i.e., type that is *NOT* builtin but
-    # erroneously masquerading as being builtin), this type is *NOT* a builtin.
-    # In this case, silently reject this type.
-    if cls in TYPES_BUILTIN_FAKE:
+    # If ignoring fake builtin types *AND* this type is such a type, this type
+    # is *NOT* a builtin. In this case, silently reject this type.
+    if is_ignore_fake and cls in TYPES_BUILTIN_FAKE:
         return False
     # Else, this type is *NOT* a fake builtin.
 
