@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -11,14 +11,11 @@ user-defined callables).
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from collections.abc import Callable
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ TESTERS                           }....................
-def is_func_pep484_no_type_checked(func: Callable) -> bool:
+# ....................{ TESTERS                            }....................
+def is_func_pep484_notypechecked(func: Callable) -> bool:
     '''
     ``True`` only if the passed callable was decorated by the
     :pep:`484`-compliant :func:`typing.no_type_check` decorator instructing
