@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -10,26 +10,22 @@ possibly nested lexical scopes enclosing arbitrary callables).
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from beartype.roar._roarexc import _BeartypeUtilCallableException
+from beartype.typing import (
+    Any,
+    Optional,
+)
 from beartype._util.utilobject import get_object_basename_scoped
-from beartype._data.datatyping import TypeException
+from beartype._data.datakind import DICT_EMPTY
+from beartype._data.datatyping import (
+    LexicalScope,
+    TypeException,
+)
 from collections.abc import Callable
 from types import CodeType
-from typing import Any, Dict, Optional
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ HINTS                             }....................
-CallableScope = Dict[str, Any]
-'''
-PEP-compliant type hint matching a **callable socpe** (i.e., dictionary mapping
-from the name to value of each locally or globally scoped variable accessible
-to a callable).
-'''
-
-# ....................{ TESTERS                           }....................
+# ....................{ TESTERS                            }....................
 def is_func_nested(func: Callable) -> bool:
     '''
     ``True`` only if the passed callable is **nested** (i.e., a pure-Python
@@ -119,7 +115,7 @@ def is_func_nested(func: Callable) -> bool:
 #     # * If this callable is C-based, undefined.
 #     return getattr(func, '__closure__', None) is not None
 
-# ....................{ GETTERS                           }....................
+# ....................{ GETTERS                            }....................
 #FIXME: Unit test us up, please.
 def get_func_globals(
     # Mandatory parameters.
@@ -127,7 +123,7 @@ def get_func_globals(
 
     # Optional parameters.
     exception_cls: TypeException = _BeartypeUtilCallableException,
-) -> CallableScope:
+) -> LexicalScope:
     '''
     **Global scope** (i.e., a dictionary mapping from the name to value of each
     globally scoped attribute declared by the module transitively declaring
@@ -191,20 +187,21 @@ def get_func_locals(
     func: Callable,
 
     # Optional parameters.
+    func_scope_names_ignore: int = 0,
     func_stack_frames_ignore: int = 0,
     exception_cls: TypeException = _BeartypeUtilCallableException,
-) -> CallableScope:
+) -> LexicalScope:
     '''
     **Local scope** for the passed callable.
 
     This getter returns either:
 
-    * If this callable is **nested** (i.e., is a method *or* is a non-method
+    * If that callable is **nested** (i.e., is a method *or* is a non-method
       callable declared in the body of another callable), a dictionary mapping
       from the name to value of each **locally scoped attribute** (i.e., local
-      attribute declared by a parent callable transitively declaring this
-      callable) accessible to this callable.
-    * Else, the empty dictionary otherwise (i.e., if this callable is a
+      attribute declared by a parent callable transitively declaring that
+      callable) accessible to that callable.
+    * Else, the empty dictionary otherwise (i.e., if that callable is a
       function directly declared by a module).
 
     This getter transparently supports methods, which in Python are lexically
@@ -212,7 +209,7 @@ def get_func_locals(
     variables** (i.e., variables declared from class scope and thus accessible
     as type hints when annotating the methods of that class). When declaring a
     class, Python creates a stack frame for the declaration of that class whose
-    local scope is the set of all class-scope attributes declared in the body
+    local scope is the set of all class-scoped attributes declared in the body
     of that class (including class variables, class methods, static methods,
     and instance methods). When passed any method, this getter finds and
     returns that local scope. When passed the ``MuhClass.muh_method` method
@@ -228,11 +225,15 @@ def get_func_locals(
        ...    # Instance method annotated by this class variable.
        ...    def muh_method(self) -> muh_class_var: return 42
 
+    However, note that this getter's transparent support for methods does *not*
+    extend to methods of the currently decorated class. Why? Because that class
+    has yet to be declared and thus added to the call stack.
+
     Caveats
     ----------
     **This high-level getter requires the private low-level**
     :func:`sys._getframe` **getter.** If that getter is undefined, this getter
-    unconditionally treats this callable as module-scoped by returning the
+    unconditionally treats the passed callable as module-scoped by returning the
     empty dictionary rather than raising an exception. Since all standard
     Python implementations (e.g., CPython, PyPy) define that getter, this
     should typically *not* be a real-world concern.
@@ -240,7 +241,7 @@ def get_func_locals(
     **This high-level getter is inefficient and should thus only be called if
     absolutely necessary.** Specifically, deciding the local scope for any
     callable is an ``O(k)`` operation for ``k`` the distance in call stack
-    frames from the call to the current function to the call to the top-most
+    frames from the call of the current function to the call of the top-most
     parent scope transitively declaring the passed callable in its submodule.
     Ergo, this decision problem should be deferred as long as feasible to
     minimize space and time consumption.
@@ -249,6 +250,17 @@ def get_func_locals(
     ----------
     func : Callable
         Callable to be inspected.
+    func_scope_names_ignore : int, optional
+        Number of parent lexical scopes in the fully-qualified name of that
+        callable to be ignored (i.e., silently incremented past), such that the
+        next non-ignored lexical scope preceding the first ignored lexical scope
+        is that of the parent callable or module directly declaring the passed
+        callable. This parameter is typically used to ignore the parent lexical
+        scopes of parent classes lexically nesting that callable that have yet
+        to be fully declared and thus encapsulated by stack frames on the call
+        stack (e.g., due to being currently decorated by
+        :func:`beartype.beartype`). See the :mod:`beartype._decor._pep.pep563`
+        submodule for the standard use case. Defaults to 0.
     func_stack_frames_ignore : int, optional
         Number of frames on the call stack to be ignored (i.e., silently
         incremented past), such that the next non-ignored frame following the
@@ -260,28 +272,35 @@ def get_func_locals(
 
     Returns
     ----------
-    Dict[str, Any]
+    LexicalScope
         Local scope for this callable.
 
     Raises
     ----------
-    exception_cls
+    :exc:`exception_cls`
         If the next non-ignored frame following the last ignored frame is *not*
         the parent callable or module directly declaring the passed callable.
     '''
     assert callable(func), f'{repr(func)} not callable.'
+    assert isinstance(func_scope_names_ignore, int), (
+        f'{func_scope_names_ignore} not integer.')
+    assert func_scope_names_ignore >= 0, (
+        f'{func_scope_names_ignore} negative.')
     assert isinstance(func_stack_frames_ignore, int), (
         f'{func_stack_frames_ignore} not integer.')
     assert func_stack_frames_ignore >= 0, (
         f'{func_stack_frames_ignore} negative.')
     # print(f'\n--------- Capturing nested {func.__qualname__}() local scope...')
 
-    # ..................{ IMPORTS                           }..................
+    # ..................{ IMPORTS                            }..................
     # Avoid circular import dependencies.
-    from beartype._util.func.utilfunccodeobj import get_func_codeobj_or_none
-    from beartype._util.func.utilfuncstack import iter_func_stack_frames
+    from beartype._util.func.utilfunccodeobj import (
+        FUNC_CODEOBJ_NAME_MODULE,
+        get_func_codeobj_or_none,
+    )
+    from beartype._util.func.utilfuncframe import iter_frames
 
-    # ..................{ NOOP                              }..................
+    # ..................{ NOOP                               }..................
     # Fully-qualified name of the module declaring the passed callable if that
     # callable was physically declared by an on-disk module *OR* "None"
     # otherwise (i.e., if that callable was dynamically declared in-memory).
@@ -302,21 +321,21 @@ def get_func_locals(
     if (
         # The passed callable is dynamically declared in-memory...
         func_module_name is None or
-        # The passed callable is unnested *OR*...
+        # The passed callable is module-scoped rather than nested *OR*...
         not is_func_nested(func)
+    # Then silently reduce to a noop by treating this nested callable as
+    # module-scoped by preserving "func_locals" as the empty dictionary.
     ):
-        # Then silently reduce to a noop by treating this nested callable as
-        # module-scoped by preserving "func_locals" as the empty dictionary.
-        return {}
+        return DICT_EMPTY
     # Else, all of the following constraints hold:
     # * The passed callable is physically declared on-disk.
     # * The passed callable is nested.
 
-    # ..................{ LOCALS ~ scope                    }..................
+    # ..................{ LOCALS ~ scope                     }..................
     # Local scope of the passed callable to be returned.
-    func_scope: CallableScope = {}
+    func_scope: LexicalScope = {}
 
-    # ..................{ LOCALS ~ scope : name             }..................
+    # ..................{ LOCALS ~ scope : name              }..................
     # Unqualified name of this nested callable.
     func_name_unqualified = func.__name__
 
@@ -329,10 +348,10 @@ def get_func_locals(
     #     ...     return muh_closure()
     #     >>> muh_func().__qualname__
     #     'muh_func.<locals>.muh_closure'
-    func_name_qualified = func.__qualname__
+    func_name_qualified = get_object_basename_scoped(func)
 
     # Non-empty list of the unqualified names of all parent callables lexically
-    # containing this nested callable (including this nested callable itself).
+    # containing that nested callable (including that nested callable itself).
     #
     # Note that:
     # * The set of all callables embodied by the current runtime call stack is
@@ -348,29 +367,99 @@ def get_func_locals(
     #   frames with irrelevant lexical scopes, starting at the stack top (end).
     func_scope_names = func_name_qualified.rsplit(sep='.')
 
-    # Assert this nested callable is encapsulated by at least two lexical
-    # scopes identifying at least this nested callable and the parent callable
-    # or class declaring this nested callable.
-    assert len(func_scope_names) >= 2, (
-        f'{func_name_unqualified}() not nested (i.e., fully-qualified name '
-        f'"{func_name_qualified}" == unqualified name '
-        f'"{func_name_unqualified}").')
+    # Number of lexical scopes encapsulating that callable.
+    func_scope_names_len = len(func_scope_names)
 
-    # If the unqualified name of the last parent callable lexically containing
-    # the passed callable is *NOT* that callable itself, the caller maliciously
-    # renamed one but *NOT* both of the dunder attributes of that callable
-    # uniquely identifying that callable. In this case, raise an exception.
-    if func_scope_names[-1] != func_name_unqualified:
+    # If that nested callable is *NOT* encapsulated by at least two lexical
+    # scopes identifying at least that nested callable and the parent callable
+    # or class declaring that nested callable, raise an exception.
+    #
+    # You are probably now contemplating to yourself in the special darkness of
+    # your own personal computer cave: "But @leycec, isn't this condition
+    # *ALWAYS* the case? The above `not is_func_nested()` check already ignored
+    # non-nested callables."
+    #
+    # Allow me to now explicate. By the check above, that callable is nested...
+    # By the check below, however, only one lexical scope encapsulates that
+    # callable. This is not a contradiction. This is just a malicious caller.
+    # The get_object_basename_scoped() getter called above silently removed all
+    # "<locals>." placeholders from this list of lexical scopes, because those
+    # "<locals>." placeholders convey no meaningful semantics. But the
+    # is_func_nested() tester detects nested callables by searching for those
+    # "<locals>." placeholders. It follows that the caller triggered this
+    # condition by maliciously renaming the "__qualname__" dunder attribute of
+    # the passed callable to be erroneously prefixed by "<locals>". Curiously,
+    # Python permits such manhandling: e.g.,
+    #     # Python thinks this is fine.
+    #     >>> def muh_func(): pass
+    #     >>> muh_func.__qualname__ = '<locals>.muh_func'  # <-- curse you!
+    if func_scope_names_len < 2:
         raise exception_cls(
             f'{func_name_unqualified}() fully-qualified name '
-            f'{func_name_qualified}() invalid (i.e., last lexical scope '
+            f'{func.__qualname__}() invalid (e.g., placeholder substring '
+            f'"<locals>" not preceded by parent callable name).'
+        )
+    # Else, that nested callable is encapsulated by at least two lexical
+    # scopes identifying at least that nested callable and the parent callable
+    # or class declaring that nested callable.
+    #
+    # If the unqualified basename of the last parent callable lexically
+    # containing the passed callable is *NOT* that callable itself, the caller
+    # maliciously renamed one but *NOT* both of "__qualname__" and "__name__".
+    # In this case, raise an exception. Again, Python permits this. *sigh*
+    elif func_scope_names[-1] != func_name_unqualified:
+        raise exception_cls(
+            f'{func_name_unqualified}() fully-qualified name '
+            f'{func.__qualname__}() invalid (i.e., last lexical scope '
             f'"{func_scope_names[-1]}" != unqualified name '
             f'"{func_name_unqualified}").'
         )
+    # Else, the unqualified basename of the last parent callable lexically
+    # containing the passed callable is that callable itself.
 
-    # Unqualified name of the parent callable directly lexically containing
-    # (and thus declaring) the passed callable -- which by the above validation
-    # is guaranteed to be the second-to-last string in this list of names.
+    # 1-based negative index of the unqualified basename of the parent callable
+    # or module directly lexically containing the passed callable in the list of
+    # all unqualified basenames encapsulating that callable. By the above
+    # validation, this index is guaranteed to begin at the second-to-last
+    # basename in this list.
+    func_scope_names_index = -2 - func_scope_names_ignore
+
+    # Number of unignorable lexical scopes encapsulating that callable,
+    # magically adding 1 to account for the fact that "func_scope_names_index"
+    # is a 1-based negative index rather than 0-based positive index.
+    func_scope_names_search_len = (
+        func_scope_names_len + func_scope_names_index + 1)
+
+    # If exactly *ZERO* unignorable lexical scopes encapsulate that callable,
+    # all lexical scopes encapsulating that callable are exactly ignorable,
+    # implying that there is *NO* parent lexical scope to search for. In this
+    # case, silently reduce to a noop by returning the empty dictionary.
+    if func_scope_names_search_len == 0:
+        return DICT_EMPTY
+    # If a *NEGATIVE* number of unignorable lexical scopes encapsulate that
+    # callable, the caller erroneously insists that there exist more ignorable
+    # lexical scopes encapsulating that callable than there actually exist
+    # lexical scopes encapsulating that callable. The caller is profoundly
+    # mistaken. Whereas the prior branch is a non-erroneous condition that
+    # commonly occurs, this current branch is an erroneous condition that should
+    # *NEVER* occur. In this case...
+    elif func_scope_names_search_len < 0:
+        # Number of parent lexical scopes containing that callable.
+        func_scope_parents_len = func_scope_names_len - 1
+
+        # Raise an exception.
+        raise exception_cls(
+            f'Callable name "{func_name_qualified}" contains only '
+            f'{func_scope_parents_len} parent lexical scope(s) but '
+            f'"func_scope_names_ignore" parameter ignores '
+            f'{func_scope_names_ignore} parent lexical scope(s), leaving '
+            f'{func_scope_names_search_len} parent lexical scope(s) to be '
+            f'searched for {func_name_qualified}() locals.'
+        )
+    # Else, there are one or more unignorable lexical scopes to be searched.
+
+    # Unqualified basename of the parent callable or module directly lexically
+    # containing the passed callable.
     #
     # Note that that the parent callable's local runtime scope transitively
     # contains *ALL* local variables accessible to this nested callable
@@ -380,32 +469,10 @@ def get_func_locals(
     # scope). Since that parent callable's local runtime scope is exactly the
     # dictionary to be returned, iteration below searches up the runtime call
     # stack for a stack frame embodying that parent callable and no further.
-    func_scope_name = func_scope_names[-2]
-
-    # If this name is the placeholder substring specific to nested callables...
-    if func_scope_name == '<locals>':
-        # If this list contains less than three names, this list *MUST* contain
-        # exactly two names, since this list is neither empty *NOR* contains
-        # exactly one name. In this case, this name *MUST* by deduction have
-        # been the first in this list.
-        #
-        # But this placeholder substring *MUST* be preceded by the name of a
-        # parent callable. Since this is *NOT* the case, the caller maliciously
-        # renamed the "__qualname__" dunder attributes of the passed callable
-        # to be prefixed by "<locals>". In this case, raise an exception.
-        if len(func_scope_names) < 3:
-            raise exception_cls(
-                f'{func_name_unqualified}() fully-qualified name '
-                f'{func_name_qualified}() invalid (i.e., placeholder '
-                f'substring "<locals>" not preceded by parent callable name).'
-            )
-
-        # Skip over this placeholder to the unqualified name of the parent
-        # callable lexically containing the passed callable.
-        func_scope_name = func_scope_names[-3]
+    func_scope_name = func_scope_names[func_scope_names_index]
     # print(f'Searching for parent {func_scope_name}() local scope...')
 
-    # ..................{ LOCALS ~ frame                    }..................
+    # ..................{ LOCALS ~ frame                     }..................
     # Code object underlying the parent callable associated with the current
     # stack frame if that callable is pure-Python *OR* "None".
     func_frame_codeobj: Optional[CodeType] = None
@@ -416,7 +483,7 @@ def get_func_locals(
     # Unqualified name of that callable.
     func_frame_name = ''
 
-    # ..................{ SEARCH                            }..................
+    # ..................{ SEARCH                             }..................
     # While at least one frame remains on the call stack, iteratively search up
     # the call stack for a stack frame embodying the parent callable directly
     # declaring this nested callable, whereupon that parent callable's local
@@ -432,7 +499,7 @@ def get_func_locals(
     #     @beartype
     #     def the_stormlight_archive(bruh: str) -> str:
     #         return bruh
-    for func_frame in iter_func_stack_frames(
+    for func_frame in iter_frames(
         # 0-based index of the first non-ignored frame following the last
         # ignored frame, ignoring an additional frame embodying the current
         # call to this getter.
@@ -446,7 +513,7 @@ def get_func_locals(
         # case, silently ignore this scope and proceed to the next frame.
         if func_frame_codeobj is None:
             continue
-        # Else, this code object exists, implying this scope is pure-Python.
+        # Else, this code object exists, implying this scope to be pure-Python.
 
         # Fully-qualified name of that scope's module.
         func_frame_module_name = func_frame.f_globals['__name__']
@@ -463,9 +530,9 @@ def get_func_locals(
         # lexical scope of the parent declaring this nested callable. Why?
         # Because that scope *MUST* necessarily be in the same module as that
         # of this nested callable. In this case, raise an exception.
-        if func_frame_name == '<module>':
+        if func_frame_name == FUNC_CODEOBJ_NAME_MODULE:
             raise exception_cls(
-                f'{get_object_basename_scoped(func)}() parent lexical scope '
+                f'{func_name_qualified}() parent lexical scope '
                 f'{func_scope_name}() not found on call stack.'
             )
         # Else, that scope is *NOT* a module.
@@ -516,28 +583,28 @@ def get_func_locals(
     # Return the local scope of the passed callable.
     return func_scope
 
-# ....................{ ADDERS                            }....................
+# ....................{ ADDERS                             }....................
 def add_func_scope_attr(
     # Mandatory parameters.
     attr: Any,
-    func_scope: CallableScope,
+    func_scope: LexicalScope,
 
     # Optional parameters.
     exception_prefix: str = 'Globally or locally scoped attribute ',
 ) -> str:
     '''
     Add a new **scoped attribute** (i.e., new key-value pair of the passed
-    dictionary mapping from the name to value of each globally or locally
-    scoped attribute externally accessed elsewhere, whose key is a
-    machine-readable name internally generated by this function to uniquely
-    refer to the passed object and whose value is that object) to the passed
-    scope *and* return that name.
+    dictionary mapping from the name to value of each globally or locally scoped
+    attribute externally accessed elsewhere, whose key is a machine-readable
+    name internally generated by this function to uniquely refer to the passed
+    object and whose value is that object) to the passed scope *and* return that
+    name.
 
     Parameters
     ----------
     attr : Any
         Arbitrary object to be added to this scope.
-    func_scope : CallableScope
+    func_scope : LexicalScope
         Local or global scope to add this object to.
     exception_prefix : str, optional
         Human-readable label prefixing the representation of this object in the
