@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
-# Copyright (c) 2014-2021 Beartype authors.
+# --------------------( LICENSE                            )--------------------
+# Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -9,26 +9,23 @@ Project-wide **PEP-noncompliant type hint** utilities.
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ TODO                              }....................
+# ....................{ TODO                               }....................
 #FIXME: Validate strings to be syntactically valid classnames via a globally
 #scoped compiled regular expression. Raising early exceptions at decoration
 #time is preferable to raising late exceptions at call time.
 #FIXME: Indeed, we now provide such a callable:
-#    from beartype._util.mod.utilmodule import die_unless_module_attr_name
+#    from beartype._util.mod.utilmodget import die_unless_module_attr_name
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from beartype.roar import BeartypeDecorHintNonpepException
 from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.cls.pep.utilpep3119 import (
     die_unless_type_isinstanceable,
-    is_type_isinstanceable,
+    is_type_or_types_isinstanceable,
 )
-from beartype._util.utiltyping import TypeException
+from beartype._data.datatyping import TypeException
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ VALIDATORS                        }....................
+# ....................{ VALIDATORS                         }....................
 #FIXME: Unit test us up, please.
 def die_if_hint_nonpep(
     # Mandatory parameters.
@@ -68,7 +65,7 @@ def die_if_hint_nonpep(
 
     Raises
     ----------
-    exception_cls
+    :exc:`exception_cls`
         If this object is either:
 
         * An **isinstanceable type** (i.e., standard class passable as the
@@ -91,17 +88,19 @@ def die_if_hint_nonpep(
             f'{repr(exception_prefix)} not string.')
         assert isinstance(exception_cls, type), (
             f'{repr(exception_cls)} not type.')
+        assert issubclass(exception_cls, Exception), (
+            f'{repr(exception_cls)} not exception type.')
 
         raise exception_cls(
             f'{exception_prefix}type hint {repr(hint)} '
-            f'is PEP-noncompliant (e.g., ' +
+            f'is PEP-noncompliant (e.g., neither ' +
             (
                 (
-                    'isinstanceable class, forward reference, or tuple of '
+                    'isinstanceable class, forward reference, nor tuple of '
                     'isinstanceable classes and/or forward references).'
                 )
                 if is_str_valid else
-                'isinstanceable class or tuple of isinstanceable classes).'
+                'isinstanceable class nor tuple of isinstanceable classes).'
             )
         )
     # Else, this object is *NOT* a PEP-noncompliant type hint.
@@ -146,7 +145,7 @@ def die_unless_hint_nonpep(
 
     Raises
     ----------
-    exception_cls
+    :exc:`exception_cls`
         If this object is neither:
 
         * An **isinstanceable type** (i.e., standard class passable as the
@@ -169,9 +168,13 @@ def die_unless_hint_nonpep(
     # Else, this object is *NOT* a PEP-noncompliant type hint. In this case,
     # subsequent logic raises an exception specific to the passed parameters.
 
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # BEGIN: Synchronize changes here with the is_hint_nonpep() tester below.
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    assert isinstance(exception_cls, type), (
+        f'{repr(exception_cls)} not type.')
+    assert isinstance(exception_prefix, str), (
+        f'{repr(exception_prefix)} not string.')
 
     # If this object is a class...
     if isinstance(hint, type):
@@ -195,32 +198,36 @@ def die_unless_hint_nonpep(
             is_str_valid=is_str_valid,
             exception_cls=exception_cls,
         )
-    # Else, this object is neither a forward reference, class, nor tuple. Ergo,
-    # this object is *NOT* a PEP-noncompliant type hint.
-    #
-    # If forward references are supported, raise an exception noting that.
-    elif is_str_valid:
-        assert isinstance(exception_cls, type), (
-            f'{repr(exception_cls)} not type.')
-        assert isinstance(exception_prefix, str), (
-            f'{repr(exception_prefix)} not string.')
+    # Else, this object is neither a type nor type tuple.
 
-        raise exception_cls(
-            f'{exception_prefix}type hint {repr(hint)} '
-            f'neither PEP-compliant nor -noncompliant '
-            f'(e.g., isinstanceable class, forward reference, or '
-            f'tuple of isinstanceable classes and forward references).'
-        )
-    # Else, forward references are unsupported. In this case, raise an
-    # exception noting that.
-    else:
-        raise exception_cls(
-            f'{exception_prefix}type hint {repr(hint)} '
-            f'neither PEP-compliant nor -noncompliant '
-            f'(e.g., isinstanceable class or tuple of isinstanceable classes).'
-        )
+    # Raise a generic exception.
+    raise exception_cls(
+        f'{exception_prefix}type hint {repr(hint)} either '
+        f'PEP-noncompliant or currently unsupported by @beartype.'
+    )
 
-# ....................{ VALIDATORS ~ kind                 }....................
+    #FIXME: Temporarily preserved in case we want to restore this. *shrug*
+    # # Else, this object is neither a forward reference, class, nor tuple. Ergo,
+    # # this object is *NOT* a PEP-noncompliant type hint.
+    # #
+    # # If forward references are supported, raise an exception noting that.
+    # elif is_str_valid:
+    #     raise exception_cls(
+    #         f'{exception_prefix}type hint {repr(hint)} '
+    #         f'neither PEP-compliant nor -noncompliant '
+    #         f'(e.g., neither PEP-compliant, isinstanceable class, forward reference, or '
+    #         f'tuple of isinstanceable classes and forward references).'
+    #     )
+    # # Else, forward references are unsupported. In this case, raise an
+    # # exception noting that.
+    # else:
+    #     raise exception_cls(
+    #         f'{exception_prefix}type hint {repr(hint)} '
+    #         f'neither PEP-compliant nor -noncompliant '
+    #         f'(e.g., isinstanceable class or tuple of isinstanceable classes).'
+    #     )
+
+# ....................{ VALIDATORS ~ kind                  }....................
 #FIXME: Unit test us up.
 def die_unless_hint_nonpep_type(
     # Mandatory parameters.
@@ -255,7 +262,7 @@ def die_unless_hint_nonpep_type(
     BeartypeDecorHintPep3119Exception
         If this object is *not* an isinstanceable class (i.e., class passable
         as the second argument to the :func:`isinstance` builtin).
-    exception_cls
+    :exc:`exception_cls`
         If this object is a PEP-compliant type hint.
     '''
 
@@ -294,7 +301,7 @@ def die_unless_hint_nonpep_type(
 #* Else, we:
 #  * Perform a new optimized EAFP-style isinstance() check resembling that
 #    performed by die_unless_type_isinstanceable().
-#  * Likewise for _is_hint_nonpep_tuple() vis-a-vis is_type_isinstanceable().
+#  * Likewise for _is_hint_nonpep_tuple() vis-a-vis is_type_or_types_isinstanceable().
 #Fortunately, tuple unions are now sufficiently rare in the wild (i.e., in
 #real-world use cases) that this mild inefficiency probably no longer matters.
 #FIXME: Indeed! Now that we have the die_unless_type_or_types_isinstanceable()
@@ -339,7 +346,7 @@ def die_unless_hint_nonpep_tuple(
 
     Raises
     ----------
-    exception_cls
+    :exc:`exception_cls`
         If this object is neither:
 
         * A non-:mod:`typing` type (i.e., class *not* defined by the
@@ -369,9 +376,9 @@ def die_unless_hint_nonpep_tuple(
     assert isinstance(exception_prefix, str), (
         f'{repr(exception_prefix)} not string.')
 
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # BEGIN: Synchronize changes here with the _is_hint_nonpep_tuple() tester.
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
     # If this object is *NOT* a tuple, raise an exception.
     if not isinstance(hint, tuple):
@@ -386,15 +393,15 @@ def die_unless_hint_nonpep_tuple(
 
     # For each item of this tuple...
     for hint_item in hint:
-        # Duplicate the above logic. For negligible efficiency gains (and
-        # more importantly to avoid exhausting the stack), avoid calling
-        # this function recursively to do so. *shrug*
+        # Duplicate the above logic. For negligible efficiency gains (and more
+        # importantly to avoid exhausting the stack), avoid calling this
+        # function recursively to do so. *shrug*
 
         # If this item is a class...
         if isinstance(hint_item, type):
-            # If this class is *NOT* PEP-noncompliant, raise an exception.
-            die_unless_hint_nonpep_type(
-                hint=hint_item,
+            # If this class is *NOT* isinstanceable, raise an exception.
+            die_unless_type_isinstanceable(
+                cls=hint_item,
                 exception_prefix=exception_prefix,
                 exception_cls=exception_cls,
             )
@@ -420,7 +427,7 @@ def die_unless_hint_nonpep_tuple(
                 f'{"neither type nor string" if is_str_valid else "not type"}.'
             )
 
-# ....................{ TESTERS                           }....................
+# ....................{ TESTERS                            }....................
 def is_hint_nonpep(
     # Mandatory parameters.
     hint: object,
@@ -469,9 +476,9 @@ def is_hint_nonpep(
     '''
     assert isinstance(is_str_valid, bool), f'{repr(is_str_valid)} not boolean.'
 
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # BEGIN: Synchronize changes here with die_unless_hint_nonpep() above.
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
     # Return true only if either...
     return (
@@ -490,7 +497,7 @@ def is_hint_nonpep(
         else False
     )
 
-# ....................{ TESTERS ~ private                 }....................
+# ....................{ TESTERS ~ private                  }....................
 @callable_cached
 def _is_hint_nonpep_tuple(
     # Mandatory parameters.
@@ -529,9 +536,9 @@ def _is_hint_nonpep_tuple(
     '''
     assert isinstance(is_str_valid, bool), f'{repr(is_str_valid)} not boolean.'
 
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # BEGIN: Synchronize changes here with die_unless_hint_nonpep() above.
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
     # Return true only if this object is...
     return (
@@ -540,10 +547,10 @@ def _is_hint_nonpep_tuple(
         # This tuple is non-empty *AND*...
         len(hint) > 0 and
         # Each item of this tuple is either a caller-permitted forward
-        # reference *OR* a PEP-noncompliant class.
+        # reference *OR* an isinstanceable class.
         all(
-            _is_hint_nonpep_type(hint_item) if isinstance(hint_item, type) else
-            is_str_valid                    if isinstance(hint_item, str) else
+            is_type_or_types_isinstanceable(hint_item) if isinstance(hint_item, type) else
+            is_str_valid                               if isinstance(hint_item, str) else
             False
             for hint_item in hint
         )
@@ -568,9 +575,9 @@ def _is_hint_nonpep_type(hint: object) -> bool:
     bool
         ``True`` only if this object is a PEP-noncompliant type.
     '''
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # BEGIN: Synchronize changes here with die_unless_hint_nonpep() above.
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
     # Avoid circular import dependencies.
     from beartype._util.hint.pep.utilpeptest import is_hint_pep
@@ -578,4 +585,4 @@ def _is_hint_nonpep_type(hint: object) -> bool:
     # Return true only if this object is isinstanceable and *NOT* a
     # PEP-compliant class, in which case this *MUST* be a PEP-noncompliant
     # class by definition.
-    return is_type_isinstanceable(hint) and not is_hint_pep(hint)
+    return is_type_or_types_isinstanceable(hint) and not is_hint_pep(hint)
