@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -10,135 +10,18 @@ callables generically applicable to :pep:`484`-compliant generic classes).
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from beartype.roar import BeartypeDecorHintPep484Exception
-from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_7
+from beartype.typing import (
+    Any,
+    Generic,
+)
 from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.cls.utilclstest import is_type_subclass
-from typing import Any, Generic
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ TESTERS                           }....................
-# If the active Python interpreter targets at least Python >= 3.7.0, implement
-# this function in the standard way.
-#
-# Sadly, Python 3.7.0 broke backward compatibility with the public API of the
-# "typing" module by removing the "typing.GenericMeta" metaclass previously
-# referenced by this function under Python 3.6.
-if IS_PYTHON_AT_LEAST_3_7:
-    def is_hint_pep484_generic(hint: object) -> bool:
-
-        # Avoid circular import dependencies.
-        from beartype._util.hint.pep.proposal.pep484585.utilpep484585generic import (
-            get_hint_pep484585_generic_type_or_none)
-
-        # If this hint is *NOT* a class, this hint is *NOT* an unsubscripted
-        # generic but could still be a subscripted generic (i.e., generic
-        # subscripted by one or more PEP-compliant child type hints). To
-        # decide, reduce this hint to the object originating this hint if any,
-        # enabling the subsequent test to test whether this origin object is an
-        # unsubscripted generic, which would then imply this hint to be a
-        # subscripted generic. If this strikes you as insane, you're not alone.
-        hint = get_hint_pep484585_generic_type_or_none(hint)
-
-        # Return true only if this hint is a subclass of the "typing.Generic"
-        # abstract base class (ABC), in which case this hint is a user-defined
-        # generic.
-        #
-        # Note that this test is robust against edge cases, as the "typing"
-        # module guarantees all user-defined classes subclassing one or more
-        # "typing" pseudo-superclasses to subclass the "typing.Generic"
-        # abstract base class (ABC) regardless of whether those classes did so
-        # explicitly. How? By type erasure, of course, the malignant gift that
-        # keeps on giving:
-        #     >>> import typing as t
-        #     >>> class MuhList(t.List): pass
-        #     >>> MuhList.__orig_bases__
-        #     (typing.List)
-        #     >>> MuhList.__mro__
-        #     (__main__.MuhList, list, typing.Generic, object)
-        #
-        # Note that:
-        # * This issubclass() call implicitly performs a surprisingly
-        #   inefficient search over the method resolution order (MRO) of all
-        #   superclasses of this hint. In theory, the cost of this search might
-        #   be circumventable by observing that this ABC is expected to reside
-        #   at the second-to-last index of the tuple exposing this MRO far all
-        #   generics by virtue of fragile implementation details violating
-        #   privacy encapsulation. In practice, this codebase is already
-        #   fragile enough.
-        # * The following logic superficially appears to implement the same
-        #   test *WITHOUT* the onerous cost of a search:
-        #       return len(get_hint_pep484_generic_bases_unerased_or_none(hint)) > 0
-        #   Why didn't we opt for that, then? Because this tester is routinely
-        #   passed objects that *CANNOT* be guaranteed to be PEP-compliant.
-        #   Indeed, the high-level is_hint_pep() tester establishing the
-        #   PEP-compliance of arbitrary objects internally calls this
-        #   lower-level tester to do so. Since the
-        #   get_hint_pep484_generic_bases_unerased_or_none() getter internally
-        #   reduces to returning the tuple of the general-purpose
-        #   "__orig_bases__" dunder attribute formalized by PEP 560, testing
-        #   whether that tuple is non-empty or not in no way guarantees this
-        #   object to be a PEP-compliant generic.
-        return is_type_subclass(hint, Generic)  # type: ignore[arg-type]
-# Else, the active Python interpreter targets Python 3.6.x. In this case,
-# implement this function specific to this Python version.
-else:
-    # Import the Python 3.6.x-specific metaclass required by this tester.
-    from typing import GenericMeta  # type: ignore[attr-defined]
-
-    def is_hint_pep484_generic(hint: object) -> bool:
-
-        # Avoid circular import dependencies.
-        from beartype._util.hint.pep.proposal.pep484585.utilpep484585generic import (
-            get_hint_pep484585_generic_type_or_none)
-        from beartype._util.hint.pep.utilpeptest import (
-            is_hint_pep_type_typing)
-
-        # If this hint is *NOT* a class, reduce this hint to the object
-        # originating this hint if any. See the above tester for details.
-        hint_type = get_hint_pep484585_generic_type_or_none(hint)
-
-        # Return true only if...
-        #
-        # Note that:
-        # * The Python >= 3.7.0-specific implementation of this tester does
-        #   *NOT* apply to Python < 3.7.0, as this metaclass unconditionally
-        #   raises exceptions when user-defined "typing" subclasses internally
-        #   requiring this metaclass are passed to the issubclass() builtin.
-        # * This tester intentionally avoids returning true for *ALL* generics
-        #   (including both those internally defined by the "typing" module and
-        #   those externally defined by third-party callers). Why? Because
-        #   generics internally defined by the "typing" module are effectively
-        #   *NOT* generics and only implemented as such under Python < 3.7.0
-        #   for presumably indefensible low-level reasons -- including:
-        #   * *ALL* callable types (e.g., "typing.Awaitable",
-        #     "typing.Callable", "typing.Coroutine", "typing.Generator").
-        #   * *MOST* container and iterable types (e.g., "typing.Dict",
-        #     "typing.List", "typing.Mapping", "typing.Tuple").
-        #
-        # If this tester returned true for *ALL* generics, downstream callers
-        # would have no means of distinguishing genuine generics from
-        # disingenuous "typing" pseudo-generics.
-        return (
-            # The metaclass of this hint is the "typing.GenericMeta" metaclass
-            # *AND*...
-            isinstance(hint_type, GenericMeta) and
-            # This hint is either...
-            (
-                # A parametrization of the "typing.Generic" class (e.g.,
-                # "Generic[S, T]") *OR*...
-                hint_type is Generic or
-                # A subclass *NOT* defined by the "typing" module. See above.
-                not is_hint_pep_type_typing(hint_type)
-            )
-        )
-
-
-# Docstring for this function regardless of implementation details.
-is_hint_pep484_generic.__doc__ = '''
+# ....................{ TESTERS                            }....................
+def is_hint_pep484_generic(hint: object) -> bool:
+    '''
     ``True`` only if the passed object is a :pep:`484`-compliant **generic**
     (i.e., object that may *not* actually be a class originally subclassing at
     least one PEP-compliant type hint defined by the :mod:`typing` module).
@@ -170,7 +53,61 @@ is_hint_pep484_generic.__doc__ = '''
         ``True`` only if this object is a :mod:`typing` generic.
     '''
 
-# ....................{ GETTERS                           }....................
+    # Avoid circular import dependencies.
+    from beartype._util.hint.pep.proposal.pep484585.utilpep484585generic import (
+        get_hint_pep484585_generic_type_or_none)
+
+    # If this hint is *NOT* a class, this hint is *NOT* an unsubscripted
+    # generic but could still be a subscripted generic (i.e., generic
+    # subscripted by one or more PEP-compliant child type hints). To
+    # decide, reduce this hint to the object originating this hint if any,
+    # enabling the subsequent test to test whether this origin object is an
+    # unsubscripted generic, which would then imply this hint to be a
+    # subscripted generic. If this strikes you as insane, you're not alone.
+    hint = get_hint_pep484585_generic_type_or_none(hint)
+
+    # Return true only if this hint is a subclass of the "typing.Generic"
+    # abstract base class (ABC), in which case this hint is a user-defined
+    # generic.
+    #
+    # Note that this test is robust against edge cases, as the "typing"
+    # module guarantees all user-defined classes subclassing one or more
+    # "typing" pseudo-superclasses to subclass the "typing.Generic"
+    # abstract base class (ABC) regardless of whether those classes did so
+    # explicitly. How? By type erasure, of course, the malignant gift that
+    # keeps on giving:
+    #     >>> import typing as t
+    #     >>> class MuhList(t.List): pass
+    #     >>> MuhList.__orig_bases__
+    #     (typing.List)
+    #     >>> MuhList.__mro__
+    #     (__main__.MuhList, list, typing.Generic, object)
+    #
+    # Note that:
+    # * This issubclass() call implicitly performs a surprisingly
+    #   inefficient search over the method resolution order (MRO) of all
+    #   superclasses of this hint. In theory, the cost of this search might
+    #   be circumventable by observing that this ABC is expected to reside
+    #   at the second-to-last index of the tuple exposing this MRO far all
+    #   generics by virtue of fragile implementation details violating
+    #   privacy encapsulation. In practice, this codebase is already
+    #   fragile enough.
+    # * The following logic superficially appears to implement the same
+    #   test *WITHOUT* the onerous cost of a search:
+    #       return len(get_hint_pep484_generic_bases_unerased_or_none(hint)) > 0
+    #   Why didn't we opt for that, then? Because this tester is routinely
+    #   passed objects that *CANNOT* be guaranteed to be PEP-compliant.
+    #   Indeed, the high-level is_hint_pep() tester establishing the
+    #   PEP-compliance of arbitrary objects internally calls this
+    #   lower-level tester to do so. Since the
+    #   get_hint_pep484_generic_bases_unerased_or_none() getter internally
+    #   reduces to returning the tuple of the general-purpose
+    #   "__orig_bases__" dunder attribute formalized by PEP 560, testing
+    #   whether that tuple is non-empty or not in no way guarantees this
+    #   object to be a PEP-compliant generic.
+    return is_type_subclass(hint, Generic)  # type: ignore[arg-type]
+
+# ....................{ GETTERS                            }....................
 @callable_cached
 def get_hint_pep484_generic_base_erased_from_unerased(hint: Any) -> type:
     '''
@@ -206,10 +143,10 @@ def get_hint_pep484_generic_base_erased_from_unerased(hint: Any) -> type:
 
     # Erased superclass originating this unerased pseudo-superclass if any *OR*
     # "None" otherwise.
-    hint_type_origin = get_hint_pep_origin_or_none(hint)
+    hint_origin_type = get_hint_pep_origin_or_none(hint)
 
     # If this hint originates from *NO* such superclass, raise an exception.
-    if hint_type_origin is None:
+    if hint_origin_type is None:
         raise BeartypeDecorHintPep484Exception(
             f'Unerased PEP 484 generic or PEP 544 protocol {repr(hint)} '
             f'originates from no erased superclass.'
@@ -217,7 +154,7 @@ def get_hint_pep484_generic_base_erased_from_unerased(hint: Any) -> type:
     # Else, this hint originates from such a superclass.
 
     # Return this superclass.
-    return hint_type_origin
+    return hint_origin_type
 
 
 @callable_cached
@@ -238,17 +175,16 @@ def get_hint_pep484_generic_bases_unerased(hint: Any) -> tuple:
 
     Returns
     ----------
-    Tuple[object]
+    tuple
         Tuple of the one or more unerased pseudo-superclasses of this
         :mod:`typing` generic. Specifically:
 
         * If this generic defines an ``__orig_bases__`` dunder instance
-          variable, the value of that variable.
+          variable, the value of that variable as is.
         * Else, the value of the ``__mro__`` dunder instance variable stripped
-          of all ignorable classes conveying no semantic meaning, including:
+          of all ignorable classes conveying *no* semantic meaning, including:
 
           * This generic itself.
-          * The :class:`typing.Generic` superclass.
           * The :class:`object` root superclass.
 
     Raises
@@ -266,6 +202,8 @@ def get_hint_pep484_generic_bases_unerased(hint: Any) -> tuple:
           #. The one or more :mod:`typing` objects directly subclassed by this
              generic.
           #. The :class:`typing.Generic` superclass.
+          #. The zero or more non-:mod:`typing` superclasses subsequently
+             subclassed by this generic (e.g., :class:`abc.ABC`).
           #. The :class:`object` root superclass.
 
     See Also
@@ -304,14 +242,14 @@ def get_hint_pep484_generic_bases_unerased(hint: Any) -> tuple:
     #        return hint_bases
     #
     #    # Fixed list of all typing super attributes to be returned.
-    #    superattrs = acquire_fixed_list(SIZE_BIG)
+    #    superattrs = acquire_fixed_list(FIXED_LIST_SIZE_MEDIUM)
     #
     #    # 0-based index of the last item of this list.
     #    superattrs_index = 0
     #
     #    # Fixed list of all transitive superclasses originally listed by this
     #    # class iterated in method resolution order (MRO).
-    #    hint_orig_mro = acquire_fixed_list(SIZE_BIG)
+    #    hint_orig_mro = acquire_fixed_list(FIXED_LIST_SIZE_MEDIUM)
     #
     #    # 0-based indices of the current and last items of this list.
     #    hint_orig_mro_index_curr = 0
@@ -341,13 +279,13 @@ def get_hint_pep484_generic_bases_unerased(hint: Any) -> tuple:
     #
     #            # If this class subclasses more than the maximum number of "typing"
     #            # attributes supported by this function, raise an exception.
-    #            if superattrs_index >= SIZE_BIG:
+    #            if superattrs_index >= FIXED_LIST_SIZE_MEDIUM:
     #                raise BeartypeDecorHintPep560Exception(
     #                    '{} PEP type {!r} subclasses more than '
     #                    '{} "typing" types.'.format(
     #                        exception_prefix,
     #                        hint,
-    #                        SIZE_BIG))
+    #                        FIXED_LIST_SIZE_MEDIUM))
     #        # Else, this superclass is *NOT* a typing attribute. In this case...
     #        else:
     #            # Tuple of all direct superclasses originally listed by this class
@@ -373,7 +311,7 @@ def get_hint_pep484_generic_bases_unerased(hint: Any) -> tuple:
     #    ----------
     #    BeartypeDecorHintPep560Exception
     #        If this object defines the ``__orig_bases__`` dunder attribute but that
-    #        attribute transitively lists :data:`SIZE_BIG` or more :mod:`typing`
+    #        attribute transitively lists :data:`FIXED_LIST_SIZE_MEDIUM` or more :mod:`typing`
     #        attributes.
     #
     #Specifically:
@@ -418,8 +356,7 @@ def get_hint_pep484_generic_bases_unerased(hint: Any) -> tuple:
     if hint_bases is not None:
         return hint_bases
     # Else, this generic erased *NONE* of its superclasses. These superclasses
-    # *MUST* by definition be unerased and thus safely returnable as is. In
-    # this case...
+    # *MUST* by definition be unerased and thus safely returnable as is.
 
     # Unerased superclasses of this generic defined by the method resolution
     # order (MRO) for this generic.
@@ -428,31 +365,38 @@ def get_hint_pep484_generic_bases_unerased(hint: Any) -> tuple:
     # Substring prefixing all exceptions raised below.
     EXCEPTION_STR_PREFIX = (
         f'PEP 484 generic {repr(hint)} '
-        f'method resolution order {repr(hint_bases)}'
+        f'method resolution order {repr(hint_bases)} '
     )
 
     # If this MRO lists strictly less than four classes, raise an exception.
     # The MRO for any unerased generic should list at least four classes:
     # * This class itself.
     # * The one or more "typing" objects directly subclassed by this generic.
-    # * The "typing.Generic" superclass.
+    # * The "typing.Generic" superclass. Note that this superclass is typically
+    #   but *NOT* necessarily the second-to-last superclass. Since this ad-hoc
+    #   heuristic is *NOT* an actual constraint, we intentionally avoid
+    #   asserting this to be the case. An example in which "typing.Generic" is
+    #   *NOT* the second-to-last superclass is:
+    #       class ProtocolCustomSuperclass(Protocol): pass
+    #       class ProtocolCustomABC(ProtocolCustomSuperclass, ABC): pass
     # * The "object" root superclass.
     if len(hint_bases) < 4:
         raise BeartypeDecorHintPep484Exception(
-            f'{EXCEPTION_STR_PREFIX} lists less than four classes.')
+            f'{EXCEPTION_STR_PREFIX}lists less than four types.')
     # Else, this MRO lists at least four classes.
     #
     # If any class listed by this MRO fails to comply with the above
     # expectations, raise an exception.
     elif hint_bases[0] != hint:
         raise BeartypeDecorHintPep484Exception(
-            f'{EXCEPTION_STR_PREFIX} first item not {hint}.')
-    elif hint_bases[-2] != Generic:
-        raise BeartypeDecorHintPep484Exception(
-            f'{EXCEPTION_STR_PREFIX} second-to-last item not {Generic}.')
+            f'{EXCEPTION_STR_PREFIX}first type '
+            f'{repr(hint_bases[0])} not {repr(hint)}.'
+        )
     elif hint_bases[-1] != object:
         raise BeartypeDecorHintPep484Exception(
-            f'{EXCEPTION_STR_PREFIX} last item not {object}.')
+            f'{EXCEPTION_STR_PREFIX}last type '
+            f'{repr(hint_bases[-1])} not {repr(object)}.'
+        )
     # Else, all classes listed by this MRO comply with the above expectations.
 
     # Return a slice of this tuple preserving *ONLY* the non-ignorable
@@ -460,6 +404,14 @@ def get_hint_pep484_generic_bases_unerased(hint: Any) -> tuple:
     # by this getter from the "__orig_bases__", which similarly lists *ONLY*
     # non-ignorable superclasses. Specifically, strip from this tuple:
     # * This class itself.
-    # * The "typing.Generic" superclass.
     # * The "object" root superclass.
-    return hint_bases[1:-2]
+    #
+    # Ideally, the ignorable "(beartype.|)typing.(Generic|Protocol)"
+    # superclasses would also be stripped. Sadly, as exemplified by the above
+    # counter-example, those superclasses are *NOT* guaranteed to occupy the
+    # third- and second-to-last positions (respectively) of this tuple. Ergo,
+    # stripping these superclasses safely would require an inefficient
+    # iterative O(n) search across this tuple for those superclasses. Instead,
+    # we defer ignoring these superclasses to the caller -- which necessarily
+    # already (and hopefully efficiently) ignores ignorable superclasses.
+    return hint_bases[1:-1]
