@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -11,31 +11,27 @@ reference type hints).
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
-import typing
+# ....................{ IMPORTS                            }....................
 from beartype.roar import BeartypeDecorHintForwardRefException
-from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_7
-from beartype._util.cache.utilcachecall import callable_cached
-from typing import Any
-
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ HINTS                             }....................
-# Conditionally define the "typing.ForwardRef" superclass depending on the
-# current Python version. This superclass was thankfully publicized under
-# Python >= 3.7 after its initial privatization under Python <= 3.6.
-HINT_PEP484_FORWARDREF_TYPE: Any = (
-    typing.ForwardRef if IS_PYTHON_AT_LEAST_3_7 else
-    typing._ForwardRef  # type: ignore [attr-defined]
+from beartype.typing import (
+    Any,
+    ForwardRef,
 )
+from beartype._util.cache.utilcachecall import callable_cached
+
+# ....................{ HINTS                              }....................
+#FIXME: Refactor this now-useless global away, please. Specifically:
+#* Globally replace all references to this global with references to
+#  "beartype.typing.ForwardRef" instead.
+#* Excise this global.
+HINT_PEP484_FORWARDREF_TYPE = ForwardRef
 '''
 :pep:`484`-compliant **forward reference type** (i.e., class of all forward
 reference objects implicitly created by all :mod:`typing` type hint factories
 when subscripted by a string).
 '''
 
-# ....................{ TESTERS                           }....................
+# ....................{ TESTERS                            }....................
 def is_hint_pep484_forwardref(hint: object) -> bool:
     '''
     ``True`` only if the passed object is a :pep:`484`-compliant **forward
@@ -68,7 +64,7 @@ def is_hint_pep484_forwardref(hint: object) -> bool:
     # forward reference superclass.
     return isinstance(hint, HINT_PEP484_FORWARDREF_TYPE)
 
-# ....................{ GETTERS                           }....................
+# ....................{ GETTERS                            }....................
 @callable_cached
 def get_hint_pep484_forwardref_type_basename(hint: Any) -> str:
     '''
