@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -11,13 +11,10 @@ subscriptions).
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
-from typing import Union
+# ....................{ IMPORTS                            }....................
+from beartype.typing import Union
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ MAKERS                            }....................
+# ....................{ MAKERS                             }....................
 def make_hint_pep484_union(hints: tuple) -> object:
     '''
     :pep:`484`-compliant **union type hint** (:attr:`typing.Union`
@@ -52,4 +49,4 @@ def make_hint_pep484_union(hints: tuple) -> object:
     assert isinstance(hints, tuple), f'{repr(hints)} not tuple.'
 
     # These are the one-liners of our lives.
-    return Union.__getitem__(hints)
+    return Union.__getitem__(hints)  # pyright: ignore[reportGeneralTypeIssues]
