@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -11,10 +11,20 @@ and :pep:`585`-compliant generic classes).
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from beartype.roar import BeartypeDecorHintPep484585Exception
+from beartype.typing import (
+    Optional,
+    Tuple,
+)
 from beartype._data.datatyping import TypeException
+from beartype._data.hint.pep.sign.datapepsigns import HintSignGeneric
 from beartype._util.cache.utilcachecall import callable_cached
+from beartype._util.cache.pool.utilcachepoollistfixed import (
+    FIXED_LIST_SIZE_MEDIUM,
+    acquire_fixed_list,
+    release_fixed_list,
+)
 from beartype._util.hint.pep.proposal.pep484.utilpep484generic import (
     get_hint_pep484_generic_bases_unerased,
     is_hint_pep484_generic,
@@ -23,12 +33,9 @@ from beartype._util.hint.pep.proposal.utilpep585 import (
     get_hint_pep585_generic_bases_unerased,
     is_hint_pep585_generic,
 )
-from typing import Optional, Tuple
+from collections.abc import Iterable
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ TESTERS                           }....................
+# ....................{ TESTERS                            }....................
 @callable_cached
 def is_hint_pep484585_generic(hint: object) -> bool:
     '''
@@ -93,7 +100,7 @@ def is_hint_pep484585_generic(hint: object) -> bool:
         is_hint_pep585_generic(hint)
     )
 
-# ....................{ GETTERS ~ bases                   }....................
+# ....................{ GETTERS ~ bases                    }....................
 def get_hint_pep484585_generic_bases_unerased(
     # Mandatory parameters.
     hint: object,
@@ -275,7 +282,8 @@ def get_hint_pep484585_generic_bases_unerased(
     #FIXME: Refactor get_hint_pep585_generic_bases_unerased() and
     #get_hint_pep484_generic_bases_unerased() to:
     #* Raise "BeartypeDecorHintPep484585Exception" instead.
-    #* Accept an optional "exception_prefix" parameter, which we should pass here.
+    #* Accept an optional "exception_prefix" parameter, which we should pass
+    #  here.
 
     # Tuple of either...
     #
@@ -309,7 +317,7 @@ def get_hint_pep484585_generic_bases_unerased(
     # Return this tuple of these pseudo-superclasses.
     return hint_pep_generic_bases_unerased
 
-# ....................{ GETTERS                           }....................
+# ....................{ GETTERS                            }....................
 #FIXME: Unit test us up, please.
 def get_hint_pep484585_generic_type(
     # Mandatory parameters.
@@ -321,12 +329,12 @@ def get_hint_pep484585_generic_type(
 ) -> type:
     '''
     Either the passed :pep:`484`- or :pep:`585`-compliant **generic** (i.e.,
-    class superficially subclassing at least one PEP-compliant type hint that
-    is possibly *not* an actual class) if **unsubscripted** (i.e., indexed by
-    *no* arguments or type variables), the unsubscripted generic underlying
-    this generic if **subscripted** (i.e., indexed by one or more child type
-    hints and/or type variables), *or* raise an exception otherwise (i.e., if
-    this hint is *not* a generic).
+    class superficially subclassing at least one PEP-compliant type hint that is
+    possibly *not* an actual class) if **unsubscripted** (i.e., indexed by *no*
+    arguments or type variables), the unsubscripted generic underlying this
+    generic if **subscripted** (i.e., indexed by one or more child type hints
+    and/or type variables), *or* raise an exception otherwise (i.e., if this
+    hint is *not* a generic).
 
     Specifically, this getter returns (in order):
 
@@ -463,3 +471,253 @@ def get_hint_pep484585_generic_type_or_none(hint: object) -> Optional[type]:
 
     # Return the "None" singleton.
     return None
+
+# ....................{ ITERATORS                          }....................
+#FIXME: Unit test us up, please.
+def iter_hint_pep484585_generic_bases_unerased_tree(
+    # Mandatory parameters.
+    hint: object,
+
+    # Optional parameters.
+    exception_cls: TypeException = BeartypeDecorHintPep484585Exception,
+    exception_prefix: str = '',
+) -> Iterable:
+    '''
+    Breadth-first search (BFS) generator iteratively yielding the one or more
+    unignorable unerased transitive pseudo-superclasses originally declared as
+    superclasses prior to their type erasure of the passed :pep:`484`- or
+    :pep:`585`-compliant generic.
+
+    This generator yields the full tree of all pseudo-superclasses by
+    transitively visiting both all direct pseudo-superclasses of this generic
+    *and* all indirect pseudo-superclasses transitively superclassing all direct
+    pseudo-superclasses of this generic. For efficiency, this generator is
+    internally implemented with an efficient imperative First In First Out
+    (FILO) queue rather than an inefficient (and dangerous, due to both
+    unavoidable stack exhaustion and avoidable infinite recursion) tree of
+    recursive function calls.
+
+    Motivation
+    ----------
+    Ideally, a BFS would *not* be necessary. Instead, pseudo-superclasses
+    visited by this BFS should be visitable as is via whatever external parent
+    BFS is currently iterating over the tree of all transitive type hints (e.g.,
+    our code generation algorithm implemented by the
+    :func:`beartype._check.expr.exprmake.make_func_wrapper_code` function).
+    That's how we transitively visit all other kinds of type hints, right?
+    Sadly, that simple solution fails to scale to all possible edge cases that
+    arise with generics. Why? Because our code generation algorithm sensibly
+    requires that *only* unignorable hints may be enqueued onto its outer BFS.
+    Generics confound that constraint. Some pseudo-superclasses are
+    paradoxically:
+
+    * Ignorable from the perspective of code generation. *No* type-checking code
+      should be generated for these pseudo-superclasses. See reasons below.
+    * Unignorable from the perspective of algorithm visitation. These
+      pseudo-superclasses generate *no* code but may themselves subclass other
+      pseudo-superclasses for which type-checking code should be generated and
+      which must thus be visited by our outer BFS.
+
+    Paradoxical pseudo-superclasses include:
+
+    * User-defined :pep:`484`-compliant subgenerics (i.e., user-defined generics
+      subclassing one or more parent user-defined generic superclasses).
+    * User-defined :pep:`544`-compliant subprotocols (i.e., user-defined
+      protocols subclassing one or more parent user-defined protocol
+      superclasses).
+
+    Consider this example :pep:`544`-compliant subprotocol:
+
+        >>> import typing as t
+        >>> class UserProtocol(t.Protocol[t.AnyStr]): pass
+        >>> class UserSubprotocol(UserProtocol[str], t.Protocol): pass
+        >>> UserSubprotocol.__orig_bases__
+        (UserProtocol[str], typing.Protocol)
+        >>> UserProtocolUnerased = UserSubprotocol.__orig_bases__[0]
+        >>> UserProtocolUnerased is UserProtocol
+        False
+        >>> isinstance(UserProtocolUnerased, type)
+        False
+
+    :pep:`585`-compliant generics suffer no such issues:
+
+        >>> from beartype._util.hint.pep.proposal.utilpep585 import is_hint_pep585_builtin
+        >>> class UserGeneric(list[int]): pass
+        >>> class UserSubgeneric(UserGeneric[int]): pass
+        >>> UserSubgeneric.__orig_bases__
+        (UserGeneric[int],)
+        >>> UserGenericUnerased = UserSubgeneric.__orig_bases__[0]
+        >>> isinstance(UserGenericUnerased, type)
+        True
+        >>> UserGenericUnerased.__mro__
+        (UserGeneric, list, object)
+        >>> is_hint_pep585_builtin(UserGenericUnerased)
+        True
+
+    Iteratively walking up the unerased inheritance hierarchy for any such
+    paradoxical generic or protocol subclass (e.g., ``UserSubprotocol`` but
+    *not* ``UserSubgeneric`` above) would visit a user-defined generic or
+    protocol pseudo-superclass subscripted by type variables. Due to poorly
+    defined obscurities in the :mod:`typing` implementation, that
+    pseudo-superclass is *not* actually a class but rather an instance of a
+    private :mod:`typing` class (e.g., :class:`typing._SpecialForm`). This
+    algorithm would then detect that pseudo-superclass as neither a generic nor
+    a :mod:`typing` object and thus raise an exception. Fortunately, that
+    pseudo-superclass conveys no meaningful intrinsic semantics with respect to
+    type-checking; its only use is to register its own pseudo-superclasses (one
+    or more of which could convey meaningful intrinsic semantics with respect to
+    type-checking) for visitation by this BFS.
+
+    Parameters
+    ----------
+    hint : object
+        Generic type hint to be inspected.
+    exception_cls : TypeException
+        Type of exception to be raised. Defaults to
+        :exc:`BeartypeDecorHintPep484585Exception`.
+    exception_prefix : str, optional
+        Human-readable substring prefixing the representation of this object in
+        the exception message. Defaults to the empty string.
+
+    Returns
+    ----------
+    Iterable
+        Breadth-first search (BFS) generator iteratively yielding the one or
+        more unignorable unerased transitive pseudo-superclasses originally
+        declared as superclasses prior to their type erasure of this generic.
+
+    Raises
+    ----------
+    :exc:`exception_cls`
+        If this hint is *not* a generic.
+
+    See Also
+    ----------
+    :func:`get_hint_pep484585_generic_type_or_none`
+        Further details.
+    '''
+
+    # Avoid circular import dependencies.
+    from beartype._util.hint.pep.proposal.utilpep585 import (
+        is_hint_pep585_builtin)
+    from beartype._util.hint.pep.utilpepget import get_hint_pep_sign_or_none
+    from beartype._util.hint.pep.utilpeptest import is_hint_pep_typing
+    from beartype._util.hint.utilhinttest import is_hint_ignorable
+
+    # Tuple of the one or more unerased pseudo-superclasses originally listed as
+    # superclasses prior to their type erasure by this generic.
+    hint_bases_direct = get_hint_pep484585_generic_bases_unerased(
+        hint=hint,
+        exception_cls=exception_cls,
+        exception_prefix=exception_prefix,
+    )
+    # print(f'generic {hint} hint_bases_direct: {hint_bases_direct}')
+
+    # Fixed list of the one or more unerased transitive pseudo-superclasses
+    # originally listed as superclasses prior to their type erasure by this
+    # generic that have yet to be visited by the breadth-first search (BFS) over
+    # these superclasses performed below.
+    hint_bases = acquire_fixed_list(size=FIXED_LIST_SIZE_MEDIUM)
+
+    # 0-based index of the currently visited pseudo-superclass of this list.
+    hint_bases_index_curr = 0
+
+    # 0-based index of one *PAST* the last pseudo-superclass of this list.
+    hint_bases_index_past_last = len(hint_bases_direct)
+
+    # Initialize this list to these direct pseudo-superclasses of this generic.
+    hint_bases[0:hint_bases_index_past_last] = hint_bases_direct
+    # print(f'generic pseudo-superclasses [initial]: {repr(hint_childs)}')
+
+    # While the 0-based index of the next visited pseudo-superclass does *NOT*
+    # exceed that of the last pseudo-superclass in this list, there remains one
+    # or more pseudo-superclasses to be visited in this BFS.
+    while hint_bases_index_curr < hint_bases_index_past_last:
+        # Currently visited pseudo-superclass.
+        hint_base = hint_bases[hint_bases_index_curr]
+        # print(f'generic {hint} base: {repr(hint_base)}')
+
+        # Sign uniquely identifying this pseudo-superclass if any *OR* "None".
+        hint_base_sign = get_hint_pep_sign_or_none(hint_base)
+
+        # If this pseudo-superclass is neither...
+        if not (
+            # A type conveying no meaningful typing semantics *NOR*...
+            #
+            # Note that types conveying no meaningful typing semantics are
+            # effectively ignorable. Why? Because the caller already type-checks
+            # this pith against the generic subclassing this superclass and thus
+            # this superclass as well in an isinstance() call (e.g., in the
+            # "PEP484585_CODE_HINT_GENERIC_PREFIX" snippet leveraged by the
+            # "beartype._check.expr.exprmake" submodule).
+            hint_base_sign is None or
+            # An ignorable PEP-compliant type hint...
+            is_hint_ignorable(hint_base)
+        # Then this pseudo-superclass is unignorable. In this case...
+        ):
+            #FIXME: Unit test up this branch, please.
+            # If this pseudo-superclass is...
+            if (
+                # A PEP-compliant generic *AND*...
+                hint_base_sign is HintSignGeneric and
+                # Is neither...
+                not (
+                    # A PEP 585-compliant superclass *NOR*...
+                    is_hint_pep585_builtin(hint_base) and
+                    # A PEP 484- nor 544-compliant superclass defined by the
+                    # "typing" module...
+                    is_hint_pep_typing(hint_base)
+                )
+            ):
+            # Then this pseudo-superclass is a user-defined PEP 484-compliant
+            # generic or 544-compliant protocol. In this case, generate *NO*
+            # type-checking code for this pseudo-superclass; we only enqueue all
+            # parent pseudo-superclasses of this pseudo-superclasses for
+            # visitation by later iteration of this inner BFS.
+            #
+            # See "hints_bases" for explanatory commentary.
+                # Tuple of the one or more parent pseudo-superclasses of this
+                # child pseudo-superclass.
+                hint_base_bases = (
+                    get_hint_pep484585_generic_bases_unerased(
+                        hint=hint_base,
+                        exception_cls=exception_cls,
+                        exception_prefix=exception_prefix,
+                    ))
+
+                # 0-based index of the last pseudo-superclass
+                # of this list *BEFORE* adding onto this list.
+                hint_bases_index_past_last_prev = (
+                    hint_bases_index_past_last)
+
+                # 0-based index of the last pseudo-superclass
+                # of this list *AFTER* adding onto this list.
+                hint_bases_index_past_last += len(hint_base_bases)
+
+                # Enqueue these superclasses onto this list.
+                hint_bases[
+                    hint_bases_index_past_last_prev:
+                    hint_bases_index_past_last
+                ] = hint_base_bases
+            # Else, this pseudo-superclass is neither an ignorable user-defined
+            # PEP 484-compliant generic *NOR* an ignorable 544-compliant
+            # protocol. In this case, yield this unignorable pseudo-superclass.
+            else:
+                yield hint_base
+        # Else, this pseudo-superclass is ignorable.
+        # else:
+        #     print(f'Ignoring generic {hint} base...')
+        #     print(f'Is generic {hint} base type? {isinstance(hint_base, type)}')
+
+        # Nullify the previously visited pseudo-superclass in
+        # this list for safety.
+        hint_bases[hint_bases_index_curr] = None
+
+        # Increment the 0-based index of the next visited
+        # pseudo-superclass in this list *BEFORE* visiting that
+        # pseudo-superclass but *AFTER* performing all other
+        # logic for the currently visited pseudo-superclass.
+        hint_bases_index_curr += 1
+
+    # Release this list. Pray for salvation, for we find none here.
+    release_fixed_list(hint_bases)
