@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -9,13 +9,10 @@ Project-wide :pep:`544`-compliant type hint utilities.
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from abc import abstractmethod
 from beartype.roar import BeartypeDecorHintPep544Exception
-from beartype._data.hint.pep.sign.datapepsigncls import HintSign
-from beartype._util.cls.utilclstest import is_type_builtin, is_type_subclass
-from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_8
-from typing import (
+from beartype.typing import (
     Any,
     BinaryIO,
     Dict,
@@ -23,11 +20,12 @@ from typing import (
     Optional,
     TextIO,
 )
+from beartype._data.hint.pep.sign.datapepsigncls import HintSign
+from beartype._data.mod.datamodtyping import TYPING_MODULE_NAMES_STANDARD
+from beartype._util.cls.utilclstest import is_type_builtin
+from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_8
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ PRIVATE ~ mappings                }....................
+# ....................{ PRIVATE ~ mappings                 }....................
 _HINTS_PEP484_IO_GENERIC = frozenset((IO, BinaryIO, TextIO,))
 '''
 Frozen set of all :mod:`typing` **IO generic base class** (i.e., either
@@ -46,9 +44,9 @@ by the :mod:`typing` module) to the associated :mod:`beartype` **IO protocol**
 defined by this submodule).
 '''
 
-# ....................{ PRIVATE ~ classes                 }....................
+# ....................{ PRIVATE ~ classes                  }....................
 # Conditionally initialized by the _init() function below.
-_Pep544IO: Any = None
+_Pep544IO: Any = None  # type: ignore[assignment]
 '''
 :pep:`544`-compliant protocol base class for :class:`_Pep544TextIO` and
 :class:`_Pep544BinaryIO`.
@@ -101,36 +99,58 @@ advertised (or at all)... *and no one ever will.*
 
 
 # Conditionally initialized by the _init() function below.
-_Pep544BinaryIO: Any = None
+_Pep544BinaryIO: Any = None  # type: ignore[assignment]
 '''
 Typed version of the return of open() in binary mode.
 '''
 
 
 # Conditionally initialized by the _init() function below.
-_Pep544TextIO: Any = None
+_Pep544TextIO: Any = None  # type: ignore[assignment]
 '''
 Typed version of the return of open() in text mode.
 '''
 
-# ....................{ TESTERS                           }....................
+# ....................{ TESTERS                            }....................
 # If the active Python interpreter targets at least Python >= 3.8 and thus
 # supports PEP 544, define these functions appropriately.
 if IS_PYTHON_AT_LEAST_3_8:
+    # Defer version-dependent imports.
+    from typing import Protocol
+
     def is_hint_pep544_ignorable_or_none(
         hint: object, hint_sign: HintSign) -> Optional[bool]:
 
-        # Return either:
-        # * If this hint is the "typing.Protocol" superclass directly
-        #   parametrized by one or more type variables (e.g.,
-        #   "typing.Protocol[S, T]"), true. Since this superclass can *ONLY* be
-        #   parametrized by type variables, a simple test suffices.
-        # * Else, "None".
+        # Machine-readable representation of this hint.
+        hint_repr = repr(hint)
+
+        #FIXME: *OPTIMIZE.* Would a compiled regex test be faster? Possibly,
+        #but possibly not. Regexes are notoriously slow -- even when compiled.
+        # For the fully-qualified name of each standard typing module (i.e.,
+        # modules whose "Protocol" superclass strictly conforms with the
+        # runtime behaviour of the standard "typing.Protocol" superclass).
         #
-        # For unknown and uninteresting reasons, *ALL* possible objects satisfy
-        # this superclass. Ergo, this superclass and *ALL* parametrizations of
-        # this superclass are synonymous with the "object" root superclass.
-        return repr(hint).startswith('typing.Protocol[') or None
+        # Note this intentionally omits the "typing_extensions.Protocol"
+        # superclass, which does *NOT* conform with the runtime behaviour of
+        # the standard "typing.Protocol" superclass.
+        for typing_module_name in TYPING_MODULE_NAMES_STANDARD:
+            # If this hint is the "Protocol" superclass directly parametrized
+            # by one or more type variables (e.g., "typing.Protocol[S, T]"),
+            # ignore this superclass by returning true. Since this superclass
+            # can *ONLY* be parametrized by type variables, a trivial string
+            # test suffices.
+            #
+            # For unknown and uninteresting reasons, *ALL* possible objects
+            # satisfy the "Protocol" superclass. Ergo, this superclass and
+            # *ALL* parametrizations of this superclass are synonymous with the
+            # "object" root superclass.
+            if hint_repr.startswith(f'{typing_module_name}.Protocol['):
+                return True
+
+        # Else, this hint is *NOT* the "Protocol" superclass directly
+        # parametrized by one or more type variables. In this case, continue
+        # testing this hint for other kinds of ignorable by returning None.
+        return None
 
 
     def is_hint_pep484_generic_io(hint: object) -> bool:
@@ -152,25 +172,30 @@ if IS_PYTHON_AT_LEAST_3_8:
 
     def is_hint_pep544_protocol(hint: object) -> bool:
 
-        # Defer version-dependent imports.
-        from typing import Protocol
-
         # Return true only if this hint is...
         return (
+            # A type *AND*...
+            isinstance(hint, type) and
             # A PEP 544-compliant protocol *AND*...
-            is_type_subclass(hint, Protocol) and  # type: ignore[arg-type]
+            issubclass(hint, Protocol) and  # type: ignore[arg-type]
             # *NOT* a builtin type. For unknown reasons, some but *NOT* all
             # builtin types erroneously present themselves to be PEP
             # 544-compliant protocols under Python >= 3.8: e.g.,
             #     >>> from typing import Protocol
-            #     >>> isinstance(str, Protocol)
+            #     >>> issubclass(str, Protocol)
             #     False        # <--- this makes sense
-            #     >>> isinstance(int, Protocol)
+            #     >>> issubclass(int, Protocol)
             #     True         # <--- this makes no sense whatsoever
             #
             # Since builtin types are obviously *NOT* PEP 544-compliant
             # protocols, explicitly exclude all such types. Why, Guido? Why?
-            not (isinstance(hint, type) and is_type_builtin(hint))
+            not is_type_builtin(
+                cls=hint,
+                # Do *NOT* ignore fake builtins for the purposes of this
+                # test. Why? Because even fake builtins (e.g., "type(None)")
+                # erroneously masquerade as PEP 544-compliant protocols! :o
+                is_ignore_fake=False,
+            )
         )
 
 
@@ -190,7 +215,7 @@ else:
     def is_hint_pep544_protocol(hint: object) -> bool:
         return False
 
-# ....................{ TESTERS ~ doc                     }....................
+# ....................{ TESTERS ~ doc                      }....................
 is_hint_pep544_ignorable_or_none.__doc__ = '''
     ``True`` only if the passed object is a :pep:`544`-compliant **ignorable
     type hint,** ``False`` only if this object is a :pep:`544`-compliant
@@ -246,9 +271,8 @@ is_hint_pep484_generic_io.__doc__ = '''
     the :mod:`typing` module effectively unusable at runtime due to botched
     implementation details) that is losslessly replaceable with a useful
     :pep:`544`-compliant :mod:`beartype` **IO protocol** (i.e., either
-    :class:`beartype._util.hint.pep.proposal.utilpep544._Pep544IO` itself
-    *or* a subclass of that class defined by this submodule intentionally
-    designed to be usable at runtime).
+    :class:`_Pep544IO` itself *or* a subclass of that class defined by this
+    submodule intentionally designed to be usable at runtime).
 
     This tester is intentionally *not* memoized (e.g., by the
     :func:`callable_cached` decorator), as the implementation trivially reduces
@@ -267,7 +291,7 @@ is_hint_pep484_generic_io.__doc__ = '''
 
     See Also
     ----------
-    :class:`beartype._util.hint.pep.proposal.utilpep544._Pep544IO`
+    :class:`_Pep544IO`
         Further commentary.
     '''
 
@@ -291,18 +315,17 @@ is_hint_pep544_protocol.__doc__ = '''
         ``True`` only if this object is a :pep:`544`-compliant protocol.
     '''
 
-# ....................{ REDUCERS                          }....................
+# ....................{ REDUCERS                           }....................
 def reduce_hint_pep484_generic_io_to_pep544_protocol(
     hint: Any, exception_prefix: str) -> Any:
     '''
     :pep:`544`-compliant :mod:`beartype` **IO protocol** (i.e., either
-    :class:`beartype._util.hint.pep.proposal.utilpep544._Pep544IO`
-    itself *or* a subclass of that class defined by this submodule
-    intentionally designed to be usable at runtime) corresponding to the passed
-    :pep:`484`-compliant :mod:`typing` **IO generic base class** (i.e., either
-    :class:`typing.IO` itself *or* a subclass of :class:`typing.IO` defined by
-    the :mod:`typing` module effectively unusable at runtime due to botched
-    implementation details).
+    :class:`_Pep544IO` itself *or* a subclass of that class defined by this
+    submodule intentionally designed to be usable at runtime) corresponding to
+    the passed :pep:`484`-compliant :mod:`typing` **IO generic base class**
+    (i.e., either :class:`typing.IO` itself *or* a subclass of
+    :class:`typing.IO` defined by the :mod:`typing` module effectively unusable
+    at runtime due to botched implementation details).
 
     This reducer is intentionally *not* memoized (e.g., by the
     :func:`callable_cached` decorator), as the implementation trivially reduces
@@ -393,13 +416,13 @@ def reduce_hint_pep484_generic_io_to_pep544_protocol(
     # Return this protocol.
     return pep544_protocol
 
-# ....................{ INITIALIZERS                      }....................
+# ....................{ INITIALIZERS                       }....................
 def _init() -> None:
     '''
     Initialize this submodule.
     '''
 
-    # ..................{ VERSIONS                          }..................
+    # ..................{ VERSIONS                           }..................
     # If the active Python interpreter only targets Python < 3.8 and thus fails
     # to support PEP 544, silently reduce to a noop.
     if not IS_PYTHON_AT_LEAST_3_8:
@@ -407,7 +430,7 @@ def _init() -> None:
     # Else, the active Python interpreter targets Python >= 3.8 and thus
     # supports PEP 593.
 
-    # ..................{ IMPORTS                           }..................
+    # ..................{ IMPORTS                            }..................
     # Defer Python version-specific imports.
     from beartype._util.mod.lib.utiltyping import import_typing_attr_or_none
     from beartype.typing import (
@@ -416,14 +439,14 @@ def _init() -> None:
         Protocol,
     )
 
-    # ..................{ GLOBALS                           }..................
+    # ..................{ GLOBALS                            }..................
     # Global attributes to be redefined below.
     global \
         _Pep544BinaryIO, \
         _Pep544IO, \
         _Pep544TextIO
 
-    # ..................{ PROTOCOLS ~ protocol              }..................
+    # ..................{ PROTOCOLS ~ protocol               }..................
     # Note that these classes are intentionally *NOT* declared at global scope;
     # instead, these classes are declared *ONLY* if the active Python
     # interpreter targets Python >= 3.8.
@@ -536,7 +559,7 @@ def _init() -> None:
 
         @property
         @abstractmethod
-        def buffer(self) -> _Pep544BinaryIO:
+        def buffer(self) -> _Pep544BinaryIO:  # pyright: ignore[reportGeneralTypeIssues]
             pass
 
         @property
@@ -563,7 +586,7 @@ def _init() -> None:
         def __enter__(self) -> '_Pep544TextIO':
             pass
 
-    # ..................{ PROTOCOLS ~ validator             }..................
+    # ..................{ PROTOCOLS ~ validator              }..................
     # PEP-compliant type hint matching file handles opened in binary rather
     # than text mode.
     #
@@ -630,7 +653,7 @@ def _init() -> None:
     # Else, this factory is unimportable. In this case, accept this hint's
     # default ambiguously matching both binary and text files.
 
-    # ..................{ MAPPINGS                          }..................
+    # ..................{ MAPPINGS                           }..................
     # Dictionary mapping from each "typing" IO generic base class to the
     # associated IO protocol defined above.
     #
