@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -11,14 +11,18 @@ hints).
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
-import typing
+# ....................{ IMPORTS                            }....................
 from beartype.meta import URL_ISSUES
 from beartype.roar import (
     BeartypeDecorHintPepException,
     BeartypeDecorHintPepSignException,
 )
+from beartype.typing import (
+    Any,
+    Optional,
+)
 from beartype._cave._cavefast import HintGenericSubscriptedType
+from beartype._data.datatyping import TypeException
 from beartype._data.hint.pep.datapeprepr import (
     HINT_REPR_PREFIX_ARGS_0_OR_MORE_TO_SIGN,
     HINT_REPR_PREFIX_ARGS_1_OR_MORE_TO_SIGN,
@@ -29,7 +33,6 @@ from beartype._data.hint.pep.sign.datapepsigns import (
     HintSignGeneric,
     HintSignNewType,
     HintSignTypedDict,
-    HintSignTypeVar,
 )
 from beartype._data.hint.pep.sign.datapepsignset import (
     HINT_SIGNS_ORIGIN_ISINSTANCEABLE,
@@ -44,15 +47,10 @@ from beartype._util.hint.pep.proposal.utilpep585 import (
 from beartype._util.py.utilpyversion import (
     IS_PYTHON_AT_MOST_3_9,
     IS_PYTHON_AT_LEAST_3_9,
-    IS_PYTHON_AT_LEAST_3_7,
 )
 from beartype._data.datatyping import TupleTypes
-from typing import Any, Optional
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ GETTERS ~ args                    }....................
+# ....................{ GETTERS ~ args                     }....................
 # If the active Python interpreter targets Python >= 3.9, implement this
 # getter to directly access the "__args__" dunder attribute.
 if IS_PYTHON_AT_LEAST_3_9:
@@ -70,61 +68,37 @@ if IS_PYTHON_AT_LEAST_3_9:
         # defines this attribute *OR* the empty tuple otherwise.
         hint_args = getattr(hint, '__args__', ())
 
-        # Return either...
-        return (
-            # If this hint appears to be unsubscripted but is PEP
-            # 585-compliant, then this hint *WAS* actually subscripted by the
-            # empty tuple (e.g., "tuple[()]"). For unknown reasons, the
-            # "HintGenericSubscriptedType" superclass erroneously reduces the
-            # empty tuple subscripting such hints to... literally nothing.
-            # Since doing so violates orthogonality with equivalent PEP
-            # 484-compliant type hints that do correctly preserve their
-            # arguments (e.g., "Tuple[()]"), we silently coerce PEP
-            # 585-compliant type hints to behave like PEP 484-compliant type
-            # hints by returning a tuple containing only the empty tuple.
-            _HINT_PEP585_ARGS_EMPTY_TUPLE
-            if (
-                not hint_args and isinstance(hint, HintGenericSubscriptedType)
-            ) else
-            # Else, return this tuple as is.
-            hint_args
-        )
-# Else if the active Python interpreter targets Python >= 3.7, implement this
-# getter to directly access the "__args__" dunder attribute.
-elif IS_PYTHON_AT_LEAST_3_7:
-    def get_hint_pep_args(hint: object) -> tuple:
+        # If this hint appears to be unsubscripted but is PEP 585-compliant,
+        # then this hint *WAS* actually subscripted by the empty tuple (e.g.,
+        # "tuple[()]"). For unknown reasons, the "HintGenericSubscriptedType"
+        # superclass erroneously reduces the empty tuple subscripting such hints
+        # to... literally nothing. Since doing so violates orthogonality with
+        # equivalent PEP 484-compliant type hints that do correctly preserve
+        # their arguments (e.g., "Tuple[()]"), silently coerce PEP 585-compliant
+        # type hints to behave like PEP 484-compliant type hints by returning a
+        # tuple containing only the empty tuple.
+        if not hint_args and isinstance(hint, HintGenericSubscriptedType):
+            return _HINT_PEP585_ARGS_EMPTY_TUPLE
+        # Else, this hint is either subscripted *OR* is unsubscripted but not
+        # PEP 585-compliant.
 
-        # Return the value of the "__args__" dunder attribute if this hint
-        # defines this attribute *OR* the empty tuple otherwise.
-        return getattr(hint, '__args__', ())
-#FIXME: Drop this like hot lead after dropping Python 3.6 support.
-# Else, the active Python interpreter targets Python 3.6. In this case...
-#
-# Gods... this is horrible. Thanks for nuthin', Python 3.6.
+        # In this case, return this tuple as is.
+        return hint_args
+# Else, the active Python interpreter targets Python < 3.9. In this case,
+# implement this getter to directly access the "__args__" dunder attribute.
 else:
     def get_hint_pep_args(hint: object) -> tuple:
 
-        # If this hint is a poorly designed Python 3.6-specific "type alias",
-        # this hint is a subscription of either the "typing.Match" or
-        # "typing.Pattern" objects. In this case, this hint declares a
-        # non-standard "type_var" instance variable whose value is either
-        # "typing.AnyStr", "str", or "bytes". Create and return a new 1-tuple
-        # containing only the value of this variable.
-        if isinstance(hint, typing._TypeAlias):  # type: ignore[attr-defined]
-            return (hint.type_var,)
-
+        # in python < 3.9, and unparametrized Generic would have the attribute
+        # `_special` set to True (but the actual __args__ are often a TypeVar).
+        # Because we want to differentiate between unparametrized and parametrized
+        # Generics, we check whether the hint is `_special` and if so, we return
+        # the empty tuple (instead of the TypeVar).
+        if getattr(hint, '_special', False):
+            return ()
         # Return the value of the "__args__" dunder attribute if this hint
         # defines this attribute *OR* the empty tuple otherwise.
-        #
-        # Note this hint is a poorly designed Python 3.6-specific "generic
-        # meta." In this case, this hint declares the standard "__args__"
-        # dunder attribute in a non-standard way. Specifically, the trailing
-        # "or ()" test below is needed to handle undocumented edge cases under
-        # the Python 3.6-specific "typing" implementation:
-        #     >>> import typing as t
-        #     >>> t.Tuple.__args__   # yes, this is total bullocks
-        #     None
-        return getattr(hint, '__args__', ()) or ()
+        return getattr(hint, '__args__', ())
 
 # Document this function regardless of implementation details above.
 get_hint_pep_args.__doc__ = '''
@@ -184,7 +158,7 @@ get_hint_pep_args.__doc__ = '''
         (int, str, typing.Dict[str, str])
     '''
 
-# ....................{ GETTERS ~ typevars                }....................
+# ....................{ GETTERS ~ typevars                 }....................
 # If the active Python interpreter targets Python >= 3.9, implement this
 # function to either directly access the "__parameters__" dunder attribute for
 # type hints that are not PEP 585-compliant generics *OR* to synthetically
@@ -211,9 +185,10 @@ if IS_PYTHON_AT_LEAST_3_9:
 
         # Return this attribute.
         return hint_pep_typevars
-# Else if the active Python interpreter targets Python >= 3.7, implement
-# this function to directly access the "__parameters__" dunder attribute.
-elif IS_PYTHON_AT_LEAST_3_7:
+# Else, the active Python interpreter targets Python < 3.9. In this case,
+# implement this function to directly access the "__parameters__" dunder
+# attribute.
+else:
     def get_hint_pep_typevars(hint: object) -> TupleTypes:
 
         # Value of the "__parameters__" dunder attribute on this object if this
@@ -227,42 +202,6 @@ elif IS_PYTHON_AT_LEAST_3_7:
         #   subclasses during PEP 560-style type erasure. Finally: they did
         #   something slightly right.
         return getattr(hint, '__parameters__', ())
-#FIXME: Drop this like hot lead after dropping Python 3.6 support.
-# Else, the active Python interpreter targets Python 3.6. In this case...
-#
-# Gods... this is horrible. Thanks for nuthin', Python 3.6.
-else:
-    def get_hint_pep_typevars(hint: object) -> TupleTypes:
-
-        # If this hint is a poorly designed Python 3.6-specific "type alias",
-        # this hint is a subscription of either the "typing.Match" or
-        # "typing.Pattern" objects. In this case, this hint declares a
-        # non-standard "type_var" instance variable whose value is either
-        # "typing.AnyStr", "str", or "bytes". Since only the former is an
-        # actual type variable, however, we further test that condition.
-        if isinstance(hint, typing._TypeAlias):  # type: ignore[attr-defined]
-            # Sign uniquely identifying this hint if any *OR* "None" otherwise.
-            hint_sign = get_hint_pep_sign_or_none(hint.type_var)
-
-            # If this value is a type variable, return a new 1-tuple containing
-            # only this type variable.
-            if hint_sign is HintSignTypeVar:
-                return (hint.type_var,)
-            # Else, this value is *NOT* a type variable. In this case, return
-            # the empty tuple.
-            else:
-                return ()
-
-        # Else, this hint is a poorly designed Python 3.6-specific "generic
-        # meta." In this case, this hint declares the standard
-        # "__parameters__" dunder instance variable in a non-standard way.
-        # Specifically, the trailing "or ()" test below is needed to handle
-        # undocumented edge cases under the Python 3.6-specific implementation
-        # of the "typing" module:
-        #       >>> import typing as t
-        #       >>> t.Union.__parameters__   # yes, this is total bullocks
-        #       None
-        return getattr(hint, '__parameters__', ()) or ()
 
 
 # Document this function regardless of implementation details above.
@@ -313,8 +252,15 @@ get_hint_pep_typevars.__doc__ = '''
         (T, S)
     '''
 
-# ....................{ GETTERS ~ sign                    }....................
-def get_hint_pep_sign(hint: Any) -> HintSign:
+# ....................{ GETTERS ~ sign                     }....................
+def get_hint_pep_sign(
+    # Mandatory parameters.
+    hint: object,
+
+    # Optional parameters.
+    exception_cls: TypeException = BeartypeDecorHintPepSignException,
+    exception_prefix: str = '',
+) -> HintSign:
     '''
     **Sign** (i.e., :class:`HintSign` instance) uniquely identifying the passed
     PEP-compliant type hint if PEP-compliant *or* raise an exception otherwise
@@ -328,6 +274,12 @@ def get_hint_pep_sign(hint: Any) -> HintSign:
     ----------
     hint : object
         Type hint to be inspected.
+    exception_cls : TypeException, optional
+        Type of exception to be raised. Defaults to
+        :exc:`BeartypeDecorHintPepSignException`.
+    exception_prefix : str, optional
+        Human-readable substring prefixing the representation of this object in
+        the exception message. Defaults to the empty string.
 
     Returns
     ----------
@@ -336,7 +288,7 @@ def get_hint_pep_sign(hint: Any) -> HintSign:
 
     Raises
     ----------
-    BeartypeDecorHintPepSignException
+    :exc:`exception_cls`
         If this hint is either:
 
         * PEP-compliant but *not* uniquely identifiable by a sign.
@@ -355,12 +307,14 @@ def get_hint_pep_sign(hint: Any) -> HintSign:
     # If this hint is unrecognized...
     if hint_sign is None:
         # Avoid circular import dependencies.
-        from beartype._util.hint.nonpep.utilnonpeptest import (
-            die_if_hint_nonpep)
+        from beartype._util.hint.nonpep.utilnonpeptest import die_if_hint_nonpep
 
         # If this hint is PEP-noncompliant, raise an exception.
         die_if_hint_nonpep(
-            hint=hint, exception_cls=BeartypeDecorHintPepSignException)
+            hint=hint,
+            exception_cls=exception_cls,
+            exception_prefix=exception_prefix,
+        )
         # Else, this hint is *NOT* PEP-noncompliant. Since this hint was
         # unrecognized, this hint *MUST* necessarily be a PEP-compliant type
         # hint currently unsupported by the @beartype decorator.
@@ -370,8 +324,9 @@ def get_hint_pep_sign(hint: Any) -> HintSign:
         # Note that we intentionally avoid calling the
         # die_if_hint_pep_unsupported() function here, which calls the
         # is_hint_pep_supported() function, which calls this function.
-        raise BeartypeDecorHintPepSignException(
-            f'Type hint {repr(hint)} currently unsupported by beartype. '
+        raise exception_cls(
+            f'{exception_prefix}type hint {repr(hint)} '
+            f'currently unsupported by beartype. '
             f'You suddenly feel encouraged to submit '
             f'a feature request for this hint to our '
             f'friendly issue tracker at:\n\t{URL_ISSUES}'
@@ -383,10 +338,6 @@ def get_hint_pep_sign(hint: Any) -> HintSign:
 
 
 #FIXME: Revise us up the docstring, most of which is now obsolete.
-#FIXME: Refactor as follows:
-#* Remove all now-unused "beartype._util.hint.pep.*" testers. Thanks to this
-#  dramatically simpler approach, we no longer require the excessive glut of
-#  PEP-specific testers we previously required.
 @callable_cached
 def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     '''
@@ -460,20 +411,20 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     ----------
         >>> import typing
         >>> from beartype._util.hint.pep.utilpepget import (
-        ...     get_hint_pep_sign)
-        >>> get_hint_pep_sign(typing.Any)
+        ...     get_hint_pep_sign_or_none)
+        >>> get_hint_pep_sign_or_none(typing.Any)
         typing.Any
-        >>> get_hint_pep_sign(typing.Union[str, typing.Sequence[int]])
+        >>> get_hint_pep_sign_or_none(typing.Union[str, typing.Sequence[int]])
         typing.Union
         >>> T = typing.TypeVar('T')
-        >>> get_hint_pep_sign(T)
+        >>> get_hint_pep_sign_or_none(T)
         HintSignTypeVar
         >>> class Genericity(typing.Generic[T]): pass
-        >>> get_hint_pep_sign(Genericity)
+        >>> get_hint_pep_sign_or_none(Genericity)
         HintSignGeneric
         >>> class Duplicity(typing.Iterable[T], typing.Container[T]): pass
-        >>> get_hint_pep_sign(Duplicity)
-        typing.Iterable
+        >>> get_hint_pep_sign_or_none(Duplicity)
+        HintSignGeneric
     '''
 
     # For efficiency, this tester identifies the sign of this type hint with
@@ -485,7 +436,7 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     # underlying all higher-level hint validation functions! Calling the latter
     # here would thus induce infinite recursion, which would be very bad.
     #
-    # ..................{ PHASE ~ classname                 }..................
+    # ..................{ PHASE ~ classname                  }..................
     # This phase attempts to map from the fully-qualified classname of this
     # hint to a sign identifying *ALL* hints that are instances of that class.
     #
@@ -532,7 +483,7 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
         return hint_sign
     # Else, this hint is *NOT* identifiable by its classname.
 
-    # ..................{ PHASE ~ repr                      }..................
+    # ..................{ PHASE ~ repr                       }..................
     # This phase attempts to map from the unsubscripted machine-readable
     # representation of this hint to a sign identifying *ALL* hints of that
     # representation.
@@ -554,8 +505,7 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     hint_repr_prefix, hint_repr_subscripted, _ = repr(hint).partition('[')
 
     # Sign identifying this possibly unsubscripted hint if this hint is
-    # identifiable by its possibly unsubscripted representation *OR* "None"
-    # otherwise.
+    # identifiable by its possibly unsubscripted representation *OR* "None".
     hint_sign = HINT_REPR_PREFIX_ARGS_0_OR_MORE_TO_SIGN.get(hint_repr_prefix)
 
     # If this hint is identifiable by its possibly unsubscripted
@@ -581,7 +531,7 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
         # representation.
     # Else, this representation (and thus this hint) is unsubscripted.
 
-    # ..................{ PHASE ~ manual                    }..................
+    # ..................{ PHASE ~ manual                     }..................
     # This phase attempts to manually identify the signs of all hints *NOT*
     # efficiently identifiably by the prior phases.
     #
@@ -650,68 +600,13 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     elif IS_PYTHON_AT_MOST_3_9 and is_hint_pep484_newtype_pre_python310(hint):
         return HintSignNewType
 
-    # ..................{ ERROR                             }..................
+    # ..................{ ERROR                              }..................
     # Else, this hint is unrecognized. In this case, return "None".
     return None
 
-# ....................{ GETTERS ~ origin                  }....................
-# If the active Python interpreter targets at least Python >= 3.7, implement
-# this function to access the standard "__origin__" dunder instance variable
-# whose value is the origin type originating this hint.
-if IS_PYTHON_AT_LEAST_3_7:
-    def get_hint_pep_origin_or_none(hint: Any) -> Optional[Any]:
-
-        # Return this hint's origin object if any *OR* "None" otherwise.
-        return getattr(hint, '__origin__', None)
-
-#FIXME: Drop this like hot lead after dropping Python 3.6 support.
-# Else, the active Python interpreter targets Python 3.6. In this case...
-#
-# Gods... this is horrible. Thanks for nuthin', Python 3.6.
-else:
-    from beartype._util.utilobject import SENTINEL
-
-    def get_hint_pep_origin_or_none(hint: Any) -> Optional[Any]:
-
-        # If this hint is a poorly designed Python 3.6-specific "type
-        # alias", this hint is a subscription of either the "typing.Match"
-        # or "typing.Pattern" objects. In this case, this hint declares a
-        # non-standard "impl_type" instance variable whose value is either
-        # the "re.Match" or "re.Pattern" class. Return that class.
-        if isinstance(hint, typing._TypeAlias):  # type: ignore[attr-defined]
-            return hint.impl_type
-
-        # This hint's origin object if any *OR* "None" otherwise.
-        #
-        # If this hint is a poorly designed Python 3.6-specific "generic meta,"
-        # this hint declares a non-standard "__extra__" dunder instance
-        # variable whose value is the origin object originating this hint. The
-        # "__origin__" dunder instance variable *DOES* exist under Python 3.6
-        # but is typically the identity class referring to the same "typing"
-        # singleton (e.g., "typing.List" for "typing.List[int]") rather than
-        # the origin type (e.g., "list" for "typing.List[int]") and is thus
-        # completely useless for everything.
-        #
-        # Note that we intentionally avoid defaulting "hint_extra" to "None"
-        # if that attribute is undefined. Under Python 3.6, user-defined PEP
-        # 484-compliant generics define:
-        # * "hint.__extra__" to be "None".
-        # * "hint.__origin__" to be the desired origin.
-        #
-        # Altogether, this means we *MUST* distinguish these two cases with a
-        # sentinel placeholder that is explicitly *NOT* "None".
-        #
-        # Welcome to Typing Hell. We hope you really enjoy pain, because... I
-        # mean, just look around.
-        hint_extra = getattr(hint, '__extra__', SENTINEL)
-        return (
-            hint_extra
-            if hint_extra is not None else
-            getattr(hint, '__origin__', None)
-        )
-
-# Document this function regardless of implementation details above.
-get_hint_pep_origin_or_none.__doc__ = '''
+# ....................{ GETTERS ~ origin                   }....................
+def get_hint_pep_origin_or_none(hint: Any) -> Optional[Any]:
+    '''
     **Unsafe origin object** (i.e., arbitrary object possibly related to the
     passed PEP-compliant type hint but *not* necessarily a non-:mod:`typing`
     class such that *all* objects satisfying this hint are instances of this
@@ -724,7 +619,7 @@ get_hint_pep_origin_or_none.__doc__ = '''
 
     Caveats
     ----------
-    **The high-level** :func:`get_hint_pep_type_isinstanceable_or_none`
+    **The high-level** :func:`get_hint_pep_origin_type_isinstanceable`
     function should always be called in lieu of this low-level function.**
     Whereas the former is guaranteed to return either a class or ``None``, this
     function enjoys no such guarantees and instead returns what the caller can
@@ -763,18 +658,18 @@ get_hint_pep_origin_or_none.__doc__ = '''
     ----------
         >>> import typing
         >>> from beartype._util.hint.pep.utilpepget import (
-        ...     get_hint_pep_origin_type_unsafe_or_none)
+        ...     get_hint_pep_origin_or_none)
         # This is sane.
-        >>> get_hint_pep_origin_type_unsafe_or_none(typing.List)
+        >>> get_hint_pep_origin_or_none(typing.List)
         list
-        >>> get_hint_pep_origin_type_unsafe_or_none(typing.List[int])
+        >>> get_hint_pep_origin_or_none(typing.List[int])
         list
-        >>> get_hint_pep_origin_type_unsafe_or_none(typing.Union)
+        >>> get_hint_pep_origin_or_none(typing.Union)
         None
-        >>> get_hint_pep_origin_type_unsafe_or_none(typing.Union[int])
+        >>> get_hint_pep_origin_or_none(typing.Union[int])
         None
         # This is insane.
-        >>> get_hint_pep_origin_type_unsafe_or_none(typing.Union[int, str])
+        >>> get_hint_pep_origin_or_none(typing.Union[int, str])
         Union
         # This is crazy.
         >>> typing.Union.__origin__
@@ -787,7 +682,10 @@ get_hint_pep_origin_or_none.__doc__ = '''
         typing.Union
     '''
 
-# ....................{ GETTERS ~ origin : type           }....................
+    # Return this hint's origin object if any *OR* "None" otherwise.
+    return getattr(hint, '__origin__', None)
+
+# ....................{ GETTERS ~ origin : type            }....................
 def get_hint_pep_origin_type_isinstanceable(hint: object) -> type:
     '''
     **Isinstanceable origin type** (i.e., class passable as the second argument
@@ -817,12 +715,12 @@ def get_hint_pep_origin_type_isinstanceable(hint: object) -> type:
 
     See Also
     ----------
-    :func:`get_hint_pep_type_isinstanceable_or_none`
+    :func:`get_hint_pep_origin_type_isinstanceable_or_none`
         Related getter.
     '''
 
     # Origin type originating this object if any *OR* "None" otherwise.
-    hint_origin_type = get_hint_pep_type_isinstanceable_or_none(hint)
+    hint_origin_type = get_hint_pep_origin_type_isinstanceable_or_none(hint)
 
     # If this type does *NOT* exist, raise an exception.
     if hint_origin_type is None:
@@ -836,7 +734,7 @@ def get_hint_pep_origin_type_isinstanceable(hint: object) -> type:
     return hint_origin_type
 
 
-def get_hint_pep_type_isinstanceable_or_none(
+def get_hint_pep_origin_type_isinstanceable_or_none(
     hint: Any) -> Optional[type]:
     '''
     **Standard origin type** (i.e., isinstanceable class declared by Python's
