@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -10,42 +10,34 @@ validating arbitrary objects to be PEP-compliant type hints).
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from beartype.roar import (
     BeartypeDecorHintPepException,
     BeartypeDecorHintPepUnsupportedException,
     BeartypeDecorHintPep484Exception,
     BeartypeDecorHintPep585DeprecationWarning,
 )
-from beartype._util.cache.utilcachecall import callable_cached
+from beartype.typing import NoReturn
+from beartype._data.datatyping import TypeException
 from beartype._data.hint.pep.datapeprepr import (
     HINTS_PEP484_REPR_PREFIX_DEPRECATED)
 from beartype._data.hint.pep.sign.datapepsignset import (
     HINT_SIGNS_SUPPORTED,
     HINT_SIGNS_TYPE_MIMIC,
 )
-from beartype._data.mod.datamod import TYPING_MODULE_NAMES
+from beartype._data.mod.datamodtyping import TYPING_MODULE_NAMES
+from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.hint.pep.proposal.pep484.utilpep484 import (
-    is_hint_pep484_ignorable_or_none,
-)
+    is_hint_pep484_ignorable_or_none)
 from beartype._util.hint.pep.proposal.utilpep544 import (
     is_hint_pep544_ignorable_or_none)
 from beartype._util.hint.pep.proposal.utilpep593 import (
     is_hint_pep593_ignorable_or_none)
-from beartype._util.mod.utilmodule import (
-    get_object_module_name,
-    get_object_module_name_or_none,
-)
-from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_7
+from beartype._util.mod.utilmodget import get_object_module_name_or_none
 from beartype._util.utilobject import get_object_type_unless_type
-from beartype._data.datatyping import TypeException
-from typing import NoReturn
 from warnings import warn
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ CONSTANTS                         }....................
+# ....................{ CONSTANTS                          }....................
 _IS_HINT_PEP_IGNORABLE_TESTERS = (
     is_hint_pep484_ignorable_or_none,
     is_hint_pep544_ignorable_or_none,
@@ -67,13 +59,13 @@ Each such function is expected to return either:
 
 * If the passed object is fully compliant with that PEP:
 
-    * If this object is a ignorable, ``True``.
+    * If this object is ignorable, ``True``.
     * Else, ``False``.
 
 * If this object is *not* fully compliant with that PEP, ``None``.
 '''
 
-# ....................{ EXCEPTIONS                        }....................
+# ....................{ EXCEPTIONS                         }....................
 def die_if_hint_pep(
     # Mandatory parameters.
     hint: object,
@@ -164,7 +156,7 @@ def die_unless_hint_pep(
         raise exception_cls(
             f'{exception_prefix}type hint {repr(hint)} not PEP-compliant.')
 
-# ....................{ EXCEPTIONS ~ supported            }....................
+# ....................{ EXCEPTIONS ~ supported             }....................
 #FIXME: *DANGER.* This function makes beartype more fragile. Instead, refactor
 #all or most calls to this function into calls to the
 #warn_if_hint_pep_unsupported() function; then, consider excising this as well
@@ -213,7 +205,7 @@ def die_if_hint_pep_unsupported(
     BeartypeDecorHintPep484Exception
         If this object is the PEP-compliant :attr:`typing.NoReturn` type hint,
         which is contextually valid in only a single use case and thus
-        supported externally by the :mod:`beartype._decor._code.codemain`
+        supported externally by the :mod:`beartype._decor._wrapper.wrappermain`
         submodule rather than with general-purpose automation.
     '''
 
@@ -238,23 +230,23 @@ def die_if_hint_pep_unsupported(
     # *ONLY* as a return annotation, raise an exception specific to this hint.
     if hint is NoReturn:
         raise BeartypeDecorHintPep484Exception(
-            f'{exception_prefix}return type hint {repr(hint)} invalid (i.e., '
+            f'{exception_prefix}return type hint "{repr(hint)}" invalid (i.e., '
             f'"typing.NoReturn" valid only as non-nested return annotation).'
         )
     # Else, this is any PEP-compliant type hint other than "typing.NoReturn".
+
     # In this case, raise a general-purpose exception.
     #
-    # Note that, by definition, the sign uniquely identifying this hint
-    # *SHOULD* be in the "HINT_SIGNS_SUPPORTED" set. Regardless of whether
-    # it is or isn't, we raise a similar exception. Ergo, there's no benefit to
-    # validating that expectation here.
-    else:
-        raise BeartypeDecorHintPepUnsupportedException(
-            f'{exception_prefix}type hint {repr(hint)} '
-            f'currently unsupported by @beartype.'
-        )
+    # Note that, by definition, the sign uniquely identifying this hint *SHOULD*
+    # be in the "HINT_SIGNS_SUPPORTED" set. Regardless of whether it is or not,
+    # we raise a similar exception in either case. Ergo, there is *NO* practical
+    # benefit to validating that expectation here.
+    raise BeartypeDecorHintPepUnsupportedException(
+        f'{exception_prefix}type hint {repr(hint)} '
+        f'currently unsupported by @beartype.'
+    )
 
-# ....................{ WARNINGS                          }....................
+# ....................{ WARNINGS                           }....................
 #FIXME: Resurrect support for the passed "warning_prefix" parameter. We've
 #currently disabled this parameter as it's typically just a non-human-readable
 #placeholder substring *NOT* intended to be exposed to end users (e.g.,
@@ -288,7 +280,7 @@ def warn_if_hint_pep_deprecated(
 
     Warns
     ----------
-    :class:`BeartypeDecorHintPep585DeprecationWarning`
+    BeartypeDecorHintPep585DeprecationWarning
         If this hint is a :pep:`484`-compliant type hint deprecated by
         :pep:`585` *and* the active Python interpreter targets Python >= 3.9.
     '''
@@ -314,6 +306,42 @@ def warn_if_hint_pep_deprecated(
     # equivalent PEP 585-compliant type hint (e.g., "list[int]"). In this case,
     # emit a non-fatal PEP 585-specific deprecation warning.
     if hint_bare_repr in HINTS_PEP484_REPR_PREFIX_DEPRECATED:
+        #FIXME: Resolve issue #73 by additionally passing the "stacklevel"
+        #keyword parameter. Doing so will probably require:
+        #* Refactoring this function to accept an *OPTIONAL*
+        #  "warning_stack_level" parameter. Why optional? Because this
+        #  parameter is only reliably decidable under Python interpreters
+        #  defining the implementation-specific sys._getframe() function, which
+        #  is admittedly all of them everyone cares about. Nonetheless, do this
+        #  right. If non-"None", conditionally pass this level below as:
+        #      stacklevel=(
+        #          warning_stack_level
+        #          if warning_stack_level is not None else
+        #          1  # <-- the official default value for this parameter
+        #      ),
+        #* Refactoring all callers of this function to pass that parameter.
+        #  Here's where things get dicey, however. Passing this parameter
+        #  reliably (so, *NOT* just hard-coding a magic number somewhere and
+        #  praying devoutly for the best) will require computing the distance
+        #  between the current function and the first external third-party
+        #  non-@beartype scope on the call stack. So, maybe we want to actually
+        #  *NOT* refactor this function to accept an *OPTIONAL*
+        #  "warning_stack_level" parameter but instead locally define
+        #  "warning_stack_level" based on an iterative O(n) search up the
+        #  stack? That's obviously non-ideal -- but still absolutely preferable
+        #  to the current untenable situation of emitting unreadable warnings.
+        #
+        #Okay. So, scrap everything above. Let's instead:
+        #* Define a new warn_safe() wrapper function (somewhere in
+        #  "beartype._util", clearly) that automatically decides the
+        #  appropriate "stacklevel" by iterating up the call stack to compute
+        #  the distance between the current function and the first external
+        #  third-party non-@beartype scope. We perform similar iteration when
+        #  resolving PEP 563-based deferred annotations, so that would probably
+        #  be the first place to clean inspiration. That code is rock solid and
+        #  well-tested. Things get non-trivial fast here, sadly. *sigh*
+        #
+        #See also: https://docs.python.org/3/library/warnings.html#warnings.warn
         warn(
             (
                 f'PEP 484 type hint {repr(hint)} deprecated by PEP 585 '
@@ -399,7 +427,7 @@ def warn_if_hint_pep_deprecated(
 #     # Return true only if this object is a supported PEP-compliant type hint.
 #     return is_hint_pep_supported_test
 
-# ....................{ TESTERS                           }....................
+# ....................{ TESTERS                            }....................
 def is_hint_pep(hint: object) -> bool:
     '''
     ``True`` only if the passed object is a **PEP-compliant type hint** (i.e.,
@@ -447,7 +475,7 @@ def is_hint_pep(hint: object) -> bool:
     # a PEP-compliant type hint.
     return get_hint_pep_sign_or_none(hint) is not None
 
-# ....................{ TESTERS ~ ignorable               }....................
+# ....................{ TESTERS ~ ignorable                }....................
 def is_hint_pep_ignorable(hint: object) -> bool:
     '''
     ``True`` only if the passed object is a **deeply ignorable PEP-compliant
@@ -526,7 +554,7 @@ def is_hint_pep_ignorable(hint: object) -> bool:
     # Else, this hint is *NOT* deeply ignorable. In this case, return false.
     return False
 
-# ....................{ TESTERS ~ supported               }....................
+# ....................{ TESTERS ~ supported                }....................
 @callable_cached
 def is_hint_pep_supported(hint: object) -> bool:
     '''
@@ -573,13 +601,12 @@ def is_hint_pep_supported(hint: object) -> bool:
     # Return true only if this sign is supported.
     return hint_sign in HINT_SIGNS_SUPPORTED
 
-# ....................{ TESTERS ~ typing                  }....................
+# ....................{ TESTERS ~ typing                   }....................
 #FIXME: Replace all hardcoded "'typing" strings throughout the codebase with
-#access of "TYPING_MODULE_NAMES" instead. We only see two remaining in:
-#* beartype/_util/hint/pep/proposal/utilpep544.py
+#access of "TYPING_MODULE_NAMES" instead. We only see one remaining in:
 #* beartype._util.hint.pep.proposal.pep484.utilpep484.py
-#Thankfully, nobody really cares about generalizing these two edge cases to
-#"testing_extensions", so they're mostly fine for various definitions of fine.
+#Thankfully, nobody really cares about generalizing this one edge case to
+#"testing_extensions", so it's mostly fine for various definitions of fine.
 @callable_cached
 def is_hint_pep_typing(hint: object) -> bool:
     '''
@@ -617,106 +644,8 @@ def is_hint_pep_typing(hint: object) -> bool:
     )
 
 
-# If the active Python interpreter targets at least Python 3.7 and is thus
-# sane enough to support the normal implementation of this tester, do so.
-if IS_PYTHON_AT_LEAST_3_7:
-    def is_hint_pep_type_typing(hint: object) -> bool:
-
-        # This hint if this hint is a class *OR* this hint's class otherwise.
-        hint_type = get_object_type_unless_type(hint)
-        # print(f'pep_type_typing({repr(hint)}): {get_object_module_name(hint_type)}')
-
-        # Return true only if this type is defined by a typing module.
-        #
-        # Note that this implementation could probably be reduced to the
-        # leading portion of the body of the get_hint_pep_sign_or_none()
-        # function testing this object's representation. While certainly more
-        # compact and convenient than the current approach, that refactored
-        # approach would also be considerably more fragile, failure-prone, and
-        # subject to whimsical "improvements" in the already overly hostile
-        # "typing" API. Why? Because the get_hint_pep_sign_or_none() function:
-        # * Parses the machine-readable string returned by the __repr__()
-        #   dunder method of "typing" types. Since that string is *NOT*
-        #   standardized by PEP 484 or any other PEP, "typing" authors remain
-        #   free to violate this pseudo-standard in any manner and at any time
-        #   of their choosing.
-        # * Suffers common edge cases for "typing" types whose __repr__()
-        #   dunder methods fail to comply with the non-standard implemented by
-        #   their sibling types. This includes the common "TypeVar" type.
-        # * Calls this tester function to decide whether the passed object is a
-        #   PEP-compliant type hint or not before subjecting that object to
-        #   further introspection, which would clearly complicate implementing
-        #   this tester function in terms of that getter function.
-        #
-        # In contrast, the current approach only tests the standard
-        # "__module__" dunder attribute and is thus significantly more robust
-        # against whimsical destruction by "typing" authors. Note that there
-        # might exist an alternate means of deciding this boolean, documented
-        # here merely for completeness:
-        #     try:
-        #         isinstance(obj, object)
-        #         return False
-        #     except TypeError as type_error:
-        #         return str(type_error).endswith(
-        #             'cannot be used with isinstance()')
-        #
-        # The above effectively implements an Aikido throw by using the fact
-        # that "typing" types prohibit isinstance() calls against those types.
-        # While clever (and deliciously obnoxious), the above logic:
-        # * Requires catching exceptions in the common case and is thus *MUCH*
-        #   less efficient than the preferable approach implemented here.
-        # * Assumes that *ALL* "typing" types prohibit such calls. Sadly, only
-        #   a proper subset of these types prohibit such calls.
-        # * Assumes that those "typing" types that do prohibit such calls raise
-        #   exceptions with reliable messages across *ALL* Python versions.
-        #
-        # In short, there is no general-purpose clever solution. *sigh*
-        return hint_type.__module__ in TYPING_MODULE_NAMES
-# Else, the active Python interpreter targets exactly Python 3.6. In this case,
-# define this tester to circumvent Python 3.6-specific issues. Notably, the
-# implementation of the "typing" module under this major version harmfully
-# modifies the fully-qualified module names advertised by some but *NOT* all
-# "collections.abc" superclasses to be "typing" rather than "collections.abc".
-# This absolute insanity appears to have something inexplicable to do with
-# internal misuse of the private "collections.abc" caches by this
-# implementation of the "typing" module. Although the exact cause is unclear,
-# the resolution is simply to explicitly test for and reject "collections.abc"
-# superclasses passed to this Python 3.6-specific tester implementation.
-else:
-    def is_hint_pep_type_typing(hint: object) -> bool:
-
-        # This hint if this hint is a class *OR* this hint's class otherwise.
-        hint_type = get_object_type_unless_type(hint)
-        # print(f'pep_type_typing({repr(hint)}): {repr(hint_type)} {repr(get_object_module_name(hint_type))}')
-
-        # Return true only if...
-        return (
-            # This type pretends to be defined by a typing module *AND*...
-            get_object_module_name(hint_type) in TYPING_MODULE_NAMES and
-            # This type is *NOT* actually a superclass defined by the
-            # "collections.abc" submodule. Ideally, we would simply uncomment
-            # the following test:
-            #     not (
-            #         isinstance(hint, type) and
-            #         getattr(collections_abc, hint.__name__, None) is hint
-            #     )
-            #
-            # Insanely, that seemingly sane test returns false positives for
-            # both "typing.Hashable" and "typing.Sized", which appear to be
-            # literally replacing "collections.abc.Hashable" and
-            # "collections.abc.Sized" with themselves... somehow.
-            #
-            # Equally insanely, "typing.Generator" retains a sane
-            # representation when accessed as "typing.Generator" but *NOT* when
-            # accessed as "collections.abc.Generator" -- the latter of which
-            # returns this insane representation. Ergo, we explicitly detect
-            # and reject the latter. We have no idea what's happening here and
-            # can only wish for the hasty death of Python 3.6. So much rage.
-            repr(hint) != "<class 'typing.Generator'>"
-        )
-
-
-is_hint_pep_type_typing.__doc__ = '''
+def is_hint_pep_type_typing(hint: object) -> bool:
+    '''
     ``True`` only if either the passed object is defined by a **typing module**
     (i.e., module officially declaring attributes usable for creating
     PEP-compliant type hints accepted by both static and runtime type checkers)
@@ -741,7 +670,58 @@ is_hint_pep_type_typing.__doc__ = '''
         * Else, the class of this object is defined by a typing module.
     '''
 
-# ....................{ TESTERS ~ args                    }....................
+    # This hint if this hint is a class *OR* this hint's class otherwise.
+    hint_type = get_object_type_unless_type(hint)
+    # print(f'pep_type_typing({repr(hint)}): {get_object_module_name(hint_type)}')
+
+    # Return true only if this type is defined by a typing module.
+    #
+    # Note that this implementation could probably be reduced to the
+    # leading portion of the body of the get_hint_pep_sign_or_none()
+    # function testing this object's representation. While certainly more
+    # compact and convenient than the current approach, that refactored
+    # approach would also be considerably more fragile, failure-prone, and
+    # subject to whimsical "improvements" in the already overly hostile
+    # "typing" API. Why? Because the get_hint_pep_sign_or_none() function:
+    # * Parses the machine-readable string returned by the __repr__()
+    #   dunder method of "typing" types. Since that string is *NOT*
+    #   standardized by PEP 484 or any other PEP, "typing" authors remain
+    #   free to violate this pseudo-standard in any manner and at any time
+    #   of their choosing.
+    # * Suffers common edge cases for "typing" types whose __repr__()
+    #   dunder methods fail to comply with the non-standard implemented by
+    #   their sibling types. This includes the common "TypeVar" type.
+    # * Calls this tester function to decide whether the passed object is a
+    #   PEP-compliant type hint or not before subjecting that object to
+    #   further introspection, which would clearly complicate implementing
+    #   this tester function in terms of that getter function.
+    #
+    # In contrast, the current approach only tests the standard
+    # "__module__" dunder attribute and is thus significantly more robust
+    # against whimsical destruction by "typing" authors. Note that there
+    # might exist an alternate means of deciding this boolean, documented
+    # here merely for completeness:
+    #     try:
+    #         isinstance(obj, object)
+    #         return False
+    #     except TypeError as type_error:
+    #         return str(type_error).endswith(
+    #             'cannot be used with isinstance()')
+    #
+    # The above effectively implements an Aikido throw by using the fact
+    # that "typing" types prohibit isinstance() calls against those types.
+    # While clever (and deliciously obnoxious), the above logic:
+    # * Requires catching exceptions in the common case and is thus *MUCH*
+    #   less efficient than the preferable approach implemented here.
+    # * Assumes that *ALL* "typing" types prohibit such calls. Sadly, only
+    #   a proper subset of these types prohibit such calls.
+    # * Assumes that those "typing" types that do prohibit such calls raise
+    #   exceptions with reliable messages across *ALL* Python versions.
+    #
+    # In short, there is no general-purpose clever solution. *sigh*
+    return hint_type.__module__ in TYPING_MODULE_NAMES
+
+# ....................{ TESTERS ~ args                     }....................
 #FIXME: Overkill. Replace directly with a simple test, please.
 #
 #Note that the corresponding unit test should be preserved, as that test is
@@ -786,7 +766,7 @@ def is_hint_pep_args(hint: object) -> bool:
     # Return true only if this hint is subscripted by one or more arguments.
     return bool(get_hint_pep_args(hint))
 
-# ....................{ TESTERS ~ typevars                }....................
+# ....................{ TESTERS ~ typevars                 }....................
 #FIXME: Overkill. Replace directly with a simple test, please.
 #
 #Note that the corresponding unit test should be preserved, as that test is
