@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -11,7 +11,7 @@ regardless of whether those hints comply with PEP standards or not).
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from beartype._data.hint.pep.datapeprepr import HINTS_REPR_IGNORABLE_SHALLOW
 from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.hint.nonpep.utilnonpeptest import (
@@ -24,10 +24,7 @@ from beartype._util.hint.pep.utilpeptest import (
     is_hint_pep_supported,
 )
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ VALIDATORS                        }....................
+# ....................{ VALIDATORS                         }....................
 def die_unless_hint(
     # Mandatory parameters.
     hint: object,
@@ -50,15 +47,15 @@ def die_unless_hint(
 
     Efficiency
     ----------
-    This validator is effectively (but technically *not*) memoized. Since the
-    passed ``exception_prefix`` parameter is typically unique to each call to this
-    validator, memoizing this validator would uselessly consume excess space
-    *without* improving time efficiency. Instead, this validator first calls
-    the memoized :func:`is_hint_pep` tester. If that tester returns ``True``,
-    this validator immediately returns ``True`` and is thus effectively
-    memoized; else, this validator inefficiently raises a human-readable
-    exception without memoization. Since efficiency is largely irrelevant in
-    exception handling, this validator thus remains effectively memoized.
+    This validator is effectively (but technically *not*) memoized. The passed
+    ``exception_prefix`` parameter is usually unique to each call to this
+    validator; memoizing this validator would uselessly consume excess space
+    *without* improving time efficiency. Instead, this validator first calls the
+    memoized :func:`is_hint_pep` tester. If that tester returns ``True``, this
+    validator immediately returns ``True`` and is thus effectively memoized;
+    else, this validator inefficiently raises a human-readable exception without
+    memoization. Since efficiency is mostly irrelevant in exception handling,
+    this validator remains effectively memoized.
 
     Parameters
     ----------
@@ -70,10 +67,10 @@ def die_unless_hint(
 
     Raises
     ----------
-    :exc:`BeartypeDecorHintPepUnsupportedException`
+    BeartypeDecorHintPepUnsupportedException
         If this object is a PEP-compliant type hint currently unsupported by
         the :func:`beartype.beartype` decorator.
-    :exc:`BeartypeDecorHintNonpepException`
+    BeartypeDecorHintNonpepException
         If this object is neither a:
 
         * Supported PEP-compliant type hint.
@@ -86,9 +83,9 @@ def die_unless_hint(
     # Else, this object is *NOT* a supported type hint. In this case,
     # subsequent logic raises an exception specific to the passed parameters.
 
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # BEGIN: Synchronize changes here with is_hint() below.
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
     # If this hint is PEP-compliant, raise an exception only if this hint is
     # currently unsupported by @beartype.
@@ -101,7 +98,7 @@ def die_unless_hint(
     # definition, all PEP-noncompliant type hints are supported by @beartype.
     die_unless_hint_nonpep(hint=hint, exception_prefix=exception_prefix)
 
-# ....................{ TESTERS                           }....................
+# ....................{ TESTERS                            }....................
 @callable_cached
 def is_hint(hint: object) -> bool:
     '''
@@ -135,9 +132,9 @@ def is_hint(hint: object) -> bool:
         dictionaries and sets). All supported type hints are hashable.
     '''
 
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # BEGIN: Synchronize changes here with die_unless_hint() above.
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
     # Return true only if...
     return (
@@ -148,11 +145,65 @@ def is_hint(hint: object) -> bool:
         is_hint_nonpep(hint=hint, is_str_valid=True)
     )
 
-# ....................{ TESTERS ~ ignorable               }....................
+# ....................{ TESTERS ~ caching                  }....................
+#FIXME: Unit test us up, please.
+def is_hint_uncached(hint: object) -> bool:
+    '''
+    ``True`` only if the passed type hint is **uncached** (i.e., hint *not*
+    already internally cached by its parent class or module).
+
+    Caveats
+    ----------
+    This function *cannot* be meaningfully memoized, since the passed type hint
+    is *not* guaranteed to be cached somewhere. Only functions passed cached
+    type hints can be meaningfully memoized. Since this high-level function
+    internally defers to unmemoized low-level functions that are ``O(n)`` for
+    ``n`` the size of the inheritance hierarchy of this hint, this function
+    should be called sparingly.
+
+    Parameters
+    ----------
+    hint : object
+        Type hint to be inspected.
+
+    Returns
+    ----------
+    bool
+        ``True`` only if this type hint is uncached.
+
+    See Also
+    ----------
+    :func:`beartype.util.hint.convert.utilconvcoerce.coerce_hint_any`
+        Further details.
+    '''
+
+    # Avoid circular import dependencies.
+    from beartype._util.hint.pep.proposal.utilpep585 import (
+        is_hint_pep585_builtin)
+    from beartype._util.hint.pep.proposal.utilpep604 import is_hint_pep604
+
+    # Return true only if this hint is either...
+    return (
+        # PEP 585-compliant (e.g., "list[str]"), this hint is *NOT* self-caching
+        # (e.g., "list[str] is not list[str]").
+        is_hint_pep585_builtin(hint) or
+        # PEP 604-compliant (e.g., "int | str"), this hint is *NOT* self-caching
+        # (e.g., "int | str is not int | str").
+        #
+        # Note that this hint could also be implicitly cached by coercing this
+        # non-self-caching PEP 604-compliant union into a self-caching PEP
+        # 484-compliant union (e.g., from "int | str" to "Union[int, str]").
+        # Since doing so would consume substantially more time for *NO* tangible
+        # gain, we strongly prefer the current trivial and efficient approach.
+        is_hint_pep604(hint)
+    )
+
+# ....................{ TESTERS ~ ignorable                }....................
 @callable_cached
 def is_hint_ignorable(hint: object) -> bool:
     '''
-    ``True`` only if the passed type hint is **ignorable.**
+    ``True`` only if the passed type hint is **ignorable** (i.e., conveys *no*
+    meaningful semantics despite superficially appearing to do so).
 
     This tester function is memoized for efficiency.
 
