@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -10,27 +10,24 @@ Project-wide **Sphinx** utilities (i.e., callables handling the third-party
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+# ....................{ IMPORTS                            }....................
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 # WARNING: To prevent this project from accidentally requiring third-party
 # packages as mandatory runtime dependencies, avoid importing from *ANY* such
 # package via a module-scoped import. These imports should be isolated to the
 # bodies of callables declared below.
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+from beartype._util.func.utilfuncframe import iter_frames
 from sys import modules as module_imported_names
-from beartype._util.func.utilfuncstack import iter_func_stack_frames
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ PRIVATE ~ magic                   }....................
+# ....................{ PRIVATE ~ magic                    }....................
 _SPHINX_AUTODOC_SUBPACKAGE_NAME = 'sphinx.ext.autodoc'
 '''
 Fully-qualified name of the subpackage providing the ``autodoc`` extension
 bundled with Sphinx.
 '''
 
-# ....................{ TESTERS                           }....................
+# ....................{ TESTERS                            }....................
 def is_sphinx_autodocing() -> bool:
     '''
     ``True`` only if Sphinx is currently **autogenerating documentation**
@@ -64,7 +61,7 @@ def is_sphinx_autodocing() -> bool:
 
     # For each stack frame on the call stack, ignoring the stack frame
     # encapsulating the call to this tester...
-    for frame in iter_func_stack_frames(func_stack_frames_ignore=1):
+    for frame in iter_frames(func_stack_frames_ignore=1):
         # Fully-qualified name of this scope's module if this scope defines
         # this name *OR* "None" otherwise.
         frame_module_name = frame.f_globals.get('__name__')
