@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
-# Copyright (c) 2014-2021 Beartype authors.
+# --------------------( LICENSE                            )--------------------
+# Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -10,14 +10,12 @@ platform the active Python interpreter is running under) utilities.
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from beartype._util.cache.utilcachecall import callable_cached
-from platform import system
+from platform import system as platform_system
+from sys import platform as sys_platform
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ TESTERS                           }....................
+# ....................{ TESTERS                            }....................
 @callable_cached
 def is_os_macos() -> bool:
     '''
@@ -27,4 +25,16 @@ def is_os_macos() -> bool:
     This tester is memoized for efficiency.
     '''
 
-    return system() == 'Darwin'
+    return platform_system() == 'Darwin'
+
+
+@callable_cached
+def is_os_windows_vanilla() -> bool:
+    '''
+    ``True`` only if the current platform is **vanilla Microsoft Windows**
+    (i.e., *not* running the Cygwin POSIX compatibility layer).
+
+    This tester is memoized for efficiency.
+    '''
+
+    return sys_platform == 'win32'
