@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -9,13 +9,10 @@ Project-wide **Python interpreter version utilities**.
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from sys import version_info
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ CONSTANTS ~ at least              }....................
+# ....................{ CONSTANTS ~ at least               }....................
 IS_PYTHON_AT_LEAST_4_0 = version_info >= (4, 0)
 '''
 ``True`` only if the active Python interpreter targets at least Python 4.0.0.
@@ -102,17 +99,6 @@ which introduced several new public attributes to the :mod:`typing` module
 '''
 
 
-#FIXME: After dropping Python 3.6 support:
-#* Refactor all code conditionally testing this global to be unconditional.
-#* Remove this global.
-#* Remove all decorators resembling:
-#  @skip_if_python_version_less_than('3.7.0')
-IS_PYTHON_AT_LEAST_3_7 = IS_PYTHON_AT_LEAST_3_7_2 or version_info >= (3, 7)
-'''
-``True`` only if the active Python interpreter targets at least Python 3.7.0.
-'''
-
-
 #FIXME: After dropping Python 3.7 support, *REMOVE* all code conditionally
 #testing this global.
 IS_PYTHON_3_7 = version_info[:2] == (3, 7)
@@ -120,10 +106,12 @@ IS_PYTHON_3_7 = version_info[:2] == (3, 7)
 ``True`` only if the active Python interpreter targets exactly Python 3.7.
 '''
 
+# ....................{ GETTERS                            }....................
+def get_python_version_major_minor() -> str:
+    '''
+    ``"."``-delimited major and minor version of the active Python interpreter
+    (e.g., ``3.11``, ``3.7``), excluding the patch version of this interpreter.
+    '''
 
-#FIXME: After dropping Python 3.6 support, *REMOVE* all code conditionally
-#testing this global.
-IS_PYTHON_3_6 = not IS_PYTHON_AT_LEAST_3_7
-'''
-``True`` only if the active Python interpreter targets exactly Python 3.6.
-'''
+    # Heroic one-liners are an inspiration to us all.
+    return f'{version_info[0]}.{version_info[1]}'
