@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
-# Copyright (c) 2014-2021 Beartype authors.
+# --------------------( LICENSE                            )--------------------
+# Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -10,18 +10,23 @@ objects or types, typically interpolated into error messages) utilities.
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
+from beartype.typing import Optional
+from beartype._util.text.utiltextcolour import user_value_colour
 from beartype._util.utilobject import (
-    get_object_basename_scoped,
+    get_object_name,
     get_object_type_name,
 )
 from collections.abc import Callable
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
+# ....................{ LABELLERS ~ callable               }....................
+def label_callable(
+    # Mandatory parameters.
+    func: Callable,
 
-# ....................{ LABELLERS ~ callable              }....................
-def label_callable(func: Callable) -> str:
+    # Optional parameters.
+    is_contextualized: Optional[bool] = None,
+) -> str:
     '''
     Human-readable label describing the passed **callable** (e.g., function,
     method, property).
@@ -30,6 +35,23 @@ def label_callable(func: Callable) -> str:
     ----------
     func : Callable
         Callable to be labelled.
+    is_contextualized : Optional[bool] = None
+        Either:
+
+        * ``True``, in which case this label is suffixed by additional metadata
+          contextually disambiguating that callable, including:
+
+          * The line number of the first line declaring that callable in its
+            underlying source code module file.
+          * The absolute filename of that file.
+
+        * ``False``, in which case this label is *not* suffixed by such
+          metadata.
+        * ``None``, in which case this label is conditionally suffixed by such
+          metadata only if that callable is a lambda function and thus
+          ambiguously lacks any semblance of an innate context.
+
+        Defaults to ``None``.
 
     Returns
     ----------
@@ -39,15 +61,26 @@ def label_callable(func: Callable) -> str:
     assert callable(func), f'{repr(func)} uncallable.'
 
     # Avoid circular import dependencies.
-    from beartype._util.func.utilfuncarg import get_func_args_len_flexible
+    from beartype._util.func.arg.utilfuncargget import (
+        get_func_args_len_flexible)
     from beartype._util.func.utilfuncfile import get_func_filename_or_none
     from beartype._util.func.utilfunccodeobj import get_func_codeobj
     from beartype._util.func.utilfunctest import (
         is_func_lambda,
-        is_func_async_coroutine,
+        is_func_coro,
         is_func_async_generator,
         is_func_sync_generator,
     )
+    from beartype._util.mod.utilmodget import (
+        get_object_module_line_number_begin)
+
+    # Substring prefixing the string to be returned, typically identifying the
+    # specialized type of that callable if that callable has a specialized type.
+    func_label_prefix = ''
+
+    # Substring suffixing the string to be returned, typically contextualizing
+    # that callable with respect to its on-disk code module file.
+    func_label_suffix = ''
 
     # If the passed callable is a pure-Python lambda function, that callable
     # has *NO* unique fully-qualified name. In this case, return a string
@@ -56,57 +89,61 @@ def label_callable(func: Callable) -> str:
         # Code object underlying this lambda.
         func_codeobj = get_func_codeobj(func)
 
-        # Human-readable label describing this lambda.
-        func_label = (
-            f'Lambda function of '
+        # Substring preceding the string to be returned.
+        func_label_prefix = (
+            f'lambda function of '
             f'{get_func_args_len_flexible(func_codeobj)} argument(s)'
         )
 
-        # Absolute filename of the file defining this lambda if this lambda was
-        # defined on-disk *OR* "None" otherwise (i.e., if this lambda was
-        # defined in-memory).
-        func_filename = get_func_filename_or_none(func)
-
-        # If this lambda was defined on-disk, describe the location of this
-        # lambda in that file.
-        if func_filename:
-            func_label += (
-                f' declared on line {func_codeobj.co_firstlineno} of '
-                f'file "{func_filename}" '
-            )
-
-        # Return this label.
-        return func_label
+        # If the caller failed to request an explicit contextualization, default
+        # to contextualizing this lambda function.
+        if is_contextualized is None:
+            is_contextualized = True
+        # Else, the caller requested an explicit contextualization. In this
+        # case, preserve that contextualization as is.
     # Else, the passed callable is *NOT* a pure-Python lambda function and thus
     # has a unique fully-qualified name.
+    else:
+        # If that callable is a synchronous generator, return this string
+        # prefixed by a substring emphasizing that fact.
+        if is_func_sync_generator(func):
+            func_label_prefix = 'generator '
+        # Else, that callable is *NOT* a synchronous generator.
+        #
+        # If that callable is an asynchronous coroutine, return this string
+        # prefixed by a substring emphasizing that fact.
+        elif is_func_coro(func):
+            func_label_prefix = 'coroutine '
+        # Else, that callable is *NOT* an asynchronous coroutine.
+        #
+        # If that callable is an asynchronous generator, return this string
+        # prefixed by a substring emphasizing that fact.
+        elif is_func_async_generator(func):
+            func_label_prefix = 'asynchronous generator '
+        # Else, that callable is *NOT* an asynchronous generator.
 
-    # Substring preceding the string to be returned, typically identifying the
-    # specialized type of this callable if this callable has a specialized
-    # type.
-    func_label_prefix = ''
+    # If contextualizing that callable...
+    if is_contextualized:
+        # Absolute filename of the source module file defining that callable if
+        # that callable was defined on-disk *OR* "None" otherwise (i.e., if that
+        # callable was defined in-memory).
+        func_filename = get_func_filename_or_none(func)
 
-    # If that callable is a synchronous generator, return this string prefixed
-    # by a substring emphasizing that fact.
-    if is_func_sync_generator(func):
-        func_label_prefix = 'generator '
-    # Else, that callable is *NOT* a synchronous generator.
-    #
-    # If that callable is an asynchronous coroutine, return this string
-    # prefixed by a substring emphasizing that fact.
-    elif is_func_async_coroutine(func):
-        func_label_prefix = 'coroutine '
-    # Else, that callable is *NOT* an asynchronous coroutine.
-    #
-    # If that callable is an asynchronous generator, return this string
-    # prefixed by a substring emphasizing that fact.
-    elif is_func_async_generator(func):
-        func_label_prefix = 'asynchronous generator '
-    # Else, that callable is *NOT* an asynchronous generator.
+        # Line number of the first line declaring that callable in that file.
+        func_lineno = get_object_module_line_number_begin(func)
 
-    # Return the fully-qualified name of this callable preceded by this prefix.
-    return f'{func_label_prefix}{get_object_basename_scoped(func)}()'
+        # If that callable was defined on-disk, describe the location of that
+        # callable in that file.
+        if func_filename:
+            func_label_suffix += (
+                f' declared on line {func_lineno} of file "{func_filename}" ')
+        # Else, that callable was defined in-memory. In this case, avoid
+        # attempting to uselessly contextualize that callable.
 
-# ....................{ LABELLERS ~ type                  }....................
+    # Return that prefix followed by the fully-qualified name of that callable.
+    return f'{func_label_prefix}{get_object_name(func)}(){func_label_suffix}'
+
+# ....................{ LABELLERS ~ type                   }....................
 def label_obj_type(obj: object) -> str:
     '''
     Human-readable label describing the class of the passed object.
@@ -149,6 +186,7 @@ def label_type(cls: type) -> str:
 
     # Label to be returned, initialized to this class' fully-qualified name.
     classname = get_object_type_name(cls)
+    # print(f'cls {cls} classname: {classname}')
 
     # If this name contains *NO* periods, this class is actually a builtin type
     # (e.g., "list"). Since builtin types are well-known and thus
@@ -156,6 +194,9 @@ def label_type(cls: type) -> str:
     # case, return this name as is.
     if '.' not in classname:
         pass
+    # Else, this name contains one or more periods but could still be a
+    # builtin indirectly accessed via the standard "builtins" module.
+    #
     # If this name is that of a builtin type uselessly prefixed by the name of
     # the module declaring all builtin types (e.g., "builtins.list"), reduce
     # this name to the unqualified basename of this type (e.g., "list").
@@ -167,6 +208,7 @@ def label_type(cls: type) -> str:
     # If this class is a PEP 544-compliant protocol supporting structural
     # subtyping, label this protocol.
     elif is_hint_pep544_protocol(cls):
+        # print(f'cls {cls} is protocol!')
         classname = f'<protocol "{classname}">'
     # Else if this class is a standard abstract base class (ABC) defined by a
     # stdlib submodule also known to support structural subtyping (e.g.,
@@ -191,7 +233,7 @@ def label_type(cls: type) -> str:
     # Return this labelled classname.
     return classname
 
-# ....................{ LABELLERS ~ exception             }....................
+# ....................{ LABELLERS ~ exception              }....................
 def label_exception(exception: Exception) -> str:
     '''
     Human-readable label describing the passed exception.
@@ -218,7 +260,7 @@ def label_exception(exception: Exception) -> str:
     # Return this exception's label.
     return f'{exception.__class__.__qualname__}: {str(exception)}'
 
-# ....................{ PREFIXERS ~ callable              }....................
+# ....................{ PREFIXERS ~ callable               }....................
 def prefix_callable(func: Callable) -> str:
     '''
     Human-readable label describing the passed **callable** (e.g., function,
@@ -291,12 +333,12 @@ def prefix_callable_decorated_pith(
         prefix_callable_decorated_return(func)
         if pith_name == 'return' else
         # Else, the parameter with this name of this callable.
-        prefix_callable_decorated_param(func=func, param_name=pith_name)
+        prefix_callable_decorated_arg(func=func, arg_name=pith_name)
     )
 
-# ....................{ PREFIXERS ~ callable : param      }....................
-def prefix_callable_decorated_param(
-    func: Callable, param_name: str) -> str:
+# ....................{ PREFIXERS ~ callable : param       }....................
+def prefix_callable_decorated_arg(
+    func: Callable, arg_name: str) -> str:
     '''
     Human-readable label describing the parameter with the passed name of the
     passed **decorated callable** (i.e., callable wrapped by the
@@ -307,7 +349,7 @@ def prefix_callable_decorated_param(
     ----------
     func : Callable
         Decorated callable to be labelled.
-    param_name : str
+    arg_name : str
         Name of the parameter of this callable to be labelled.
 
     Returns
@@ -315,14 +357,14 @@ def prefix_callable_decorated_param(
     str
         Human-readable label describing this parameter's name.
     '''
-    assert isinstance(param_name, str), f'{repr(param_name)} not string.'
+    assert isinstance(arg_name, str), f'{repr(arg_name)} not string.'
 
     # Create and return this label.
-    return f'{prefix_callable_decorated(func)}parameter "{param_name}" '
+    return f'{prefix_callable_decorated(func)}parameter "{arg_name}" '
 
 
-def prefix_callable_decorated_param_value(
-    func: Callable, param_name: str, param_value: object) -> str:
+def prefix_callable_decorated_arg_value(
+    func: Callable, arg_name: str, arg_value: object) -> str:
     '''
     Human-readable label describing the parameter with the passed name and
     trimmed value of the passed **decorated callable** (i.e., callable wrapped
@@ -333,9 +375,9 @@ def prefix_callable_decorated_param_value(
     ----------
     func : Callable
         Decorated callable to be labelled.
-    param_name : str
+    arg_name : str
         Name of the parameter of this callable to be labelled.
-    param_value : object
+    arg_value : object
         Value of the parameter of this callable to be labelled.
 
     Returns
@@ -343,18 +385,19 @@ def prefix_callable_decorated_param_value(
     str
         Human-readable label describing this parameter's name and value.
     '''
-    assert isinstance(param_name, str), f'{repr(param_name)} not string.'
+    assert isinstance(arg_name, str), f'{repr(arg_name)} not string.'
 
     # Avoid circular import dependencies.
     from beartype._util.text.utiltextrepr import represent_object
 
+    coloured_arg = user_value_colour(f'{arg_name}={represent_object(arg_value)}')
     # Create and return this label.
     return (
         f'{prefix_callable_decorated(func)}parameter '
-        f'{param_name}={represent_object(param_value)} '
+        f'{coloured_arg} '
     )
 
-# ....................{ PREFIXERS ~ callable : return     }....................
+# ....................{ PREFIXERS ~ callable : return      }....................
 def prefix_callable_decorated_return(func: Callable) -> str:
     '''
     Human-readable label describing the return of the passed **decorated
@@ -404,6 +447,5 @@ def prefix_callable_decorated_return_value(
     # Create and return this label.
     return (
         f'{prefix_callable_decorated_return(func)}'
-        f'{represent_object(return_value)} '
+        f'{user_value_colour(represent_object(return_value))} '
     )
-
