@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -9,11 +9,9 @@ Project-wide **magic strings** (i.e., globally applicable string constants).
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
+# ....................{ IMPORTS                            }....................
 
-# ....................{ CODE ~ indent                     }....................
+# ....................{ CODE ~ indent                      }....................
 CODE_INDENT_1 = '    '
 '''
 PEP-agnostic code snippet expanding to a single level of indentation.
@@ -31,7 +29,7 @@ CODE_INDENT_3 = CODE_INDENT_2 + CODE_INDENT_1
 PEP-agnostic code snippet expanding to three levels of indentation.
 '''
 
-# ....................{ CODE ~ operator                   }....................
+# ....................{ CODE ~ operator                    }....................
 LINE_RSTRIP_INDEX_AND = -len(' and')
 '''
 Negative index relative to the end of any arbitrary newline-delimited Python
