@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -21,8 +21,8 @@ Hear :mod:`beartype` roar as it efficiently checks types, validates data, and
 raids native beehives for organic honey.
 '''
 
-# ....................{ IMPORTS                           }....................
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+# ....................{ IMPORTS                            }....................
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 # WARNING: To prevent "mypy --no-implicit-reexport" from raising literally
 # hundreds of errors at static analysis time, *ALL* public attributes *MUST* be
 # explicitly reimported under the same names with "{exception_name} as
@@ -31,22 +31,29 @@ raids native beehives for organic honey.
 #     beartype/_cave/_cavefast.py:47: error: Module "beartype.roar" does not
 #     explicitly export attribute "BeartypeCallUnavailableTypeException";
 #     implicit reexport disabled  [attr-defined]
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 # WARNING: To avoid polluting the public module namespace, external attributes
 # should be locally imported at module scope *ONLY* under alternate private
 # names (e.g., "from argparse import ArgumentParser as _ArgumentParser" rather
 # than merely "from argparse import ArgumentParser").
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
 # Public exception hierarchy.
 from beartype.roar._roarexc import (
     # Exceptions.
     BeartypeException as BeartypeException,
+    BeartypeAbbyTesterException as BeartypeAbbyTesterException,
     BeartypeCaveException as BeartypeCaveException,
     BeartypeCaveNoneTypeOrException as BeartypeCaveNoneTypeOrException,
     BeartypeCaveNoneTypeOrKeyException as BeartypeCaveNoneTypeOrKeyException,
     BeartypeCaveNoneTypeOrMutabilityException as BeartypeCaveNoneTypeOrMutabilityException,
+    BeartypeClawException as BeartypeClawException,
+    BeartypeClawRegistrationException as BeartypeClawRegistrationException,
     BeartypeConfException as BeartypeConfException,
+    BeartypeDoorException as BeartypeDoorException,
+    BeartypeDoorNonpepException as BeartypeDoorNonpepException,
+    BeartypeDoorPepException as BeartypeDoorPepException,
+    BeartypeDoorPepUnsupportedException as BeartypeDoorPepUnsupportedException,
     BeartypeDecorException as BeartypeDecorException,
     BeartypeDecorWrappeeException as BeartypeDecorWrappeeException,
     BeartypeDecorWrapperException as BeartypeDecorWrapperException,
@@ -61,7 +68,6 @@ from beartype.roar._roarexc import (
     BeartypeDecorHintPep484585Exception as BeartypeDecorHintPep484585Exception,
     BeartypeDecorHintPep544Exception as BeartypeDecorHintPep544Exception,
     BeartypeDecorHintPep557Exception as BeartypeDecorHintPep557Exception,
-    BeartypeDecorHintPep563Exception as BeartypeDecorHintPep563Exception,
     BeartypeDecorHintPep585Exception as BeartypeDecorHintPep585Exception,
     BeartypeDecorHintPep586Exception as BeartypeDecorHintPep586Exception,
     BeartypeDecorHintPep593Exception as BeartypeDecorHintPep593Exception,
@@ -69,24 +75,29 @@ from beartype.roar._roarexc import (
     BeartypeDecorHintTypeException as BeartypeDecorHintTypeException,
     BeartypeDecorParamException as BeartypeDecorParamException,
     BeartypeDecorParamNameException as BeartypeDecorParamNameException,
-    BeartypeDecorPepException as BeartypeDecorPepException,
     BeartypeCallException as BeartypeCallException,
     BeartypeCallUnavailableTypeException as BeartypeCallUnavailableTypeException,
     BeartypeCallHintException as BeartypeCallHintException,
     BeartypeCallHintForwardRefException as BeartypeCallHintForwardRefException,
+    BeartypePepException as BeartypePepException,
+    BeartypePep563Exception as BeartypePep563Exception,
     BeartypeValeException as BeartypeValeException,
     BeartypeValeSubscriptionException as BeartypeValeSubscriptionException,
+    BeartypeValeValidationException as BeartypeValeValidationException,
 
     # Violations (i.e., exceptions raised during runtime type-checking).
     BeartypeAbbyHintViolation as BeartypeAbbyHintViolation,
     BeartypeCallHintViolation as BeartypeCallHintViolation,
     BeartypeCallHintParamViolation as BeartypeCallHintParamViolation,
     BeartypeCallHintReturnViolation as BeartypeCallHintReturnViolation,
+    BeartypeDoorHintViolation as BeartypeDoorHintViolation,
 )
 
 # Public warning hierarchy.
 from beartype.roar._roarwarn import (
     BeartypeWarning as BeartypeWarning,
+    BeartypeClawWarning as BeartypeClawWarning,
+    BeartypeClawDecorationWarning as BeartypeClawDecorationWarning,
     BeartypeDecorHintPepWarning as BeartypeDecorHintPepWarning,
     BeartypeDecorHintPepDeprecationWarning as BeartypeDecorHintPepDeprecationWarning,
     BeartypeDecorHintPep585DeprecationWarning as BeartypeDecorHintPep585DeprecationWarning,
@@ -98,7 +109,7 @@ from beartype.roar._roarwarn import (
     BeartypeValeLambdaWarning as BeartypeValeLambdaWarning,
 )
 
-# ....................{ DEPRECATIONS                      }....................
+# ....................{ DEPRECATIONS                       }....................
 def __getattr__(attr_deprecated_name: str) -> object:
     '''
     Dynamically retrieve a deprecated attribute with the passed unqualified
@@ -108,7 +119,9 @@ def __getattr__(attr_deprecated_name: str) -> object:
 
     The Python interpreter implicitly calls this :pep:`562`-compliant module
     dunder function under Python >= 3.7 *after* failing to directly retrieve an
-    explicit attribute with this name from this submodule.
+    explicit attribute with this name from this submodule. Since this dunder
+    function is only called in the event of an error, neither space nor time
+    efficiency are a concern here.
 
     Parameters
     ----------
@@ -148,8 +161,12 @@ def __getattr__(attr_deprecated_name: str) -> object:
                 'BeartypeDecorHintNonpepException'),
             'BeartypeDecorHintNonPepNumPyException': (
                 'BeartypeDecorHintNonpepNumpyException'),
+            'BeartypeDecorHintPep563Exception': (
+                'BeartypePep563Exception'),
             'BeartypeDecorHintPepDeprecatedWarning': (
                 'BeartypeDecorHintPepDeprecationWarning'),
+            'BeartypeDecorPepException': (
+                'BeartypePepException'),
         },
         attr_nondeprecated_name_to_value=globals(),
     )
