@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -72,8 +72,8 @@ this submodule rather than from :mod:`typing` directly: e.g.,
    from beartype.typing import Tuple, List, Dict, Set, FrozenSet, Type
 '''
 
-# ....................{ IMPORTS                           }....................
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+# ....................{ IMPORTS                            }....................
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 # WARNING: To avoid polluting the public module namespace, external attributes
 # *NOT* intended for public importation should be locally imported at module
 # scope *ONLY* under alternate private names (e.g., "import re as _re" rather
@@ -83,10 +83,8 @@ this submodule rather than from :mod:`typing` directly: e.g.,
 # import machinery rather than non-standard dynamic import shenanigans (e.g.,
 # "from typing import Annotated" rather than
 # "import_typing_attr_or_none('Annotated')").
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 from beartype._util.py.utilpyversion import (
-    IS_PYTHON_3_7            as _IS_PYTHON_3_7,
-    IS_PYTHON_AT_LEAST_3_7   as _IS_PYTHON_AT_LEAST_3_7,
     IS_PYTHON_AT_LEAST_3_7_2 as _IS_PYTHON_AT_LEAST_3_7_2,
     IS_PYTHON_AT_LEAST_3_8   as _IS_PYTHON_AT_LEAST_3_8,
     IS_PYTHON_AT_LEAST_3_9   as _IS_PYTHON_AT_LEAST_3_9,
@@ -94,8 +92,8 @@ from beartype._util.py.utilpyversion import (
     IS_PYTHON_AT_LEAST_3_11  as _IS_PYTHON_AT_LEAST_3_11,
 )
 
-# ....................{ IMPORTS ~ all                     }....................
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+# ....................{ IMPORTS ~ all                      }....................
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 # WARNING: To prevent "mypy --no-implicit-reexport" from raising literally
 # hundreds of errors at static analysis time, *ALL* public attributes *MUST* be
 # explicitly reimported under the same names with "{exception_name} as
@@ -104,7 +102,7 @@ from beartype._util.py.utilpyversion import (
 #     beartype/_cave/_cavefast.py:47: error: Module "beartype.roar" does not
 #     explicitly export attribute "BeartypeCallUnavailableTypeException";
 #     implicit reexport disabled  [attr-defined]
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
 # Import all public attributes of the "typing" module both available under all
 # supported Python versions and *NOT* deprecated by a subsequent Python version
@@ -117,17 +115,16 @@ from typing import (
     Text as Text,
     BinaryIO as BinaryIO,
     ClassVar as ClassVar,
+    ForwardRef as ForwardRef,
     Generic as Generic,
     Hashable as Hashable,
     IO as IO,
     Match as Match,
     NamedTuple as NamedTuple,
-    NewType as NewType,
     NoReturn as NoReturn,
     Optional as Optional,
     Pattern as Pattern,
     Sized as Sized,
-    Text as Text,
     TextIO as TextIO,
     TypeVar as TypeVar,
     Union as Union,
@@ -138,61 +135,100 @@ from typing import (
     overload as overload,
 )
 
-# ....................{ IMPORTS ~ version                 }....................
+# ....................{ IMPORTS ~ version                  }....................
 # Import all public attributes of the "typing" module both available under a
 # subset of supported Python versions and *NOT* deprecated by a subsequent
 # Python version under their original names.
 
-# If the active Python interpreter targets Python >= 3.7...
-if _IS_PYTHON_AT_LEAST_3_7:
-    from typing import (
-        ForwardRef as ForwardRef,
+# If the active Python interpreter targets Python >= 3.8...
+if _IS_PYTHON_AT_LEAST_3_8:
+    from typing import (  # type: ignore[attr-defined]
+        Final as Final,  # pyright: ignore[reportGeneralTypeIssues]
+        Literal as Literal,  # pyright: ignore[reportGeneralTypeIssues]
+        Reversible as Reversible,  # pyright: ignore[reportGeneralTypeIssues]
+        SupportsIndex as SupportsIndex,  # pyright: ignore[reportGeneralTypeIssues]
+        TypedDict as TypedDict,  # pyright: ignore[reportGeneralTypeIssues]
+        final as final,  # pyright: ignore[reportGeneralTypeIssues]
+        get_args as get_args,  # pyright: ignore[reportGeneralTypeIssues]
+        get_origin as get_origin,  # pyright: ignore[reportGeneralTypeIssues]
     )
 
-    # If the active Python interpreter targets Python >= 3.8...
-    if _IS_PYTHON_AT_LEAST_3_8:
+    # If the active Python interpreter targets Python >= 3.10...
+    if _IS_PYTHON_AT_LEAST_3_10:
         from typing import (  # type: ignore[attr-defined]
-            Final as Final,
-            Literal as Literal,
-            Reversible as Reversible,
-            SupportsIndex as SupportsIndex,
-            TypedDict as TypedDict,
-            final as final,
-            get_args as get_args,
-            get_origin as get_origin,
+            Concatenate as Concatenate,  # pyright: ignore[reportGeneralTypeIssues]
+            ParamSpec as ParamSpec,  # pyright: ignore[reportGeneralTypeIssues]
+            ParamSpecArgs as ParamSpecArgs,  # pyright: ignore[reportGeneralTypeIssues]
+            ParamSpecKwargs as ParamSpecKwargs,  # pyright: ignore[reportGeneralTypeIssues]
+            TypeAlias as TypeAlias,  # pyright: ignore[reportGeneralTypeIssues]
+            TypeGuard as TypeGuard,  # pyright: ignore[reportGeneralTypeIssues]
+            is_typeddict as is_typeddict,  # pyright: ignore[reportGeneralTypeIssues]
         )
 
-        # If the active Python interpreter targets Python >= 3.10...
-        if _IS_PYTHON_AT_LEAST_3_10:
-            from typing import (  # type: ignore[attr-defined]
-                Concatenate as Concatenate,
-                ParamSpec as ParamSpec,
-                ParamSpecArgs as ParamSpecArgs,
-                ParamSpecKwargs as ParamSpecKwargs,
-                TypeAlias as TypeAlias,
-                TypeGuard as TypeGuard,
-                is_typeddict as is_typeddict,
-            )
+        #FIXME: Uncomment once these PEPs go live:
+        # # If the active Python interpreter targets Python >= 3.11...
+        # if _IS_PYTHON_AT_LEAST_3_11:
+        #     from typing import (  # type: ignore[attr-defined]
+        #            LiteralString as LiteralString,
+        #            Self as Self,
+        #            TypeVarTuple as TypeVarTuple,
+        #            dataclass_transform,
+        #         #FIXME: Technically, this is already live -- but pyright insists
+        #         #it isn't. We don't particularly feel like fighting that.
+        #            reveal_type as reveal_type,
+        #     )
 
-            # If the active Python interpreter targets Python >= 3.11...
-            if _IS_PYTHON_AT_LEAST_3_11:
-                from typing import (  # type: ignore[attr-defined]
-                    #FIXME: Add once that PEP goes live:
-                    #    Self as Self,
-                    reveal_type as reveal_type,
-                )
+# ....................{ PEP ~ 544                          }....................
+# If this interpreter is either performing static type-checking (e.g., via mypy)
+# *OR* targets Python < 3.8, defer to the standard library versions of the
+# family of "Supports*" protocols available under Python < 3.8.
+if TYPE_CHECKING or not _IS_PYTHON_AT_LEAST_3_8:
+    from typing import (  # type: ignore[attr-defined]
+        SupportsAbs as SupportsAbs,
+        SupportsBytes as SupportsBytes,
+        SupportsComplex as SupportsComplex,
+        SupportsFloat as SupportsFloat,
+        SupportsInt as SupportsInt,
+        SupportsRound as SupportsRound,
+    )
 
-# ....................{ PEP ~ 585                         }....................
-# If the active Python interpreter targets Python < 3.9 and thus fails to
-# support PEP 585, import *ALL* public attributes of the "typing" module
-# deprecated by PEP 585 as their original values.
+# If this interpreter targets Python >= 3.8 and thus fully supports PEP 544...
+if _IS_PYTHON_AT_LEAST_3_8:
+    # If this interpreter is performing static type-checking, defer to the
+    # standard library versions of all remaining PEP 544 attributes.
+    if TYPE_CHECKING:
+        from typing import (  # type: ignore[attr-defined]
+            Protocol as Protocol,  # pyright: ignore[reportGeneralTypeIssues]
+            SupportsIndex as SupportsIndex,  # pyright: ignore[reportGeneralTypeIssues]
+            runtime_checkable as runtime_checkable,  # pyright: ignore[reportGeneralTypeIssues]
+        )
+    # Else, this interpreter is *NOT* performing static type-checking. In this
+    # case, prefer our optimized PEP 544 attributes.
+    else:
+        from beartype.typing._typingpep544 import (
+            Protocol as Protocol,
+            SupportsAbs as SupportsAbs,
+            SupportsBytes as SupportsBytes,
+            SupportsComplex as SupportsComplex,
+            SupportsFloat as SupportsFloat,
+            SupportsIndex as SupportsIndex,
+            SupportsInt as SupportsInt,
+            SupportsRound as SupportsRound,
+            runtime_checkable as runtime_checkable,
+        )
+
+# ....................{ PEP ~ 585                          }....................
+# If this interpreter is either performing static type-checking (e.g., via mypy)
+# *OR* targets Python < 3.9 and thus fails to support PEP 585, import *ALL*
+# public attributes of the "typing" module deprecated by PEP 585 as their
+# original values.
 #
 # This is intentionally performed *BEFORE* the corresponding "else:" branch
 # below handling the Python >= 3.9 case. Why? Because mypy. If the order of
 # these two branches is reversed, mypy emits errors under Python < 3.9 when
 # attempting to subscript any of the builtin types (e.g., "Tuple"): e.g.,
 #     error: "tuple" is not subscriptable  [misc]
-if not _IS_PYTHON_AT_LEAST_3_9:
+if TYPE_CHECKING or not _IS_PYTHON_AT_LEAST_3_9:
     from typing import (
         AbstractSet as AbstractSet,
         AsyncContextManager as AsyncContextManager,
@@ -220,11 +256,9 @@ if not _IS_PYTHON_AT_LEAST_3_9:
         List as List,
         Mapping as Mapping,
         MappingView as MappingView,
-        Match as Match,
         MutableMapping as MutableMapping,
         MutableSequence as MutableSequence,
         MutableSet as MutableSet,
-        Pattern as Pattern,
         Reversible as Reversible,
         Set as Set,
         Tuple as Tuple,
@@ -290,60 +324,3 @@ else:
     Set = set  # type: ignore[misc]
     Tuple = tuple  # type: ignore[assignment]
     Type = type  # type: ignore[assignment]
-
-# Try to install our Protocol replacement
-if TYPE_CHECKING:
-    if _IS_PYTHON_AT_LEAST_3_7:
-        from typing import (  # type: ignore[attr-defined]
-            SupportsAbs as SupportsAbs,
-            SupportsBytes as SupportsBytes,
-            SupportsComplex as SupportsComplex,
-            SupportsFloat as SupportsFloat,
-            SupportsInt as SupportsInt,
-            SupportsRound as SupportsRound,
-        )
-
-        if _IS_PYTHON_AT_LEAST_3_8:
-            # FIXME: The ignore[attr-defined] is for Python 3.7 because
-            # Mypy doesn't understand IS_PYTHON_AT_LEAST_3_8. That ignore should
-            # be removable when retiring PYTHON_AT_LEAST_3_7.
-            from typing import (  # type: ignore[attr-defined]
-                Protocol as Protocol,
-                SupportsIndex as SupportsIndex,
-                runtime_checkable as runtime_checkable,
-            )
-        else:
-            assert _IS_PYTHON_3_7
-
-            try:
-                from typing_extensions import (  # type: ignore[misc,no-redef]
-                    Protocol as Protocol,
-                    SupportsIndex as SupportsIndex,
-                    runtime_checkable as runtime_checkable,
-                )
-            except ImportError:
-                pass
-else:  # not TYPE_CHECKING
-    try:
-        # Import our replacements.
-        from beartype.typing._typingpep544 import (
-            Protocol as Protocol,
-            SupportsAbs as SupportsAbs,
-            SupportsBytes as SupportsBytes,
-            SupportsComplex as SupportsComplex,
-            SupportsFloat as SupportsFloat,
-            SupportsIndex as SupportsIndex,
-            SupportsInt as SupportsInt,
-            SupportsRound as SupportsRound,
-            runtime_checkable as runtime_checkable,
-        )
-    except ImportError:
-        # Fallback to the standard library versions.
-        from typing import (
-            SupportsAbs as SupportsAbs,
-            SupportsBytes as SupportsBytes,
-            SupportsComplex as SupportsComplex,
-            SupportsFloat as SupportsFloat,
-            SupportsInt as SupportsInt,
-            SupportsRound as SupportsRound,
-        )
