@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -7,17 +7,18 @@
 **Beartype** :pep:`544` **optimization layer.**
 
 This private submodule implements a :func:`beartype.beartype``-compatible
-(i.e., decorated by :func:`typing.runtime_checkable`) drop-in replacement for
-:class:`typing.Protocol` that can lead to significant performance improvements.
+(i.e., decorated by the :func:`typing.runtime_checkable` decorator) drop-in
+replacement for :class:`typing.Protocol` that can lead to significant
+performance improvements.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from beartype._util.py.utilpyversion import (
     IS_PYTHON_AT_LEAST_3_8,
     IS_PYTHON_AT_LEAST_3_9,
 )
 
-# ....................{ PEP 544                           }....................
+# ....................{ PEP 544                            }....................
 # If the active Python interpreter targets Python >= 3.8 and thus supports PEP
 # 544...
 #
@@ -25,16 +26,16 @@ from beartype._util.py.utilpyversion import (
 # statement. I seem to remember a bug/feature request about that somewhere,
 # but couldn't find it after a brief search.
 if IS_PYTHON_AT_LEAST_3_8:
-    # ..................{ IMPORTS                           }..................
+    # ..................{ IMPORTS                            }..................
     #FIXME: The ignore[attr-defined] is for Python 3.7 because Mypy doesn't
     #understand IS_PYTHON_AT_LEAST_3_8. That ignore should be removable
     #when retiring PYTHON 3.7.
     # Defer Python version-specific imports, including non-caching
     # protocols to be overridden by caching equivalents below (and other
     # requirements from various sources, depending on runtime environment).
-    from beartype._util.cache.utilcachecall import callable_cached
+    from beartype.typing._typingcache import callable_cached_minimal
     from typing import (  # type: ignore[attr-defined]
-        EXCLUDED_ATTRIBUTES,
+        EXCLUDED_ATTRIBUTES,  # pyright: ignore[reportGeneralTypeIssues]
         TYPE_CHECKING,
         Any,
         Generic,
@@ -43,25 +44,27 @@ if IS_PYTHON_AT_LEAST_3_8:
         SupportsBytes as _SupportsBytesSlow,
         SupportsComplex as _SupportsComplexSlow,
         SupportsFloat as _SupportsFloatSlow,
-        SupportsIndex as _SupportsIndexSlow,
+        SupportsIndex as _SupportsIndexSlow,  # pyright: ignore[reportGeneralTypeIssues]
         SupportsInt as _SupportsIntSlow,
         SupportsRound as _SupportsRoundSlow,
         TypeVar,
-        Union,
         runtime_checkable,
     )
 
-    # Note that this branch is intentionally tested first, despite the
-    # resulting negation. Why? Because mypy quietly defecates all over itself
-    # if the order of these two branches is reversed. It's as bad as it sounds.
+    # Note that we intentionally:
+    # * Avoid importing these type hint factories from "beartype.typing", as
+    #   that would induce a circular import dependency. Instead, we manually
+    #   import the relevant type hint factories conditionally depending on the
+    #   version of the active Python interpreter. *sigh*
+    # * Test the negation of this condition first. Why? Because mypy quietly
+    #   defecates all over itself if the order of these two branches is
+    #   reversed. Yeah. It's as bad as it sounds.
     if not IS_PYTHON_AT_LEAST_3_9:
-        from typing import Dict, Iterable, Tuple, Type  # type: ignore[misc]
+        from typing import Dict, Tuple, Type  # type: ignore[misc]
     # Else, the active Python interpreter targets Python >= 3.9 and thus
     # supports PEP 585. In this case, embrace non-deprecated PEP 585-compliant
     # type hints.
     else:
-        from collections.abc import Iterable
-
         Dict = dict  # type: ignore[misc]
         Tuple = tuple  # type: ignore[assignment]
         Type = type  # type: ignore[assignment]
@@ -82,7 +85,7 @@ if IS_PYTHON_AT_LEAST_3_8:
     else:
         _ProtocolMeta = type(_ProtocolSlow)
 
-    # ..................{ CONSTANTs                         }..................
+    # ..................{ CONSTANTS                          }..................
     _PROTOCOL_ATTR_NAMES_IGNORABLE = frozenset(EXCLUDED_ATTRIBUTES)
     '''
     Frozen set of the names all **ignorable non-protocol attributes** (i.e.,
@@ -98,12 +101,12 @@ if IS_PYTHON_AT_LEAST_3_8:
     '''
 
 
-    _TT = TypeVar("_TT", bound=type)
+    _TT = TypeVar("_TT", bound="_CachingProtocolMeta")
     '''
     Arbitrary type variable bound (i.e., confined) to classes.
     '''
 
-    # ..................{ METACLASSES                       }..................
+    # ..................{ METACLASSES                        }..................
     class _CachingProtocolMeta(_ProtocolMeta):
         '''
         **Caching protocol metaclass** (i.e., drop-in replacement for the
@@ -125,62 +128,76 @@ if IS_PYTHON_AT_LEAST_3_8:
 
         Motivation
         ----------
-        Although any non-caching protocol can be coerced into a caching
-        protocol through inheritance, the former will remain incompatible with
-        runtime type checkers (including :mod:`beartype`) until explicitly
-        decorated by :func:`typing.runtime_checkable`. As example:
+        By default, :class:`typing.Protocol` subclasses are constrained to only
+        be checkable by static type checkers (e.g., :mod:`mypy`). Checking a
+        protocol with a runtime type checker (e.g., :mod:`beartype`) requires
+        explicitly decorating that protocol with the
+        :func:`typing.runtime_checkable` decorator. Why? We have no idea.
+
+        For unknown (but probably indefensible) reasons, :pep:`544` authors
+        enforced this constraint with a trivial private
+        :class:`typing.Protocol` boolean instance variable imposing *no* space
+        or time burden set only by the optional
+        :func:`typing.runtime_checkable` decorator. Since that's demonstrably
+        insane, we pretend :pep:`544` authors chose wisely by unconditionally
+        decorating *all* :class:`beartype.typing.Protocol` subclasses by that
+        decorator.
+
+        Technically, any non-caching :class:`typing.Protocol` subclass can be
+        effectively coerced into a caching :class:`beartype.typing.Protocol`
+        protocol through inheritance: e.g.,
 
         .. code-block:: python
 
           >>> from abc import abstractmethod
           >>> from typing import Protocol
           >>> from beartype.typing import _CachingProtocolMeta, runtime_checkable
-
           >>> @runtime_checkable
           ... class _MyProtocol(Protocol):  # plain vanilla protocol
-          ...   @abstractmethod
-          ...   def myfunc(self, arg: int) -> str:
-          ...     pass
-
+          ...     @abstractmethod
+          ...     def myfunc(self, arg: int) -> str:
+          ...         pass
           >>> @runtime_checkable  # redundant, but useful for documentation
           ... class MyProtocol(
-          ...   _MyProtocol,
-          ...   Protocol,
-          ...   metaclass=_CachingProtocolMeta,  # caching version
+          ...     _MyProtocol,
+          ...     Protocol,
+          ...     metaclass=_CachingProtocolMeta,  # caching version
           ... ):
-          ...   pass
-
+          ...     pass
           >>> class MyImplementation:
-          ...   def myfunc(self, arg: int) -> str:
-          ...     return str(arg * -2 + 5)
-
+          ...     def myfunc(self, arg: int) -> str:
+          ...         return str(arg * -2 + 5)
           >>> my_thing: MyProtocol = MyImplementation()
           >>> isinstance(my_thing, MyProtocol)
           True
 
-        The easy way to ensure your protocol caches checks and is
-        :func:`typing.runtime_checkable` is to inherit from
-        :class:`beartype.typing.Protocol` instead:
+        Pragmatically, :class:`beartype.typing.Protocol` trivially eliminates
+        *all* of the above fragile boilerplate: e.g.,
 
         .. code-block:: python
 
           >>> from beartype.typing import Protocol
-
           >>> class MyBearProtocol(Protocol):
-          ...   @abstractmethod
-          ...   def myfunc(self, arg: int) -> str:
-          ...     pass
-
+          ...     @abstractmethod
+          ...     def myfunc(self, arg: int) -> str:
+          ...         pass
           >>> my_thing: MyBearProtocol = MyImplementation()
           >>> isinstance(my_thing, MyBearProtocol)
           True
         '''
 
+        # ................{ CLASS VARIABLES                    }................
         _abc_inst_check_cache: Dict[type, bool]
+        '''
+        :func:`isinstance` **cache** (i.e., dictionary mapping from each type
+        of any object previously passed as the first parameter to the
+        :func:`isinstance` builtin whose second parameter was this protocol
+        onto each boolean returned by that call to that builtin).
+        '''
 
-        # ................{ DUNDERS                           }................
+        # ................{ DUNDERS                            }................
         def __new__(
-            mcls: Type[_TT],
+            mcls: Type[_TT],  # pyright: ignore[reportSelfClsParameterName]
             name: str,
             bases: Tuple[type, ...],
             namespace: Dict[str, Any],
@@ -188,34 +205,62 @@ if IS_PYTHON_AT_LEAST_3_8:
         ) -> _TT:
 
             # See <https://github.com/python/mypy/issues/9282>
-            cls = super().__new__(mcls, name, bases, namespace, **kw)  # type: ignore[misc]
+            cls = super().__new__(mcls, name, bases, namespace, **kw)
 
-            # Mark this protocol class as a runtime protocol. By default,
-            # "typing.Protocol" subclasses are only static-time. Although
-            # marking a protocol class as a runtime protocol only defines a
-            # single private boolean on this class (and thus imposes *NO* space
-            # or time burden whatsoever), typing authors unwisely elected to
-            # force everyone everywhere to unconditionally mark protocols as
-            # runtime by decorate every runtime protocol by @runtime_checkable.
-            # Since that is demonstrably insane, we pretend they choose wisely.
-            #
-            # To do so, we forcefully enable a private boolean instance
-            # variable widely tested throghout the "typing" module. For unknown
-            # reasons, this line of the typing.Protocol.__init__() method
-            # forcefully disables this boolean despite the "__bases__" tuple of
-            # this protocol class explicitly listing "typing.Protocol":
-            #     cls._is_protocol = any(b is Protocol for b in cls.__bases__)
-            #
-            # Note that the @runtime_checkable decorator itself *CANNOT* be
-            # applied to this protocol class. Why? Because that decorator
-            # internally raises this exception if this private boolean instance
-            # variable is false:
-            #     TypeError: @runtime_checkable can be only applied to protocol
-            #     classes, got <class
-            #     'beartype.typing._typingpep544.SupportsAbs'>
-            #
-            # We lie to tell the truth.
-            cls._is_protocol = True
+            # If this class is *NOT* the abstract "beartype.typing.Protocol"
+            # superclass defined below...
+            if name != 'Protocol':
+                #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+                # CAUTION: Synchronize this "if" conditional against the
+                # standard "typing" module, which defines the exact same logic
+                # in the Protocol.__init_subclass__() class method.
+                #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+                # If it is unknown whether this class is an abstract protocol
+                # directly subclassing the "Protocol" superclass *OR* a concrete
+                # subclass of an abstract protocol, decide which applies now.
+                # Why? Because upstream performs the same logic. Since this
+                # logic tests the non-transitive dunder tuple "__bases__" of all
+                # *DIRECT* superclasses of this class rather than the transitive
+                # dunder tuple "__mro__" of all direct and indirect superclasses
+                # of this class, upstream logic erroneously detects abstract
+                # fast @beartype protocols as concrete by unconditionally
+                # reducing to:
+                #     cls._is_protocol = False
+                #
+                # Why? Because "beartype.typing.Protocol" subclasses
+                # "typing.Protocol", subclasses of "beartype.typing.Protocol"
+                # list "beartype.typing.Protocol" rather than "typing.Protocol"
+                # in their "__bases__" dunder tuple. Disaster, thy name is
+                # "typing"!
+                if not cls.__dict__.get('_is_protocol'):
+                    # print(f'Protocol {cls} bases: {cls.__bases__}')
+                    cls._is_protocol = any(b is Protocol for b in cls.__bases__)  # type: ignore[attr-defined]
+
+                # If this protocol is concrete rather than abstract,
+                # monkey-patch this concrete protocol to be implicitly
+                # type-checkable at runtime. By default, protocols are *NOT*
+                # type-checkable at runtime unless explicitly decorated by this
+                # nonsensical decorator.
+                #
+                # Note that the abstract "beartype.typing.Protocol" superclass
+                # *MUST* be explicitly excluded from consideration. Why? For
+                # unknown reasons, monkey-patching that superclass as implicitly
+                # type-checkable at runtime has extreme consequences throughout
+                # the typing ecosystem. In particular, doing so causes *ALL*
+                # non-protocol classes to be subsequently erroneously detected
+                # as being PEP 544-compliant protocols: e.g.,
+                #     # If we monkey-patched the "Protocol" superclass as well, then
+                #     # the following snippet would insanely hold true... wat!?!?!?!
+                #     >>> from typing import Protocol
+                #     >>> class OhBoy(object): pass
+                #     >>> issubclass(OhBoy, Protocol)
+                #     True  # <-- we have now destroyed the world, folks.
+                if cls._is_protocol:  # type: ignore[attr-defined]
+                    # print(f'Protocol {cls} mro: {cls.__mro__}')
+                    runtime_checkable(cls)  # pyright: ignore[reportGeneralTypeIssues]
+            # Else, this class is the abstract "beartype.typing.Protocol"
+            # superclass defined below. In this case, avoid dangerously
+            # monkey-patching this superclass.
 
             # Prefixing this class member with "_abc_" is necessary to prevent
             # it from being considered part of the Protocol. See also:
@@ -246,10 +291,10 @@ if IS_PYTHON_AT_LEAST_3_8:
 
             # Attempt to...
             try:
-                #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+                #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
                 # CAUTION: This *MUST* remain *SUPER* tight!! Even adding a
                 # mere assertion here can add ~50% to our best-case runtime.
-                #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+                #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
                 # Return a pre-cached boolean indicating whether an object of
                 # the same arbitrary type as the object passed to this call
                 # satisfied the same protocol in a prior call of this method.
@@ -340,8 +385,8 @@ if IS_PYTHON_AT_LEAST_3_8:
         # true.
         return True
 
-    # ..................{ CLASSES                           }..................
-    @runtime_checkable
+    # ..................{ CLASSES                            }..................
+    # @runtime_checkable
     class Protocol(
         _ProtocolSlow,
         # Force protocols to be generics. Although the standard
@@ -349,7 +394,7 @@ if IS_PYTHON_AT_LEAST_3_8:
         # "typing.Generic" superclass, the non-standard
         # "typing_extensions.Protocol" superclass does *NOT*. Ergo, we force
         # this to be the case.
-        Generic,
+        Generic,  # pyright: ignore
         metaclass=_CachingProtocolMeta,
     ):
         '''
@@ -383,11 +428,11 @@ if IS_PYTHON_AT_LEAST_3_8:
            ...   thing.myfunc(0)
         '''
 
-        # ................{ CLASS VARIABLES                   }................
-        __slots__: Union[str, Iterable[str]] = ()
+        # ................{ CLASS VARIABLES                    }................
+        __slots__: Any = ()
 
-        # ................{ DUNDERS                           }................
-        @callable_cached
+        # ................{ DUNDERS                            }................
+        @callable_cached_minimal
         def __class_getitem__(cls, item):
 
             # We have to redefine this method because typing.Protocol's version
@@ -402,6 +447,11 @@ if IS_PYTHON_AT_LEAST_3_8:
             #   our_gen_alias.__origin__ = cls
             #   return our_gen_alias
 
+            # Superclass __class_getitem__() dunder method, localized for
+            # brevity, efficiency, and (most importantly) to squelch false
+            # positive "errors" from pyright with a single pragma comment.
+            super_class_getitem = super().__class_getitem__  # pyright: ignore[reportGeneralTypeIssues]
+
             # If the superclass typing.Protocol.__class_getitem__() dunder
             # method has been wrapped as expected with caching by the private
             # (and thus *NOT* guaranteed to exist) @typing._tp_cache decorator,
@@ -419,7 +469,7 @@ if IS_PYTHON_AT_LEAST_3_8:
             #   decorator. Calling the decorated closure wrapping that
             #   unwrapped method with memoization would needlessly consume
             #   excess space and time for *NO* additional benefit.
-            if hasattr(super().__class_getitem__, '__wrapped__'):
+            if hasattr(super_class_getitem, '__wrapped__'):
                 # Protocol class to be passed as the "cls" parameter to the
                 # unwrapped superclass typing.Protocol.__class_getitem__()
                 # dunder method. There exist two unique cases corresponding to
@@ -448,15 +498,14 @@ if IS_PYTHON_AT_LEAST_3_8:
                     cls
                 )
 
-                gen_alias = super().__class_getitem__.__wrapped__(
-                    protocol_cls, item)
+                gen_alias = super_class_getitem.__wrapped__(protocol_cls, item)
             # We shouldn't ever be here, but if we are, we're making the
             # assumption that typing.Protocol.__class_getitem__() no longer
             # caches. Heaven help us if that ever uses some proprietary
             # memoization implementation we can't see anymore because it's not
             # based on the standard @functools.wraps decorator.
             else:
-                gen_alias = super().__class_getitem__(item)
+                gen_alias = super_class_getitem(item)
 
             # Switch the origin of this generic alias from its default of
             # "typing.Protocol" to this caching protocol class. If *NOT* done,
@@ -489,13 +538,13 @@ if IS_PYTHON_AT_LEAST_3_8:
     # representations to comply, this awkward monkey-patch preserves sanity.
     Protocol.__module__ = 'beartype.typing'
 
-    # ..................{ PROTOCOLS                         }..................
+    # ..................{ PROTOCOLS                          }..................
     class SupportsAbs(_SupportsAbsSlow[_T_co], Protocol, Generic[_T_co]):
         '''
         Caching variant of :class:`typing.SupportsAbs`.
         '''
         __module__: str = 'beartype.typing'
-        __slots__: Union[str, Iterable[str]] = ()
+        __slots__: Any = ()
 
 
     class SupportsBytes(_SupportsBytesSlow, Protocol):
@@ -503,7 +552,7 @@ if IS_PYTHON_AT_LEAST_3_8:
         Caching variant of :class:`typing.SupportsBytes`.
         '''
         __module__: str = 'beartype.typing'
-        __slots__: Union[str, Iterable[str]] = ()
+        __slots__: Any = ()
 
 
     class SupportsComplex(_SupportsComplexSlow, Protocol):
@@ -511,7 +560,7 @@ if IS_PYTHON_AT_LEAST_3_8:
         Caching variant of :class:`typing.SupportsComplex`.
         '''
         __module__: str = 'beartype.typing'
-        __slots__: Union[str, Iterable[str]] = ()
+        __slots__: Any = ()
 
 
     class SupportsFloat(_SupportsFloatSlow, Protocol):
@@ -519,7 +568,7 @@ if IS_PYTHON_AT_LEAST_3_8:
         Caching variant of :class:`typing.SupportsFloat`."
         '''
         __module__: str = 'beartype.typing'
-        __slots__: Union[str, Iterable[str]] = ()
+        __slots__: Any = ()
 
 
     class SupportsInt(_SupportsIntSlow, Protocol):
@@ -527,7 +576,7 @@ if IS_PYTHON_AT_LEAST_3_8:
         Caching variant of :class:`typing.SupportsInt`.
         '''
         __module__: str = 'beartype.typing'
-        __slots__: Union[str, Iterable[str]] = ()
+        __slots__: Any = ()
 
 
     class SupportsIndex(_SupportsIndexSlow, Protocol):
@@ -535,7 +584,7 @@ if IS_PYTHON_AT_LEAST_3_8:
         Caching variant of :class:`typing.SupportsIndex`.
         '''
         __module__: str = 'beartype.typing'
-        __slots__: Union[str, Iterable[str]] = ()
+        __slots__: Any = ()
 
 
     class SupportsRound(_SupportsRoundSlow[_T_co], Protocol, Generic[_T_co]):
@@ -543,4 +592,4 @@ if IS_PYTHON_AT_LEAST_3_8:
         Caching variant of :class:`typing.SupportsRound`.
         '''
         __module__: str = 'beartype.typing'
-        __slots__: Union[str, Iterable[str]] = ()
+        __slots__: Any = ()
