@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -10,64 +10,24 @@ This private submodule defines the core private :class:`BeartypeValidator`
 class instantiated by public **beartype validator factories** (i.e., instances
 of concrete subclasses of the private
 :class:`beartype._vale._factory._valeisabc._BeartypeValidatorFactoryABC`
-abstract base class).
+abstract base class (ABC)).
 
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from beartype.roar import BeartypeValeSubscriptionException
+from beartype.vale._util._valeutilfunc import die_unless_validator_tester
 from beartype.vale._util._valeutiltext import format_diagnosis_line
-from beartype._util.kind.utilkinddict import merge_mappings_two
-from beartype._util.func.arg.utilfuncargtest import (
-    die_unless_func_args_len_flexible_equal,
-    is_func_argless,
+from beartype.vale._util._valeutiltyping import (
+    BeartypeValidatorTester,
+    BeartypeValidatorRepresenter,
 )
-from beartype._util.func.utilfuncscope import CallableScope
+from beartype._data.datatyping import LexicalScope
+from beartype._util.func.arg.utilfuncargtest import is_func_argless
 from beartype._util.text.utiltextrepr import represent_object
-from typing import Callable, Union
 
-# See the "beartype.cave" submodule for further commentary.
-__all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
-
-# ....................{ HINTS                             }....................
-BeartypeValidatorTester = Callable[[object], bool]
-'''
-PEP-compliant type hint matching a **beartype validator tester** (i.e.,
-caller-defined callable accepting a single arbitrary object and returning
-either ``True`` if that object satisfies an arbitrary constraint *or* ``False``
-otherwise).
-
-Beartype validator testers are suitable for subscripting functional beartype
-validator factories (e.g., :attr:`beartype.vale.Is`).
-'''
-
-
-BeartypeValidatorRepresenter = Union[str, Callable[[], str]]
-'''
-PEP-compliant type hint matching a **beartype validator representer** (i.e.,
-either a string *or* caller-defined callable accepting no arguments returning a
-machine-readable representation of a beartype validator).
-
-Technically, this representation *could* be passed by the caller rather than
-this callable dynamically generating that representation. Pragmatically,
-generating this representation is sufficiently slow for numerous types of
-validators that deferring their generation until required by a call to the
-:meth:`__repr__` dunder method externally called by a call to the :func:`repr`
-builtin` on this validator is effectively mandatory. Validators whose
-representations are particularly slow to generate include:
-
-* The :class:`Is` class subscripted by a lambda rather than non-lambda
-  function. Generating the representation of that class subscripted by a
-  non-lambda function only requires introspecting the name of that function and
-  is thus trivially fast. However, lambda functions have no names and are thus
-  *only* distinguishable by their source code; generating the representation of
-  that class subscripted by a lambda function requires parsing the source code
-  of the file declaring that lambda for the exact substring of that code
-  declaring that lambda.
-'''
-
-# ....................{ CLASSES                           }....................
+# ....................{ CLASSES                            }....................
 class BeartypeValidator(object):
     '''
     **Beartype validator** (i.e., object encapsulating a caller-defined
@@ -89,10 +49,10 @@ class BeartypeValidator(object):
     _get_repr : BeartypeValidatorRepresenter
         **Representer** (i.e., either a string *or* caller-defined callable
         accepting no arguments returning a machine-readable representation of
-        this validator). See the :data:`BeartypeValidatorRepresenter` type hint for
-        further details.
+        this validator). See the :data:`BeartypeValidatorRepresenter` type hint
+        for further details.
     _is_valid : BeartypeValidatorTester
-        **Validator** (i.e., caller-defined callable accepting a single
+        **Validator tester** (i.e., caller-defined callable accepting a single
         arbitrary object and returning either ``True`` if that object satisfies
         an arbitrary constraint *or* ``False`` otherwise).
     _is_valid_code : str
@@ -106,7 +66,7 @@ class BeartypeValidator(object):
         Despite performing the same validation as the :meth:`is_valid`
         callable, this code avoids the additional stack frame imposed by
         calling that callable and thus constitutes an optimization.
-    _is_valid_code_locals : CallableScope
+    _is_valid_code_locals : LexicalScope
         **Validator code local scope** (i.e., dictionary mapping from the name
         to value of each local attribute referenced in :attr:`code`) required
         to dynamically compile this validator code into byte code at runtime.
@@ -117,12 +77,12 @@ class BeartypeValidator(object):
         Class docstring for further details.
     '''
 
-    # ..................{ CLASS VARIABLES                   }..................
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    # ..................{ CLASS VARIABLES                    }..................
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # CAUTION: Subclasses declaring uniquely subclass-specific instance
     # variables *MUST* additionally slot those variables. Subclasses violating
     # this constraint will be usable but unslotted, which defeats our purposes.
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # Slot all instance variables defined on this object to minimize the time
     # complexity of both reading and writing variables across frequently called
     # cache dunder methods. Slotting has been shown to reduce read and write
@@ -134,12 +94,15 @@ class BeartypeValidator(object):
         '_is_valid_code_locals',
     )
 
-    # ..................{ INITIALIZERS                      }..................
+    # ..................{ INITIALIZERS                       }..................
     def __init__(
         self,
+        *,
+
+        # Mandatory keyword-only parameters.
         is_valid: BeartypeValidatorTester,
         is_valid_code: str,
-        is_valid_code_locals: CallableScope,
+        is_valid_code_locals: LexicalScope,
         get_repr: BeartypeValidatorRepresenter,
     ) -> None:
         '''
@@ -148,8 +111,8 @@ class BeartypeValidator(object):
         Parameters
         ----------
         is_valid : BeartypeValidatorTester
-            **Validator** (i.e., caller-defined callable accepting a single
-            arbitrary object and returning either ``True`` if that object
+            **Validator tester** (i.e., caller-defined callable accepting a
+            single arbitrary object and returning either ``True`` if that object
             satisfies an arbitrary constraint *or* ``False`` otherwise).
         is_valid_code : str
             **Validator code** (i.e., Python code snippet validating the
@@ -167,7 +130,7 @@ class BeartypeValidator(object):
               :pep:`8`-compliant and well-established Python style guides, any
               additional indentation hard-coded into this code should be
               aligned to **four-space indentation.**
-        is_valid_code_locals : CallableScope
+        is_valid_code_locals : LexicalScope
             **Validator code local scope** (i.e., dictionary mapping from the
             name to value of each local attribute referenced in
             :attr:`is_valid_code` code) required to dynamically compile this
@@ -207,22 +170,12 @@ class BeartypeValidator(object):
               * The empty string.
         '''
 
-        # If this validator is either uncallable, a C-based callable, *OR* a
-        # pure-Python callable accepting more or less than one parameter, raise
-        # an exception.
-        die_unless_func_args_len_flexible_equal(
-            func=is_valid,
-            func_args_len_flexible=1,
-            exception_cls=BeartypeValeSubscriptionException,
-        )
-        # Else, this validator is a pure-Python callable accepting exactly one
-        # parameter. Since no further validation can be performed on this
-        # callable without unsafely calling that callable, we accept this
-        # callable as is for now.
-        #
-        # Note that we *COULD* technically inspect annotations if defined on
-        # this callable as well. Since this callable is typically defined as a
-        # lambda, annotations are typically *NOT* defined on this callable.
+        # Avoid circular import dependencies.
+        from beartype.vale._is._valeisabc import _BeartypeValidatorFactoryABC
+
+        # If that callable is *NOT* a validator tester, raise an exception.
+        die_unless_validator_tester(is_valid)
+        # Else, that callable is a validator tester.
 
         # If this code is *NOT* a string, raise an exception.
         if not isinstance(is_valid_code, str):
@@ -278,7 +231,7 @@ class BeartypeValidator(object):
         self._is_valid_code = is_valid_code
         self._is_valid_code_locals = is_valid_code_locals
 
-    # ..................{ PROPERTIES ~ read-only            }..................
+    # ..................{ PROPERTIES ~ read-only             }..................
     # Properties with no corresponding setter and thus read-only.
 
     @property
@@ -291,7 +244,7 @@ class BeartypeValidator(object):
 
         return self._is_valid
 
-    # ..................{ PROPERTIES ~ writeable            }..................
+    # ..................{ PROPERTIES ~ writeable             }..................
     # Properties with a corresponding setter and thus writeable.
 
     @property
@@ -350,7 +303,7 @@ class BeartypeValidator(object):
         # Set this representer.
         self._get_repr = get_repr
 
-    # ..................{ DUNDERS ~ str                     }..................
+    # ..................{ DUNDERS ~ str                      }..................
     def __repr__(self) -> str:
         '''
         Machine-readable representation of this validator.
@@ -376,15 +329,18 @@ class BeartypeValidator(object):
         # Return this string as is.
         return self._get_repr
 
-    # ..................{ GETTERS                           }..................
-    #FIXME: Call this method from get_cause_or_none_annotated(), please.
-    #FIXME: Unit test us up, please -- particularly with respect to non-trivial
-    #nested subvalidators.
+    # ..................{ GETTERS                            }..................
     def get_diagnosis(
         self,
+        *,
+
+        # Mandatory keyword-only parameters.
         obj: object,
         indent_level_outer: str,
         indent_level_inner: str,
+
+        # Optional keyword-only parameters.
+        is_shortcircuited: bool = False,
     ) -> str:
         '''
         Human-readable **validation failure diagnosis** (i.e., substring
@@ -411,12 +367,87 @@ class BeartypeValidator(object):
             **Innermost indentation level** (i.e., zero or more adjacent spaces
             delimiting the human-readable representation of the tri-state
             boolean and validator representation in the returned substring).
+        is_shortcircuited : bool, optional
+            ``True`` only if this validator has been **short-circuited** (i.e.,
+            *not* required to be tested against) by a previously tested sibling
+            validator, in which case this method will silently catch and reduce
+            exceptions raised by the :meth:`is_valid` method to ``False``.
+
+            Short-circuiting typically arises from binary validators (e.g.,
+            :class:`beartype.vale._core._valecore.BeartypeValidatorConjunction`)
+            in which a low-level sibling validator, previously tested against by
+            the higher-level binary validator encapsulating both this validator
+            and that sibling validator, has already either fully satisfied *or*
+            failed to satisfy that binary validator; a binary validator
+            explicitly sets this parameter to ``True`` for *all* children
+            validators except the first child validator when the first child
+            validator either fully satisfies *or* fails to satisfy that binary
+            validator.
+
+            This is *not* merely an optimization; this is a design requirement.
+            External users often chain validators together with set operators
+            (e.g., ``&``, ``|``) under the standard expectation of
+            short-circuiting, in which later validators are *not* tested when
+            earlier validators already satisfy requirements. Violating this
+            expectation causes later validators to trivially raise exceptions.
+
+            Without short-circuiting, the otherwise valid following example
+            raises a non-human-readable exception. The short-circuited
+            ``IsArrayMatrix`` validator expects to be tested *only* when the
+            preceding non-short-circuited ``IsArray2D`` validator fails:
+
+            .. code-block:: python
+
+               >>> import numpy as np
+               >>> from beartype.vale import Is
+               >>> IsArray2D = Is[lambda arr: arr.ndim == 2]
+               >>> IsArrayMatrix = Is[lambda arr: arr.shape[0] == arr.shape[1]]
+               >>> IsArray2DMatrix = IsArray2D & IsArrayMatrix
+               >>> IsArray2DMatrix.get_diagnosis(
+               ...     obj=np.zeros((4,)),
+               ...     indent_level_outer='',
+               ...     indent_level_inner='    ',
+               ... )
+               Traceback (most recent call last):
+                 File "/home/leycec/tmp/mopy.py", line 10, in <module>
+                   print(IsArray2DMatrix.get_diagnosis(
+                 File "/home/leycec/py/beartype/beartype/vale/_core/_valecorebinary.py", line 149, in get_diagnosis
+                   line_inner_operand_2 = self._validator_operand_2.get_diagnosis(
+                 File "/home/leycec/py/beartype/beartype/vale/_core/_valecore.py", line 480, in get_diagnosis
+                   is_obj_valid = self.is_valid(obj)
+                 File "/home/leycec/tmp/mopy.py", line 7, in <lambda>
+                   IsArrayMatrix = Is[lambda arr: arr.shape[0] == arr.shape[1]]
+               IndexError: tuple index out of range
+
+            Defaults to ``False``.
 
         Returns
         ----------
         str
             Substring diagnosing this object against this validator.
         '''
+        assert isinstance(is_shortcircuited, bool), (
+            f'{repr(is_shortcircuited)} not boolean.')
+
+        # True only if the passed object satisfies this validator.
+        is_obj_valid = None
+
+        # If this validator has been short-circuited by a prior sibling...
+        if is_shortcircuited:
+            # Attempt to decide whether that object satisfies this validator.
+            try:
+                is_obj_valid = self.is_valid(obj)
+            # If doing so raises an exception, this short-circuited validator
+            # was *NOT* intended to be called under short-circuiting. In this
+            # case, silently ignore this exception. See the above discussion.
+            except:
+                pass
+        # Else, this validator is *NOT* short-circuited. In this case, this
+        # validator is *NOT* expected to raise exceptions. Nonetheless, if this
+        # validator does so, ensure that exception is propagated up the call
+        # stack by *NOT* silently ignoring that exception (as above).
+        else:
+            is_obj_valid = self.is_valid(obj)
 
         # Format the validity of this object against this validator for the
         # typical case of a lowest-level beartype validator *NOT* wrapping one
@@ -426,10 +457,10 @@ class BeartypeValidator(object):
             validator_repr=repr(self),
             indent_level_outer=indent_level_outer,
             indent_level_inner=indent_level_inner,
-            is_obj_valid=self.is_valid(obj),
+            is_obj_valid=is_obj_valid,
         )
 
-    # ..................{ DUNDERS ~ operator                }..................
+    # ..................{ DUNDERS ~ operator                 }..................
     # Define a domain-specific language (DSL) enabling callers to dynamically
     # synthesize higher-level validators from lower-level validators via
     # overloaded set theoretic operators.
@@ -461,41 +492,10 @@ class BeartypeValidator(object):
         from beartype.vale._core._valecorebinary import (
             BeartypeValidatorConjunction)
 
-        #FIXME: Gradually shift *ALL* of this logic into the
-        #"BeartypeValidatorConjunction" subclass itself.
-        #FIXME: Avoid violating DRY between this and methods defined below.
-        #Indeed, since we already perform this logic in the
-        #BeartypeValidatorBinary.__init__() constructor, avoid doing so here.
-
-        # If the passed object is *NOT* also an instance of this class, raise
-        # an exception.
-        if not isinstance(other, BeartypeValidator):
-            raise BeartypeValeSubscriptionException(
-                f'Beartype validator {repr(self)} second "&" operand '
-                f'{represent_object(other)} not beartype validator '
-                f'(i.e., "beartype.vale.Is*[...]" object).'
-            )
-        # Else, the passed object is also an instance of this class.
-
-        # Lambda function conjunctively performing both validations.
-        is_valid = lambda obj: self.is_valid(obj) and other.is_valid(obj)
-
-        # Generate code conjunctively performing both validations.
-        is_valid_code = f'({self._is_valid_code} and {other._is_valid_code})'
-
-        # Generate locals safely merging the locals required by the code
-        # provided by both this and that validator.
-        is_valid_code_locals = merge_mappings_two(
-            self._is_valid_code_locals, other._is_valid_code_locals)
-
         # Closures for great justice.
         return BeartypeValidatorConjunction(
             validator_operand_1=self,
             validator_operand_2=other,
-            is_valid=is_valid,
-            is_valid_code=is_valid_code,
-            is_valid_code_locals=is_valid_code_locals,  # type: ignore[arg-type]
-            get_repr=lambda: f'{repr(self)} & {repr(other)}',
         )
 
 
@@ -521,46 +521,15 @@ class BeartypeValidator(object):
         from beartype.vale._core._valecorebinary import (
             BeartypeValidatorDisjunction)
 
-        #FIXME: Gradually shift *ALL* of this logic into the
-        #"BeartypeValidatorDisjunction" subclass itself.
-        #FIXME: Avoid violating DRY between this and methods defined above.
-        #Indeed, since we already perform this logic in the
-        #BeartypeValidatorBinary.__init__() constructor, avoid doing so here.
-
-        # If the passed object is *NOT* also an instance of this class, raise
-        # an exception.
-        if not isinstance(other, BeartypeValidator):
-            raise BeartypeValeSubscriptionException(
-                f'Beartype validator {repr(self)} second "|" operand '
-                f'{represent_object(other)} not beartype validator '
-                f'(i.e., "beartype.vale.Is*[...]" object).'
-            )
-        # Else, the passed object is also an instance of this class.
-
-        # Lambda function disjunctively performing both validations.
-        is_valid = lambda obj: self.is_valid(obj) or other.is_valid(obj)
-
-        # Generate code disjunctively performing both validations.
-        is_valid_code = f'({self._is_valid_code} or {other._is_valid_code})'
-
-        # Generate locals safely merging the locals required by the code
-        # provided by both this and that validator.
-        is_valid_code_locals = merge_mappings_two(
-            self._is_valid_code_locals, other._is_valid_code_locals)
-
         # Closures for great justice.
         return BeartypeValidatorDisjunction(
             validator_operand_1=self,
             validator_operand_2=other,
-            is_valid=is_valid,
-            is_valid_code=is_valid_code,
-            is_valid_code_locals=is_valid_code_locals,  # type: ignore[arg-type]
-            get_repr=lambda: f'{repr(self)} | {repr(other)}',
         )
 
 
     #FIXME: Fun optimization: if inverting something that's already been
-    #inverted, return the original "BeartypeValidator" object sans inversion. :p
+    #inverted, return the original "BeartypeValidator" object sans inversion.
     def __invert__(self) -> 'BeartypeValidator':
         '''
         **Negation** (i.e., ``~self``), synthesizing a new
@@ -579,12 +548,4 @@ class BeartypeValidator(object):
             BeartypeValidatorNegation)
 
         # Closures for profound lore.
-        return BeartypeValidatorNegation(
-            validator_operand=self,
-            is_valid=lambda obj: not self.is_valid(obj),
-            # Inverted validator code, defined as the trivial boolean negation
-            # of this validator.
-            is_valid_code=f'(not {self._is_valid_code})',
-            is_valid_code_locals=self._is_valid_code_locals,
-            get_repr=lambda: f'~{repr(self)}',
-        )
+        return BeartypeValidatorNegation(validator_operand=self)
