@@ -15,7 +15,7 @@ This submodule unit tests both the public *and* private API of the private
 # WARNING: To raise human-readable test errors, avoid importing from
 # package-specific submodules at module scope.
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-from beartype_test.util.mark.pytskip import skip_if_python_version_less_than
+from beartype_test._util.mark.pytskip import skip_if_python_version_less_than
 
 # ....................{ TESTS                             }....................
 # If the active Python interpreter targets Python < 3.8, this interpreter fails
@@ -31,10 +31,9 @@ def test_typingpep544_metaclass() -> None:
     # Defer heavyweight imports.
     from abc import abstractmethod
     from beartype.typing import (
-        Iterable,
+        Any,
         Protocol,
         TypeVar,
-        Union,
         runtime_checkable,
     )
     from beartype.typing._typingpep544 import _CachingProtocolMeta
@@ -45,7 +44,7 @@ def test_typingpep544_metaclass() -> None:
     # Can we really have it all?!
     @runtime_checkable  # <-- unnecessary at runtime, but Mypy is confused without it
     class SupportsRoundFromScratch(Protocol[_T_co]):
-        __slots__: Union[str, Iterable[str]] = ()
+        __slots__: Any = ()
         @abstractmethod
         def __round__(self, ndigits: int = 0) -> _T_co:
             pass
@@ -111,6 +110,7 @@ def test_typingpep544_subclass() -> None:
         runtime_checkable
     )
     from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_8
+    from pytest import raises
 
     # Arbitrary protocol directly subclassing the protocol superclass
     # subscripted by one or more type variables, exercising subtle edge cases.
@@ -145,9 +145,14 @@ def test_typingpep544_subclass() -> None:
             def dreamless_sleep(self) -> str:
                 pass
 
-        # Assert that optionally decorating protocols by the standard
+        # Assert that optionally decorating abstract protocols by the standard
         # @typing.runtime_checkable() decorator reduces to a noop.
-        assert runtime_checkable(SupportsHiddenBuds) is SupportsHiddenBuds
+        assert runtime_checkable(SupportsFeebleDreams) is SupportsFeebleDreams
+
+        # Assert that attempting to decorate concrete protocol subclasses by
+        # the same decorator raises the expected exception.
+        with raises(TypeError):
+            runtime_checkable(SupportsHiddenBuds)
 
 
 @skip_if_python_version_less_than('3.8.0')
@@ -310,10 +315,9 @@ def test_typingpep544_protocol_custom_direct_typevar() -> None:
     from abc import abstractmethod
     from beartype import beartype
     from beartype.typing import (
-        Iterable,
+        Any,
         Protocol,
         TypeVar,
-        Union,
         runtime_checkable,
     )
 
@@ -323,7 +327,7 @@ def test_typingpep544_protocol_custom_direct_typevar() -> None:
     # Arbitrary direct protocol subscripted by this type variable.
     @runtime_checkable
     class SupportsAbsToo(Protocol[_T_co]):
-        __slots__: Union[str, Iterable[str]] = ()
+        __slots__: Any = ()
 
         @abstractmethod
         def __abs__(self) -> _T_co:
