@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
@@ -10,9 +10,7 @@ This submodule predefines low-level class constants exercising known edge
 cases on behalf of higher-level unit test submodules.
 '''
 
-# ....................{ IMPORTS                           }....................
-import builtins
-from beartype._data.mod.datamod import BUILTINS_MODULE_NAME
+# ....................{ IMPORTS                            }....................
 from contextlib import contextmanager
 from sys import exc_info, implementation
 from typing import (
@@ -23,7 +21,7 @@ from typing import (
     Generator,
 )
 
-# ....................{ CLASSES                           }....................
+# ....................{ CLASSES                            }....................
 class CallableClass(object):
     '''
     Arbitrary pure-Python **callable class** (i.e., class defining the
@@ -38,12 +36,12 @@ class CallableClass(object):
 
         return len(args) + len(kwargs)
 
-# ....................{ CLASSES ~ hierarchy : 1           }....................
+# ....................{ CLASSES ~ hierarchy : 1            }....................
 # Arbitrary class hierarchy.
 
 class Class(object):
     '''
-    Arbitrary pure-Python class defining an arbitrary method.
+    Arbitrary pure-Python class defining arbitrary methods.
     '''
 
     def instance_method(self):
@@ -54,6 +52,33 @@ class Class(object):
         pass
 
 
+    @property
+    def instance_property(self):
+        '''
+        Arbitrary pure-Python instance property.
+        '''
+
+        pass
+
+
+    @classmethod
+    def class_method(cls):
+        '''
+        Arbitrary pure-Python class method.
+        '''
+
+        pass
+
+
+    @staticmethod
+    def static_method():
+        '''
+        Arbitrary pure-Python static method.
+        '''
+
+        pass
+
+
 class Subclass(Class):
     '''
     Arbitrary pure-Python subclass of an arbitrary pure-Python superclass.
@@ -70,7 +95,7 @@ class SubclassSubclass(Subclass):
 
     pass
 
-# ....................{ CLASSES ~ hierarchy : 2           }....................
+# ....................{ CLASSES ~ hierarchy : 2            }....................
 # Yet another arbitrary class hierarchy.
 
 class OtherClass(object):
@@ -102,7 +127,7 @@ class OtherSubclassSubclass(OtherSubclass):
 
     pass
 
-# ....................{ CLASSES ~ isinstance              }....................
+# ....................{ CLASSES ~ isinstance               }....................
 class NonIsinstanceableMetaclass(type):
     '''
     Metaclass overriding the ``__instancecheck__()`` dunder method to
@@ -125,7 +150,7 @@ class NonIsinstanceableClass(object, metaclass=NonIsinstanceableMetaclass):
 
     pass
 
-# ....................{ CLASSES ~ issubclass              }....................
+# ....................{ CLASSES ~ issubclass               }....................
 class NonIssubclassableMetaclass(type):
     '''
     Metaclass overriding the ``__subclasscheck__()`` dunder method to
@@ -148,37 +173,53 @@ class NonIssubclassableClass(object, metaclass=NonIssubclassableMetaclass):
 
     pass
 
-# ....................{ CALLABLES ~ async : factory       }....................
+# ....................{ CALLABLES ~ async : factory        }....................
 # Note that we intentionally avoid declaring a factory function for deprecated
 # generator-based coroutines decorated by either the types.coroutine() or
 # asyncio.coroutine() decorators. CPython 3.10 removes support for these
 # decorators and thus generator-based coroutines. See also:
 #     https://docs.python.org/3/library/asyncio-task.html#asyncio.coroutine
 
-async def async_generator_factory() -> AsyncGenerator[None, None]:
-    '''
-    Arbitrary pure-Python asynchronous generator factory function.
-    '''
-
-    yield
-
-
-async def async_coroutine_factory() -> Coroutine[None, None, None]:
+async def async_coroutine_factory(text: str) -> Coroutine[None, None, str]:
     '''
     Arbitrary pure-Python asynchronous non-generator coroutine factory
     function.
     '''
 
-    pass
+    # Defer function-specific imports.
+    from asyncio import sleep
 
-# ....................{ CALLABLES ~ async : instance      }....................
-async_generator = async_generator_factory()
+    # Asynchronously switch to another scheduled asynchronous callable (if any).
+    await sleep(0)
+
+    # Return an arbitrary string.
+    return f'{text}Yet not a city, but a flood of ruin'
+
+
+async def async_generator_factory(text: str) -> AsyncGenerator[str, None]:
+    '''
+    Arbitrary pure-Python asynchronous generator factory function.
+    '''
+
+    # Defer function-specific imports.
+    from asyncio import sleep
+
+    # Asynchronously switch to another scheduled asynchronous callable (if any).
+    await sleep(0)
+
+    # Yield an arbitrary string.
+    yield f'{text}Rolls its perpetual stream; vast pines are strewing'
+
+# ....................{ CALLABLES ~ async : instance       }....................
+async_generator = async_generator_factory(
+    "Its destin'd path, or in the mangled soil")
 '''
 Arbitrary pure-Python asynchronous generator.
 '''
 
 
-async_coroutine = async_coroutine_factory()
+async_coroutine = async_coroutine_factory(
+    "Branchless and shatter'd stand; the rocks, drawn down")
 '''
 Arbitrary pure-Python asynchronous non-generator coroutine.
 '''
@@ -186,7 +227,7 @@ Arbitrary pure-Python asynchronous non-generator coroutine.
 # Prevent Python from emitting "ResourceWarning" warnings.
 async_coroutine.close()
 
-# ....................{ CALLABLES ~ sync                  }....................
+# ....................{ CALLABLES ~ sync                   }....................
 def function():
     '''
     Arbitrary pure-Python function.
@@ -204,7 +245,7 @@ def context_manager_factory(obj: object) -> ContextManager[object]:
 
     yield obj
 
-# ....................{ CALLABLES ~ sync : decorator      }....................
+# ....................{ CALLABLES ~ sync : decorator       }....................
 def decorator(func: Callable) -> Callable:
     '''
     **Identity decorator** (i.e., decorator returning the passed callable
@@ -240,7 +281,7 @@ def decorator_wrapping(func):
     # Return this closure.
     return _identity_wrapper
 
-# ....................{ CALLABLES ~ sync : generator      }....................
+# ....................{ CALLABLES ~ sync : generator       }....................
 def sync_generator_factory() -> Generator[int, None, None]:
     '''
     Create and return a pure-Python generator yielding a single integer,
@@ -273,7 +314,7 @@ def sync_generator_factory_yield_int_send_float_return_str() -> (
     # Return a string constant.
     return 'Unmarred, scarred revenant remnants'
 
-# ....................{ CALLABLES ~ sync : closure        }....................
+# ....................{ CALLABLES ~ sync : closure         }....................
 def closure_factory():
     '''
     Arbitrary pure-Python closure factory function.
@@ -311,13 +352,13 @@ def closure_cell_factory():
     # Return this closure's first and only cell variable.
     return closure.__closure__[0]
 
-# ....................{ CALLABLES ~ sync : instance       }....................
+# ....................{ CALLABLES ~ sync : instance        }....................
 sync_generator = sync_generator_factory()
 '''
 Arbitrary pure-Python synchronous generator.
 '''
 
-# ....................{ CONSTANTS                         }....................
+# ....................{ CONSTANTS                          }....................
 CALLABLE_CODE_OBJECT = function.__code__
 '''
 Arbitrary callable code object.
@@ -336,14 +377,20 @@ try:
 except TypeError:
     TRACEBACK = exc_info()[2]
 
-# ....................{ CONSTANTS ~ filenames             }....................
+# ....................{ CONSTANTS ~ filenames              }....................
 MODULE_FILENAME = __file__
 '''
 Absolute filename of the current submodule, declared purely for convenience.
 '''
 
-# ....................{ SETS ~ callable                   }....................
-CALLABLES_PYTHON = frozenset((function, Class, Class.instance_method))
+# ....................{ SETS ~ callable                    }....................
+CALLABLES_PYTHON = frozenset((
+    function,
+    Class,
+    Class.instance_method,
+    Class.class_method,
+    Class.static_method,
+))
 '''
 Frozen set of pure-Python callables exercising edge cases.
 '''
@@ -375,24 +422,25 @@ Frozen set of both pure-Python *and* C-based callables exercising edge cases.
 '''
 
 
-NON_CALLABLES = (
-    CALLABLE_CODE_OBJECT,
-    type.__dict__,      # Mapping Proxy Type
-    implementation,     # Simple Namespace Type
-    async_coroutine,
-    async_generator,
-    sync_generator,
-    closure_cell_factory(), # Cell type
-    TRACEBACK,
-    TRACEBACK.tb_frame,
-)
-'''
-Tuple of callable-like non-callable objects exercising edge cases,
-intentionally defined as a tuple rather than frozen set due to the
-unhashability of one or more members (e.g., ``TRACEBACK``).
-'''
+#FIXME: Currently unused but preserved for posterity.
+# NON_CALLABLES = (
+#     CALLABLE_CODE_OBJECT,
+#     type.__dict__,      # Mapping Proxy Type
+#     implementation,     # Simple Namespace Type
+#     async_coroutine,
+#     async_generator,
+#     sync_generator,
+#     closure_cell_factory(), # Cell type
+#     TRACEBACK,
+#     TRACEBACK.tb_frame,
+# )
+# '''
+# Tuple of callable-like non-callable objects exercising edge cases, intentionally
+# defined as a tuple rather than frozen set due to the unhashability of one or
+# more members (e.g., ``TRACEBACK``).
+# '''
 
-# ....................{ SETS ~ type : builtin             }....................
+# ....................{ SETS ~ type : builtin              }....................
 TYPES_BUILTIN = frozenset((
     bool,
     complex,
@@ -410,24 +458,9 @@ Frozen set of all **builtin types** i.e., globally accessible C-based type
 requiring *no* explicit importation)(.
 '''
 
-# ....................{ SETS ~ type : non-builtin         }....................
-TYPES_BUILTIN_FAKE = frozenset((
-    # Type of this builtin.
-    builtin.__class__
-    # For each builtin (i.e., globally accessible object implicitly imported by
-    # the active Python interpreter into *EVERY* lexical context)...
-    for builtin in builtins.__dict__.values()
-    # If...
-    if (
-        # The type of this builtin also insists itself to be defined by the
-        # "builtins" module and thus also be a builtin *AND*...
-        builtin.__class__.__module__ == BUILTINS_MODULE_NAME and
-        # The "builtins" module contains *NO* globally-scoped attribute whose
-        # name is that of this type...
-        builtin.__class__.__name__ not in builtins.__dict__
-    # Then add this cheatin', lyin', no-good type to this set.
-    )
-))
+# ....................{ SETS ~ type : non-builtin          }....................
+# Fully initialized below by the _init() function.
+TYPES_BUILTIN_FAKE = None
 '''
 Frozen set of all **fake builtin types** (i.e., types that are *not* builtin
 but which nonetheless erroneously masquerade as being builtin).
@@ -443,10 +476,67 @@ See Also
 '''
 
 
-TYPES_NONBUILTIN = frozenset((
-    # Arbitrary non-builtin type.
-    Class,
-)) | TYPES_BUILTIN_FAKE
+# Fully initialized below by the _init() function.
+TYPES_NONBUILTIN = None
 '''
 Frozen set of arbitrary non-builtin types.
 '''
+
+# ....................{ INITIALIZERS                       }....................
+def _init() -> None:
+    '''
+    Initialize this submodule.
+    '''
+
+    # Defer initialization-specific imports.
+    import builtins, types
+    from beartype._data.mod.datamodpy import BUILTINS_MODULE_NAME
+    from beartype._util.utilobject import get_object_type_unless_type
+
+    # Global variables assigned to below.
+    global TYPES_BUILTIN_FAKE, TYPES_NONBUILTIN
+
+    # Set of all fake builtin types.
+    TYPES_BUILTIN_FAKE_SET = set()
+
+    # Frozen set of all standard modules well-known to define at least one fake
+    # builtin type.
+    #
+    # Note that, although the "builtins" module defines *MOST* fake builtins,
+    # the "types" module defines *SOME* fake builtins as well. These include:
+    # * "types.TracebackType".
+    MODULES_TYPES_BUILTIN_FAKE = frozenset((builtins, types))
+
+    # For each such module...
+    for module_type_builtin_fake in MODULES_TYPES_BUILTIN_FAKE:
+        # For each builtin (i.e., globally accessible object implicitly imported
+        # by the active Python interpreter into *EVERY* lexical context)...
+        for builtin in module_type_builtin_fake.__dict__.values():
+            # Type of this builtin if this builtin is *NOT* a type or this
+            # builtin type as is.
+            type_builtin = get_object_type_unless_type(builtin)
+
+            # If...
+            if (
+                # This builtin type insists itself to be defined by the
+                # "builtins" module and thus be a builtin *AND*...
+                type_builtin.__module__ == BUILTINS_MODULE_NAME and
+                # The "builtins" module contains *NO* globally-scoped attribute
+                # whose name is that of this type...
+                type_builtin.__name__ not in builtins.__dict__
+            # Add this cheatin', lyin', no-good fake builtin type to this set.
+            ):
+                TYPES_BUILTIN_FAKE_SET.add(type_builtin)
+
+    # Frozen set of all fake builtin types.
+    TYPES_BUILTIN_FAKE = frozenset((TYPES_BUILTIN_FAKE_SET))
+
+    # Frozen set of arbitrary non-builtin types.
+    TYPES_NONBUILTIN = frozenset((
+        # Arbitrary non-builtin type.
+        Class,
+    )) | TYPES_BUILTIN_FAKE
+
+
+# Initialize this submodule.
+_init()
