@@ -1,20 +1,23 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
-Project-wide **type hint metadata class hierarchy** (i.e., hierarchy of
+Testing-specific **type hint metadata class hierarchy** (i.e., hierarchy of
 classes encapsulating sample type hints instantiated by the
 :mod:`beartype_test.a00_unit.data.hint` submodules).
 '''
 
-# ....................{ IMPORTS                           }....................
-from beartype._data.hint.pep.sign.datapepsigncls import HintSign
-from collections.abc import Iterable
+# ....................{ IMPORTS                            }....................
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+# WARNING: To raise human-readable test errors, avoid importing from
+# package-specific submodules at module scope.
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 from typing import Optional
+from collections.abc import Iterable
 
-# ....................{ PRIVATE                           }....................
+# ....................{ PRIVATE                            }....................
 _EXCEPTION_STR_MATCH_REGEXES_MANDATORY = (
     # Ensure *ALL* exception messages contain the substring "type hint".
     # Exception messages *NOT* containing this substring are overly ambiguous
@@ -34,7 +37,7 @@ _NoneTypeOrType = (type, type(None))
 2-tuple matching both classes and the ``None`` singleton.
 '''
 
-# ....................{ CLASSES ~ hint : [un]satisfied    }....................
+# ....................{ CLASSES ~ hint : [un]satisfied     }....................
 class HintPithSatisfiedMetadata(object):
     '''
     **Type hint-satisfying pith metadata** (i.e., dataclass whose instance
@@ -66,7 +69,7 @@ class HintPithSatisfiedMetadata(object):
         passing this value to the decorated callable). Defaults to ``False``.
     '''
 
-    # ..................{ INITIALIZERS                      }..................
+    # ..................{ INITIALIZERS                       }..................
     def __init__(
         self,
 
@@ -87,7 +90,7 @@ class HintPithSatisfiedMetadata(object):
         self.is_context_manager = is_context_manager
         self.is_pith_factory = is_pith_factory
 
-    # ..................{ STRINGIFIERS                      }..................
+    # ..................{ STRINGIFIERS                       }..................
     def __repr__(self) -> str:
         return '\n'.join((
             f'{self.__class__.__name__}(',
@@ -118,7 +121,7 @@ class HintPithUnsatisfiedMetadata(HintPithSatisfiedMetadata):
         returning this ``pith``. Defaults to the empty tuple.
     '''
 
-    # ..................{ INITIALIZERS                      }..................
+    # ..................{ INITIALIZERS                       }..................
     def __init__(
         self,
         *args,
@@ -155,7 +158,7 @@ class HintPithUnsatisfiedMetadata(HintPithSatisfiedMetadata):
             _EXCEPTION_STR_MATCH_REGEXES_MANDATORY
         )
 
-    # ..................{ STRINGIFIERS                      }..................
+    # ..................{ STRINGIFIERS                       }..................
     def __repr__(self) -> str:
         return '\n'.join((
             f'{self.__class__.__name__}(',
@@ -167,7 +170,7 @@ class HintPithUnsatisfiedMetadata(HintPithSatisfiedMetadata):
             f')',
         ))
 
-# ....................{ CLASSES ~ hint : superclass       }....................
+# ....................{ CLASSES ~ hint : superclass        }....................
 class HintNonpepMetadata(object):
     '''
     **PEP-noncompliant type hint metadata** (i.e., dataclass whose instance
@@ -203,14 +206,15 @@ class HintNonpepMetadata(object):
         Defaults to the empty tuple.
     '''
 
-    # ..................{ INITIALIZERS                      }..................
+    # ..................{ INITIALIZERS                       }..................
     def __init__(
         self,
+        *,
 
-        # Mandatory parameters.
+        # Mandatory keyword-only parameters.
         hint: object,
 
-        # Optional parameters.
+        # Optional keyword-only parameters.
         is_ignorable: bool = False,
         is_supported: bool = True,
         piths_meta: 'Iterable[HintPithSatisfiedMetadata]' = (),
@@ -235,7 +239,7 @@ class HintNonpepMetadata(object):
         self.is_supported = is_supported
         self.piths_meta = piths_meta
 
-    # ..................{ STRINGIFIERS                      }..................
+    # ..................{ STRINGIFIERS                       }..................
     def __repr__(self) -> str:
         return '\n'.join((
             f'{self.__class__.__name__}(',
@@ -246,7 +250,7 @@ class HintNonpepMetadata(object):
             f')',
         ))
 
-# ....................{ CLASSES ~ hint : subclass         }....................
+# ....................{ CLASSES ~ hint : subclass          }....................
 class HintPepMetadata(HintNonpepMetadata):
     '''
     **PEP-compliant type hint metadata** (i.e., dataclass whose instance
@@ -255,38 +259,6 @@ class HintPepMetadata(HintNonpepMetadata):
 
     Attributes
     ----------
-    is_args : Optional[bool]
-        ``True`` only if this hint is subscripted by one or more **arguments**
-        (i.e., PEP-compliant type hints that are *not* type variables) and/or
-        **type variables** (i.e., :class:`typing.TypeVar` instances). Defaults
-        to ``True`` only if the machine-readable representation of this hint
-        contains one or more ``"["`` delimiters.
-    is_pep585_builtin : bool
-        ``True`` only if this hint is a `PEP 585`-compliant builtin. If
-        ``True``, then :attr:`is_type_typing` *must* be ``False``. Defaults to
-        the negation of :attr:`is_pep585_generic` if non-``None`` *or*
-        ``False`` otherwise (i.e., if :attr:`is_pep585_generic` is ``None``).
-    is_pep585_generic : bool
-        ``True`` only if this hint is a `PEP 585`-compliant generic. If
-        ``True``, then :attr:`is_type_typing` *must* be ``False``. Defaults to
-        the negation of :attr:`is_pep585_generic` if non-``None`` *or*
-        ``False`` otherwise (i.e., if :attr:`is_pep585_generic` is ``None``).
-    is_typevars : bool
-        ``True`` only if this hint is subscripted by one or more **type
-        variables** (i.e., :class:`typing.TypeVar` instances). Defaults to
-        ``False``.
-    is_type_typing : Optional[bool]
-        ``True`` only if this hint's class is defined by the :mod:`typing`
-        module. If ``True``, then :attr:`is_pep585_builtin` and
-        :attr:`is_pep585_generic` *must* both be ``False``. Defaults to
-        either:
-
-        * If either :attr:`is_pep585_builtin` *or* :attr:`is_pep585_generic`
-          are ``True``, ``False``.
-        * Else, ``True``.
-    is_typing : Optional[bool]
-        ``True`` only if this hint itself is defined by the :mod:`typing`
-        module. Defaults to :attr:`is_type_typing`.
     pep_sign : HintSign
         **Sign** (i.e., arbitrary object uniquely identifying this
         PEP-compliant type hint) if this hint is uniquely identified by such a
@@ -296,6 +268,44 @@ class HintPepMetadata(HintNonpepMetadata):
 
         * :class:`typing.NamedTuple` reducing to :class:`tuple`.
         * :class:`typing.TypedDict` reducing to :class:`dict`.
+    is_args : bool, optional
+        ``True`` only if this hint is subscripted by one or more **arguments**
+        (i.e., PEP-compliant type hints that are *not* type variables) and/or
+        **type variables** (i.e., :class:`typing.TypeVar` instances). Defaults
+        to ``True`` only if the machine-readable representation of this hint
+        contains one or more "[" delimiters.
+    is_pep585_builtin : bool, optional
+        ``True`` only if this hint is a `PEP 585`-compliant builtin. If
+        ``True``, then :attr:`is_type_typing` *must* be ``False``. Defaults to
+        the negation of :attr:`is_pep585_generic` if non-``None`` *or*
+        ``False`` otherwise (i.e., if :attr:`is_pep585_generic` is ``None``).
+    is_pep585_generic : bool, optional
+        ``True`` only if this hint is a `PEP 585`-compliant generic. If
+        ``True``, then :attr:`is_type_typing` *must* be ``False``. Defaults to
+        the negation of :attr:`is_pep585_generic` if non-``None`` *or*
+        ``False`` otherwise (i.e., if :attr:`is_pep585_generic` is ``None``).
+    is_typevars : bool, optional
+        ``True`` only if this hint is subscripted by one or more **type
+        variables** (i.e., :class:`typing.TypeVar` instances). Defaults to
+        ``False``.
+    is_type_typing : bool, optional
+        ``True`` only if this hint's class is defined by the :mod:`typing`
+        module. If ``True``, then :attr:`is_pep585_builtin` and
+        :attr:`is_pep585_generic` *must* both be ``False``. Defaults to
+        either:
+
+        * If either :attr:`is_pep585_builtin` *or* :attr:`is_pep585_generic`
+          are ``True``, ``False``.
+        * Else, ``True``.
+    is_typing : bool, optional
+        ``True`` only if this hint itself is defined by the :mod:`typing`
+        module. Defaults to :attr:`is_type_typing`.
+    isinstanceable_type : Optional[type]
+        **Origin type** (i.e., non-:mod:`typing` class such that *all* objects
+        satisfying this hint are instances of this class) originating this hint
+        if this hint originates from a non-:mod:`typing` class *or* ``None``
+        otherwise (i.e., if this hint does *not* originate from such a class).
+        Defaults to ``None``.
     generic_type : Optional[type]
         Subscripted origin type associated with this hint if any *or* ``None``
         otherwise (i.e., if this hint is associated with *no* such type).
@@ -303,67 +313,76 @@ class HintPepMetadata(HintNonpepMetadata):
 
         * If this hint is subscripted, :attr:`isinstanceable_type`.
         * Else, ``None``.
-    isinstanceable_type : Optional[type]
-        **Origin type** (i.e., non-:mod:`typing` class such that *all* objects
-        satisfying this hint are instances of this class) originating this hint
-        if this hint originates from a non-:mod:`typing` class *or* ``None``
-        otherwise (i.e., if this hint does *not* originate from such a class).
-        Defaults to ``None``.
+    typehint_cls : Optional[Type[beartype.door.TypeHint]]
+        Concrete :class:`beartype.door.TypeHint` subclass responsible for
+        handling this hint if any *or* ``None`` otherwise (e.g., if the
+        :mod:`beartype.door` submodule has yet to support this hint).
 
     All remaining keyword arguments are passed as is to the superclass
     :meth:`HintNonpepMetadata.__init__` method.
     '''
 
-    # ..................{ INITIALIZERS                      }..................
+    # ..................{ INITIALIZERS                       }..................
     def __init__(
         self,
+        *,
 
-        # Mandatory parameters.
-        pep_sign: HintSign,
+        # Mandatory keyword-only parameters.
+        pep_sign: 'beartype._data.hint.pep.sign.datapepsigncls.HintSign',
 
-        # Optional parameters.
+        # Optional keyword-only parameters.
         is_args: Optional[bool] = None,
-        is_pep585_builtin: Optional[bool] = False,
-        is_pep585_generic: Optional[bool] = False,
+        is_pep585_builtin: Optional[bool] = None,
+        is_pep585_generic: Optional[bool] = None,
         is_typevars: bool = False,
         is_type_typing: Optional[bool] = None,
         is_typing: Optional[bool] = None,
         isinstanceable_type: Optional[type] = None,
         generic_type: Optional[type] = None,
+        typehint_cls: 'Optional[Type[beartype.door.TypeHint]]' = None,
         **kwargs
     ) -> None:
+
+        # Defer heavyweight imports.
+        from beartype._data.hint.pep.sign.datapepsigncls import HintSign
+        from beartype.door import TypeHint
+
+        # Validate passed non-variadic parameters.
         assert isinstance(is_typevars, bool), (
             f'{repr(is_typevars)} not bool.')
         assert isinstance(pep_sign, HintSign), f'{repr(pep_sign)} not sign.'
         assert isinstance(isinstanceable_type, _NoneTypeOrType), (
             f'{repr(isinstanceable_type)} neither class nor "None".')
 
-        # Initialize our superclass with all passed keyword arguments.
+        # Initialize our superclass with all remaining variadic parameters.
         super().__init__(**kwargs)
 
+        # Machine-readable representation of this hint.
+        hint_repr = repr(self.hint)
+
         # Conditionally default all unpassed parameters.
         if is_args is None:
             # Default this parameter to true only if the machine-readable
-            # representation of this hint contains "[" (e.g., "List[str]").
-            is_args = '[' in repr(self.hint)
+            # representation of this hint contains "[": e.g., "List[str]".
+            is_args = '[' in hint_repr
         if is_pep585_builtin is None:
-            # Default this parameter to either...
+            # Default this parameter to true only if...
             is_pep585_builtin = (
-                # If "is_pep585_generic" is non-"None", the negation of that;
-                not is_pep585_generic
-                if is_pep585_generic is not None else
-                # Else, false.
-                False
+                # This hint originates from an origin type *AND*...
+                isinstanceable_type is not None and
+                # The machine-readable representation of this hint is prefixed
+                # by the unqualified name of this origin type (e.g., "list[str]
+                # " is prefixed by "list"), suggesting this hint to be a PEP
+                # 585-compliant builtin.
+                hint_repr.startswith(isinstanceable_type.__name__)
             )
+            # print(f'is_pep585_builtin: {is_pep585_builtin}')
+            # print(f'hint_repr: {hint_repr}')
+            # print(f'isinstanceable_type.__name__: {isinstanceable_type.__name__}')
         if is_pep585_generic is None:
-            # Default this parameter to either...
-            is_pep585_generic = (
-                # If "is_pep585_builtin" is non-"None", the negation of that;
-                not is_pep585_builtin
-                if is_pep585_builtin is not None else
-                # Else, false.
-                False
-            )
+            # Default this parameter to false, because we can't think of
+            # anything better.
+            is_pep585_generic = False
         if is_type_typing is None:
             # Default this parameter to the negation of all PEP 585-compliant
             # boolean parameters. By definition, PEP 585-compliant type hints
@@ -392,10 +411,21 @@ class HintPepMetadata(HintNonpepMetadata):
             f'{repr(is_typing)} not bool.')
         assert isinstance(generic_type, _NoneTypeOrType), (
             f'{repr(generic_type)} neither class nor "None".')
+        assert isinstance(generic_type, _NoneTypeOrType), (
+            f'{repr(generic_type)} neither class nor "None".')
+        assert (
+            typehint_cls is None or (
+                isinstance(typehint_cls, type) and
+                issubclass(typehint_cls, TypeHint),
+            )
+        ), (
+            f'{repr(typehint_cls)} neither '
+            f'"beartype.door.TypeHint" subclass nor "None".'
+        )
 
-        # Validate that the "is_pep585_builtin" and "is_type_typing" are *NOT* both true.
-        # Note that both can be false (e.g., for PEP 484-compliant user-defined
-        # generics).
+        # Validate that the "is_pep585_builtin" and "is_type_typing" parameters
+        # are *NOT* both true. Note, however, that both can be false (e.g., for
+        # PEP 484-compliant user-defined generics).
         assert not (
             (is_pep585_builtin or is_pep585_generic) and is_type_typing), (
             f'Mutually incompatible boolean parameters '
@@ -405,22 +435,24 @@ class HintPepMetadata(HintNonpepMetadata):
         )
 
         # Classify all passed parameters.
-        self.pep_sign = pep_sign
+        self.generic_type = generic_type
         self.is_args = is_args
         self.is_pep585_builtin = is_pep585_builtin
         self.is_pep585_generic = is_pep585_generic
         self.is_typevars = is_typevars
         self.is_type_typing = is_type_typing
         self.is_typing = is_typing
-        self.generic_type = generic_type
         self.isinstanceable_type = isinstanceable_type
+        self.pep_sign = pep_sign
+        self.typehint_cls = typehint_cls
 
-    # ..................{ STRINGIFIERS                      }..................
+    # ..................{ STRINGIFIERS                       }..................
     def __repr__(self) -> str:
         return '\n'.join((
             f'{self.__class__.__name__}(',
             f'    hint={repr(self.hint)},',
             f'    pep_sign={repr(self.pep_sign)},',
+            f'    typehint_cls={repr(self.typehint_cls)},',
             f'    generic_type={repr(self.generic_type)},',
             f'    isinstanceable_type={repr(self.isinstanceable_type)},',
             f'    is_args={repr(self.is_args)},',
