@@ -1,9 +1,8 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
+# --------------------( LICENSE                            )--------------------
 # Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
-
 '''
 :mod:`pytest` **global test configuration** (i.e., early-time configuration
 guaranteed to be run by :mod:`pytest` *after* passed command-line arguments are
@@ -21,16 +20,15 @@ https://github.com/pytest-dev/pytest-asyncio/blob/master/pytest_asyncio/plugin.p
     and unmerged pull requests, and just generally exhibits code smells.
 '''
 
-# ....................{ TODO                              }....................
+# ....................{ TODO                               }....................
 #FIXME: Consider refactoring the pytest_pyfunc_call() hook defined below into:
 #* A pull request against pytest itself. Pytest absolutely requires support for
 #  asynchronous test functions. This is 2021, people.
 #* A new competing "pytest-async" plugin. This is substantially easier but less
 #  ideal, as pytest *REALLY* both wants and needs this functionality.
 
-# ....................{ IMPORTS                           }....................
+# ....................{ IMPORTS                            }....................
 from asyncio import (
-    ensure_future,
     get_event_loop_policy,
     new_event_loop,
     set_event_loop,
@@ -39,7 +37,7 @@ from functools import wraps
 from inspect import iscoroutinefunction
 from pytest import hookimpl
 
-# ....................{ HOOKS ~ configure                 }....................
+# ....................{ HOOKS ~ configure                  }....................
 @hookimpl(hookwrapper=True, tryfirst=True)
 def pytest_pyfunc_call(pyfuncitem: 'Function') -> None:
     '''
@@ -77,7 +75,7 @@ def pytest_pyfunc_call(pyfuncitem: 'Function') -> None:
     #
     # Note that we intentionally prefer calling this well-tested tester of the
     # well-tested "inspect" module rather than our comparable
-    # beartype._util.func.utilfunctest.is_func_async_coroutine() tester, which
+    # beartype._util.func.utilfunctest.is_func_coro() tester, which
     # is hopefully but *NOT* necessarily known to be working here.
     if iscoroutinefunction(test_func):
         @wraps(test_func)
@@ -136,19 +134,11 @@ def pytest_pyfunc_call(pyfuncitem: 'Function') -> None:
             # asynchronous coroutine objects on each call.
             test_func_coroutine = test_func(*args, **kwargs)
 
-            #FIXME: Replace this call with the equivalent call to the more
-            #human-readable asyncio.create_task() function once we drop Python
-            #3.6 support, which lacks asyncio.create_task().
-
-            # Asynchronous task scheduling this coroutine to be subsequently
-            # asynchronously run under this event loop.
-            test_func_task = ensure_future(
-                test_func_coroutine, loop=event_loop)
-
-            # Synchronously run this task and thus this coroutine, ignoring the
-            # value returned by this coroutine (if any) while reraising any
-            # exception raised by this coroutine up the call stack to pytest.
-            event_loop.run_until_complete(test_func_task)
+            # Synchronously run a new asynchronous task implicitly scheduled to
+            # run this coroutine, ignoring the value returned by this coroutine
+            # (if any) while reraising any exception raised by this coroutine
+            # up the call stack to pytest.
+            event_loop.run_until_complete(test_func_coroutine)
 
             # Close this event loop.
             event_loop.close()
